#!/bin/sh

# Export AF Viewer Script.  This script does the following:
# - Mounts the external flash (CF) if not already mounted
# - Checks whether the af viewer already resides on the CF
# - Checks whether there is sufficient space on the CF
# - If the previous two conditions pass, it copies the AF viewer
#   to the CF.
# CF mount state is left the same as when the script started.
# Author: Randy Antosiak, 2/1/06

AFVIEWER_NAME=AFViewer_Setup_v1_1_1.exe

# Min space needed on external CF (x 1KB)
MAX_NEEDED_SPACE=3000

# Mounting
MOUNTED=$(df | grep /dev/hda1)
if [ "$MOUNTED" = "" ]; then
  echo "CF Not mounted, mounting now.."
  mount -t vfat /dev/hda1 /mntd
  if [ "$?" != 0 ]; then
     echo "Cannot Mount CF"
     exit
  fi
fi

# Version management - not active right now.
#. ./AFversion
#echo CURRENT VERSION $CURRENT_VERSION
#. ./AFlegacy
#echo LEGACY VERSION $LEGACY_VERSION

#if [ "$CURRENT_VERSION" -gt "$LEGACY_VERSION" ]; then
#   echo "current version is newer"
#else
#   echo "current version is older"
#fi

#/bin/rm AFlegacy
#touch AFlegacy
#echo LEGACY_VERSION=$CURRENT_VERSION > AFlegacy

######
# check space
######
AVAILABLE=$(df  | grep /dev/hda1 | cut -b 44-50)
echo "Available Space on Disk (x 1KB): $AVAILABLE"

######
# check if AF viewer is already on external flash
######
VIEWER_NOT_FOUND=0
ls /mntd/$AFVIEWER_NAME
if [ "$?" != 0 ]; then
  VIEWER_NOT_FOUND=1
fi

######
# copying
######
if [ $AVAILABLE -gt $MAX_NEEDED_SPACE ]; then
  if [ $VIEWER_NOT_FOUND = "1" ]; then
   echo "Copying AFViewer to External CF"
   cp /mnt/apps/afviewer/$AFVIEWER_NAME /mntd
  fi
else
   echo "No Room On CF or Viewer already on CF"
fi

######
# unmounting
######
if [ "$MOUNTED" = "" ]; then
  echo "Unmounting CF.."
  umount /mntd
fi
