##############################################################################
#
# vc/src/tcl/autofarm2.tcl
#
# Main AutoFarm screen --- used for row lineup and AutoSteer modes.
#
# 20020411 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop

    # Curve display
    frame .ftop.curve
    pack .curveDisp -in .ftop.curve -side bottom -anchor s -padx 5 -pady 5
    raise .curveDisp

    # header frame
    frame .ftop.curve.header
    label .ftop.curve.header.l1 -text "MANUAL STEERING"
    bind .ftop.curve.header.l1 <ButtonPress-1> \
        { beepOnce; post $DISP_CANVAS0_SIG 0 }
    button .ftop.curve.header.zoomout -image zoomout \
        -command { beepOnce; post $DISP_BTN1_SIG 0 } \
        -background $color7 -activebackground $color7 \
        -bd 0
    button .ftop.curve.header.zoomin -image zoomin \
        -command { beepOnce; post $DISP_BTN1_SIG 1 } \
        -background $color7 -activebackground $color7 \
        -bd 0

    pack .ftop.curve.header.zoomout -side left -padx 5 -anchor w
    pack .ftop.curve.header.zoomin -side right -padx 5 -anchor e
    pack .ftop.curve.header.l1 -side top -anchor center -padx 10 -pady 0
    pack .ftop.curve.header -side top -fill both -expand yes

    # Slider and Nudge container
    frame .ftop.sn

    # Slider frame
    frame .ftop.sn.sliders
    pack .s0 -in .ftop.sn.sliders -side top -fill both -expand yes
    raise .s0
    
    # Nudge frame
    frame .ftop.sn.nudges
    label .ftop.sn.nudges.l0 -text "Nudge (10.0 inches)" -font $medium_font
    frame .ftop.sn.nudges.r
    button .ftop.sn.nudges.r.toggle -text "Toggle" -font $btn_font \
        -command { beepOnce; post $DISP_BTN8_SIG 2 } \
        -width 5 -height 1 \
        -background $color7 -activebackground $color7 \
        -bd 5
    SnazzyButton::create .ftop.sn.nudges.r.left btnBigLeftNudgeU \
        btnBigLeftNudgeD 0.5 "beepOnce; post $DISP_BTN8_SIG 0"
    SnazzyButton::create .ftop.sn.nudges.r.right btnBigRightNudgeU \
                     btnBigRightNudgeD 0.5 "beepOnce; post $DISP_BTN8_SIG 1"

    # Pack nudge frame
    pack .ftop.sn.nudges.l0 -side top -padx 10
    pack .ftop.sn.nudges.r.left -side left -padx 5 -pady 5
    pack .ftop.sn.nudges.r.toggle -side left -padx 5 -pady 5
    pack .ftop.sn.nudges.r.right -side right -padx 5 -pady 5
    pack .ftop.sn.nudges.r -side top -fill both -expand yes

    # Pack .ftop.sn
    pack .ftop.sn.nudges -side top -pady 10
    pack .ftop.sn.sliders -side top -pady 10
    
    # CPU loading frame
    frame .ftop.cpuload
    label .ftop.cpuload.t -text "CPU Loading" -font $medium_font
    pack .ftop.cpuload.t -side top -anchor nw -padx 5 -pady 5
    label .ftop.cpuload.l -text "No data yet" -font {6x13}
    pack .ftop.cpuload.l -side top -anchor nw -padx 5 -pady 5

    # Input frame
    frame .ftop.input

    # Exit button
    button .ftop.input.cancel -text "Exit" -font $btn_font \
        -command { beepOnce; post $DISP_BTN9_SIG 9 } \
        -width 8 -height 3 \
        -background $color5 -activebackground $color5 \
        -bd 5

    # Open/Close menu buttons
    button .ftop.input.menuOpen -text "Menu" -font $btn_font \
        -command { beepOnce; post $DISP_BTN2_SIG 1 } \
        -width 8 -height 2 \
        -background $color7 -activebackground $color7 \
        -bd 5
    button .ftop.input.menuClose -text "Close\nMenu" -font $btn_font \
        -command { beepOnce;  post $DISP_BTN2_SIG 0 } \
        -width 8 -height 2 \
        -background $color5 -activebackground $color5 \
        -bd 5

    # STOP/GO buttons
    frame .ftop.input.stopgo
    SnazzyButton::create .ftop.input.stopgo.stop btnBigStopU btnBigStopD 0.5 \
        "beepOnce; post $DISP_BTN0_SIG 0"
    SnazzyButton::create .ftop.input.stopgo.go btnBigGoU btnBigGoD 0.5 \
        "beepOnce; post $DISP_BTN0_SIG 1"

    # Pack input frame
    pack .ftop.input.stopgo -side right -anchor se -padx 5 -pady 5
    pack .ftop.input.cancel -side bottom -anchor sw -padx 5 -pady 5
    pack .ftop.input.menuOpen -side bottom -anchor sw -padx 5 -pady 5

    # Menu frames
    frame .ftop.menu
    image create photo marrowfor -file ${tclPath}gif/menuarrowforward.gif
    image create photo marrowback -file ${tclPath}gif/menuarrowbackward.gif

    # Menu level 0 frame
    frame .ftop.menu.level0 -bd 1 -relief solid
    frame .ftop.menu.level0.fl -width 100 -height 40
    pack propagate .ftop.menu.level0.fl 0
    label .ftop.menu.level0.fl.l -text "Menu 0:" -font $medium_font

    frame .ftop.menu.level0.f0 -width 100 -height 60
    pack propagate .ftop.menu.level0.f0 0
    button .ftop.menu.level0.f0.b0 -text "Button0" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 0 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level0.f1 -width 100 -height 60
    pack propagate .ftop.menu.level0.f1 0
    button .ftop.menu.level0.f1.b1 -text "Button1" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 1 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level0.f2 -width 100 -height 60
    pack propagate .ftop.menu.level0.f2 0
    button .ftop.menu.level0.f2.b2 -text "Button2" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 2 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level0.f3 -width 100 -height 60
    pack propagate .ftop.menu.level0.f3 0
    button .ftop.menu.level0.f3.b3 -text "Button3" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 3 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5

    # Menu level 1 frame
    frame .ftop.menu.level1 -bd 1 -relief solid
    frame .ftop.menu.level1.fl -width 100 -height 40
    pack propagate .ftop.menu.level1.fl 0
    label .ftop.menu.level1.fl.l -text "Menu 1:" -font $medium_font
    label .ftop.menu.level1.m -image marrowfor

    frame .ftop.menu.level1.f0 -width 100 -height 60
    pack propagate .ftop.menu.level1.f0 0
    button .ftop.menu.level1.f0.b0 -text "Button0" -font $btn_font \
        -command { beepOnce; post $DISP_BTN4_SIG 0 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level1.f1 -width 100 -height 60
    pack propagate .ftop.menu.level1.f1 0
    button .ftop.menu.level1.f1.b1 -text "Button1" -font $btn_font \
        -command { beepOnce; post $DISP_BTN4_SIG 1 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level1.f2 -width 100 -height 60
    pack propagate .ftop.menu.level1.f2 0
    button .ftop.menu.level1.f2.b2 -text "Button2" -font $btn_font \
        -command { beepOnce; post $DISP_BTN4_SIG 2 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level1.f3 -width 100 -height 60
    pack propagate .ftop.menu.level1.f3 0
    button .ftop.menu.level1.f3.b3 -text "Button3" -font $btn_font \
        -command { beepOnce; post $DISP_BTN4_SIG 3 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5

    # Menu level 2 frame
    frame .ftop.menu.level2 -bd 1 -relief solid
    frame .ftop.menu.level2.fl -width 100 -height 40
    pack propagate .ftop.menu.level2.fl 0
    label .ftop.menu.level2.fl.l -text "Menu 2:" -font $medium_font

    frame .ftop.menu.level2.f0 -width 100 -height 60
    pack propagate .ftop.menu.level2.f0 0
    button .ftop.menu.level2.f0.b0 -text "Button0" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 0 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level2.f1 -width 100 -height 60
    pack propagate .ftop.menu.level2.f1 0
    button .ftop.menu.level2.f1.b1 -text "Button1" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 1 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level2.f2 -width 100 -height 60
    pack propagate .ftop.menu.level2.f2 0
    button .ftop.menu.level2.f2.b2 -text "Button2" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 2 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5
    frame .ftop.menu.level2.f3 -width 100 -height 60
    pack propagate .ftop.menu.level2.f3 0
    button .ftop.menu.level2.f3.b3 -text "Button3" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 3 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 5

    # Pack screen
    pack .ftop.curve -side right -anchor e -fill both -expand yes
    pack .ftop.input -side bottom -anchor sw
    pack .ftop.sn -side top -pady 5 -fill both -expand yes
    
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {cancelBtn setupBtn} {

        pack .ftop -fill both -expand yes
    }
    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr

    proc actConfigureRowlineup { manualLbl manualSteeringText } {
        global huge_font
        pack forget .ftop.input.stopgo.stop
        pack .ftop.input.stopgo.go -side bottom -anchor se

        actConfigureHeader $manualLbl $huge_font orange
        CurveDisp::actConfigureRowlineup $manualSteeringText
    }

    proc actConfigureAutosteer { autoLbl } {
        global huge_font
        pack forget .ftop.input.stopgo.go
        pack .ftop.input.stopgo.stop -side bottom -anchor se

        actConfigureHeader $autoLbl $huge_font LimeGreen
        CurveDisp::actConfigureAutosteer
    }

    proc actConfigureHeader { text__ font__ color__ } {
        global huge_font big_font
        eval {.ftop.curve.header.l1 configure -text $text__ -font} $font__\
            {-background $color__}
        .ftop.curve.header configure -background $color__
        .ftop.curve.header.zoomout configure -background $color__ \
            -activebackground $color__
        .ftop.curve.header.zoomin configure -background $color__ \
            -activebackground $color__
        .ftop.curve configure -background $color__
    }

    proc actConfigureMenu {} {
        pack forget \
            .ftop.input.menuOpen \
            .ftop.sn \
            .ftop.cpuload
        pack .ftop.input.menuClose -side bottom -anchor sw -padx 5 -pady 5
        pack .ftop.menu -side top -pady 5 -fill both -expand yes
    }

    proc actConfigureNoMenu {} {
        pack forget .ftop.input.menuClose \
            .ftop.menu .ftop.menu.level0 .ftop.menu.level1 .ftop.menu.level2
        pack .ftop.sn -side top -pady 10 -fill both -expand yes
        pack .ftop.input.menuOpen -side bottom -anchor sw -padx 5 -pady 5
        actUnHighlightMenuLevel 0
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureCpuLoad {} {
        pack forget .ftop.input.menuClose \
            .ftop.menu .ftop.menu.level0 .ftop.menu.level1 .ftop.menu.level2
        pack .ftop.cpuload -side top -fill both -expand yes -pady 20
        pack .ftop.input.menuOpen -side bottom -anchor sw -padx 5 -pady 5
        actUnHighlightMenuLevel 0
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureMenuLevel0 { title__ \
                                      b0__ b0Id__ b0Hi__ \
                                      b1__ b1Id__ b1Hi__ \
                                      b2__ b2Id__ b2Hi__ \
                                      b3__ b3Id__ b3Hi__ } {

        global color5 color7 color9
        pack forget \
            .ftop.menu.level1 \
            .ftop.menu.level2 \
            .ftop.menu.level0.l \
            .ftop.menu.level0.fl \
            .ftop.menu.level0.f0 \
            .ftop.menu.level0.f1 \
            .ftop.menu.level0.f2 \
            .ftop.menu.level0.f3 \
            .ftop.menu.level0.f0.b0 \
            .ftop.menu.level0.f1.b1 \
            .ftop.menu.level0.f2.b2 \
            .ftop.menu.level0.f3.b3

        .ftop.menu.level0.fl.l configure -text $title__
        pack .ftop.menu.level0.fl -side top -anchor n
        pack .ftop.menu.level0.fl.l -side top -anchor n

        if {$b0__ != "!"} {
            .ftop.menu.level0.f0.b0 configure -text $b0__ \
                -command "beepOnce; post \$DISP_BTN3_SIG $b0Id__" \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b0Id__ == 0} {
                .ftop.menu.level0.f0.b0 configure -state disabled \
                    -background $color9
            }
            if {$b0Hi__ >= 1} {
                .ftop.menu.level0.f0.b0 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f0 -side top -anchor n
            pack .ftop.menu.level0.f0.b0 -side left -padx 2 -pady 5
        }
        if {$b1__ != "!"} {
            .ftop.menu.level0.f1.b1 configure -text $b1__ \
                -command " beepOnce; post \$DISP_BTN3_SIG $b1Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b1Id__ == 0} {
                .ftop.menu.level0.f1.b1 configure -state disabled \
                    -background $color9
            }
            if {$b1Hi__ >= 1} {
                .ftop.menu.level0.f1.b1 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f1 -side top -anchor n
            pack .ftop.menu.level0.f1.b1 -side left -padx 2 -pady 5
        }
        if {$b2__ != "!"} {
            .ftop.menu.level0.f2.b2 configure -text $b2__ \
                -command " beepOnce; post \$DISP_BTN3_SIG $b2Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b2Id__ == 0} {
                .ftop.menu.level0.f2.b2 configure -state disabled \
                    -background $color9
            }
            if {$b2Hi__ >= 1} {
                .ftop.menu.level0.f2.b2 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f2 -side top -anchor n
            pack .ftop.menu.level0.f2.b2 -side left -padx 2 -pady 5
        }
        if {$b3__ != "!"} {
            .ftop.menu.level0.f3.b3 configure -text $b3__ \
                -command " beepOnce; post \$DISP_BTN3_SIG $b3Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b3Id__ == 0} {
                .ftop.menu.level0.f3.b3 configure -state disabled \
                    -background $color9
            }
            if {$b3Hi__ >= 1} {
                .ftop.menu.level0.f3.b3 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f3 -side top -anchor n
            pack .ftop.menu.level0.f3.b3 -side left -padx 2 -pady 5
        }

        pack .ftop.menu.level0 -side left -padx 5 -pady 5 -anchor nw

        # MLE-040130: Cheating; this should be done in C side
        global level0list
        set level0list \
            [list \
                 "$b0Id__ .ftop.menu.level0.f0 .ftop.menu.level0.f0.b0" \
                 "$b1Id__ .ftop.menu.level0.f1 .ftop.menu.level0.f1.b1" \
                 "$b2Id__ .ftop.menu.level0.f2 .ftop.menu.level0.f2.b2" \
                 "$b3Id__ .ftop.menu.level0.f3 .ftop.menu.level0.f3.b3" ]
    }

    proc actConfigureMenuLevel1 { title__ \
                                      b0__ b0Id__ b0Hi__ \
                                      b1__ b1Id__ b1Hi__ \
                                      b2__ b2Id__ b2Hi__ \
                                      b3__ b3Id__ b3Hi__} {

        global color5 color7 color9
        pack forget \
            .ftop.menu.level2 \
            .ftop.menu.level1.l \
            .ftop.menu.level1.fl \
            .ftop.menu.level1.f0 \
            .ftop.menu.level1.f1 \
            .ftop.menu.level1.f2 \
            .ftop.menu.level1.f3 \
            .ftop.menu.level1.f0.b0 \
            .ftop.menu.level1.f1.b1 \
            .ftop.menu.level1.f2.b2 \
            .ftop.menu.level1.f3.b3

        .ftop.menu.level1.fl.l configure -text $title__
        pack .ftop.menu.level1.fl -side top -anchor n
        pack .ftop.menu.level1.fl.l -side top -anchor n

        if {$b0__ != "!"} {
            .ftop.menu.level1.f0.b0 configure -text $b0__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b0Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b0Id__ == 0} {
                .ftop.menu.level1.f0.b0 configure -state disabled \
                    -background $color9
            }
            if {$b0Hi__ >= 1} {
                .ftop.menu.level1.f0.b0 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f0 -side top -anchor n
            pack .ftop.menu.level1.f0.b0 -side left -padx 2 -pady 5
        }
        if {$b1__ != "!"} {
            .ftop.menu.level1.f1.b1 configure -text $b1__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b1Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b1Id__ == 0} {
                .ftop.menu.level1.f1.b1 configure -state disabled \
                    -background $color9
            }
            if {$b1Hi__ >= 1} {
                .ftop.menu.level1.f1.b1 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f1 -side top -anchor n
            pack .ftop.menu.level1.f1.b1 -side left -padx 2 -pady 5
        }
        if { $b2__ != "!" } {
            .ftop.menu.level1.f2.b2 configure -text $b2__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b2Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b2Id__ == 0} {
                .ftop.menu.level1.f2.b2 configure -state disabled \
                    -background $color9
            }
            if {$b2Hi__ >= 1} {
                .ftop.menu.level1.f2.b2 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f2 -side top -anchor n
            pack .ftop.menu.level1.f2.b2 -side left -padx 2 -pady 5
        }
        if { $b3__ != "!" } {
            .ftop.menu.level1.f3.b3 configure -text $b3__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b3Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b3Id__ == 0} {
                .ftop.menu.level1.f3.b3 configure -state disabled \
                    -background $color9
            }
            if {$b3Hi__ >= 1} {
                .ftop.menu.level1.f3.b3 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f3 -side top -anchor n
            pack .ftop.menu.level1.f3.b3 -side left -padx 2 -pady 5
        }

        pack .ftop.menu.level1 -side left -padx 5 -pady 5 -anchor nw

        # MLE-040130: Cheating; this should be done in C side
        global level1list
        set level1list \
            [list \
                 "$b0Id__ .ftop.menu.level1.f0 .ftop.menu.level1.f0.b0" \
                 "$b1Id__ .ftop.menu.level1.f1 .ftop.menu.level1.f1.b1" \
                 "$b2Id__ .ftop.menu.level1.f2 .ftop.menu.level1.f2.b2" \
                 "$b3Id__ .ftop.menu.level1.f3 .ftop.menu.level1.f3.b3" ]
    }

    proc actConfigureMenuLevel2 { title__ \
                                      b0__ b0Id__ b0Hi__ \
                                      b1__ b1Id__ b1Hi__ \
                                      b2__ b2Id__ b2Hi__ \
                                      b3__ b3Id__ b3Hi__ } {

        global color5 color7 color9
        pack forget \
            .ftop.menu.level1 \
            .ftop.menu.level2.l \
            .ftop.menu.level2.fl \
            .ftop.menu.level2.f0 \
            .ftop.menu.level2.f1 \
            .ftop.menu.level2.f2 \
            .ftop.menu.level2.f3 \
            .ftop.menu.level2.f0.b0 \
            .ftop.menu.level2.f1.b1 \
            .ftop.menu.level2.f2.b2 \
            .ftop.menu.level2.f3.b3

        .ftop.menu.level2.fl.l configure -text $title__
        pack .ftop.menu.level2.fl -side top -anchor n
        pack .ftop.menu.level2.fl.l -side top -anchor n

        if {$b0__ != "!"} {
            .ftop.menu.level2.f0.b0 configure -text $b0__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b0Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b0Id__ == 0} {

                puts "at b0Id__ == 0"

                .ftop.menu.level2.f0.b0 configure -state disabled \
                    -background $color9
            }
            if {$b0Hi__ >= 1} {
                .ftop.menu.level2.f0.b0 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f0 -side top -anchor n
            pack .ftop.menu.level2.f0.b0 -side left -padx 2 -pady 5
        }
        if {$b1__ != "!"} {
            .ftop.menu.level2.f1.b1 configure -text $b1__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b1Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b1Id__ == 0} {
                .ftop.menu.level2.f1.b1 configure -state disabled \
                    -background $color9
            }
            if {$b1Hi__ >= 1} {
                .ftop.menu.level2.f1.b1 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f1 -side top -anchor n
            pack .ftop.menu.level2.f1.b1 -side left -padx 2 -pady 5
        }
        if {$b2__ != "!"} {
            .ftop.menu.level2.f2.b2 configure -text $b2__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b2Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b2Id__ == 0} {
                .ftop.menu.level2.f2.b2 configure -state disabled \
                    -background $color9
            }
            if {$b2Hi__ >= 1} {
                .ftop.menu.level2.f2.b2 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f2 -side top -anchor n
            pack .ftop.menu.level2.f2.b2 -side left -padx 2 -pady 5
        }
        if {$b3__ != "!"} {
            .ftop.menu.level2.f3.b3 configure -text $b3__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b3Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b3Id__ == 0} {
                .ftop.menu.level2.f3.b3 configure -state disabled \
                    -background $color9
            }
            if {$b3Hi__ >= 1} {

                puts "at b3Hi__"

                .ftop.menu.level2.f3.b3 configure \
                    -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f3 -side top -anchor n
            pack .ftop.menu.level2.f3.b3 -side left -padx 2 -pady 5
        }
        
        pack .ftop.menu.level2 -side left -padx 5 -pady 5 -anchor nw
        
        # MLE-040130: Cheating; this should be done in C side
        global level2list
        set level2list \
            [list \
                 "$b0Id__ .ftop.menu.level2.f0 .ftop.menu.level2.f0.b0" \
                 "$b1Id__ .ftop.menu.level2.f1 .ftop.menu.level2.f1.b1" \
                 "$b2Id__ .ftop.menu.level2.f2 .ftop.menu.level2.f2.b2" \
                 "$b3Id__ .ftop.menu.level2.f3 .ftop.menu.level2.f3.b3" ]
    }

    proc actConfigureMenuLevel0Only { } {

        pack forget \
            .ftop.menu.level0 \
            .ftop.menu.level1 \
            .ftop.menu.level2 
        pack .ftop.menu.level0 -side left -anchor nw -padx 5 -pady 5
        actUnHighlightMenuLevel 0
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureMenuLevel01Only { } {

        pack forget \
            .ftop.menu.level0 \
            .ftop.menu.level1 \
            .ftop.menu.level2 
        pack .ftop.menu.level0 -side left -anchor nw -padx 5 -pady 5
        pack .ftop.menu.level1 -side left -anchor nw -padx 5 -pady 5
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureMenuBtn { level__ btn__ text__ id__ arrow__ } {
        set sigNum [expr 3 + $level__]
        .ftop.menu.level$level__.f$btn__.b$btn__ configure -text $text__ \
            -command " beepOnce; post \$DISP_BTN${sigNum}_SIG $id__ "
        if {$arrow__ == 0} {
            .ftop.menu.level$level__.f$btn__.b$btn__ configure -image ""
        } elseif {$arrow__ == 1} {
            .ftop.menu.level$level__.f$btn__.b$btn__ \
                configure -image marrowfor
        } elseif {$arrow__ == 2} {
            .ftop.menu.level$level__.f$btn__.b$btn__ \
                configure -image marrowback
        }
    }

    proc actHighlightLevel0MenuBtn { btnId__ highlight__ } {
        global level0list color8 color10
        actUnHighlightMenuLevel 0
        foreach e $level0list {
            if {[lindex $e 0] == $btnId__} {
                if {$highlight__ > 0} {
                    [lindex $e 2] configure -background $color8 \
                        -activebackground $color8
                }
                if {$highlight__ == 2} {
                    [lindex $e 2] configure -image marrowfor
                } elseif {$highlight__ == 3} {
                    [lindex $e 2] configure -image marrowback
                }
            }
        }
    }

    proc actHighlightLevel1MenuBtn { btnId__ highlight__ } {
        global level1list color8
        #actUnHighlightMenuLevel 1
        foreach e $level1list {
            if {[lindex $e 0] == $btnId__} {
                if {$highlight__ > 0} {
                    [lindex $e 2] configure -background $color8 \
                        -activebackground $color8
                }
                if {$highlight__ == 2} {
                    [lindex $e 2] configure -image marrowfor
                } elseif {$highlight__ == 3} {
                    [lindex $e 2] configure -image marrowback
                }
            }
        }
    }

    proc actHighlightLevel2MenuBtn { btnId__ highlight__ } {
        global level2list color8
        #actUnHighlightMenuLevel 2
        foreach e $level2list {
            if {[lindex $e 0] == $btnId__} {
                if {$highlight__ > 0} {
                    [lindex $e 2] configure -background $color8 \
                        -activebackground $color8
                }
                if {$highlight__ == 2} {
                    [lindex $e 2] configure -image marrowfor
                } elseif {$highlight__ == 3} {
                    [lindex $e 2] configure -image marrowback
                }
            }
        }
    }

    proc actUnHighlightMenuLevel { level__ } {
        global color7
        .ftop.menu.level$level__.f0.b0 configure \
            -background $color7 -activebackground $color7 -image ""
        .ftop.menu.level$level__.f1.b1 configure \
            -background $color7 -activebackground $color7 -image ""
        .ftop.menu.level$level__.f2.b2 configure \
            -background $color7 -activebackground $color7 -image ""
        .ftop.menu.level$level__.f3.b3 configure \
            -background $color7 -activebackground $color7 -image ""
    }

    proc actConfigureSecondSlider { sliderNum } {
        pack .s$sliderNum -in .ftop.sn.sliders -side top \
            -fill both -expand yes
        raise .s$sliderNum
    }

    proc actDrawJunkTcl {} {
        # Delegate to the .curveDisp component
        CurveDisp::actDrawJunkTcl
    }

    proc actDrawThis {script__} {
        # Delegate to the .curveDisp component
        CurveDisp::actDrawThis $script__
    }

    proc actVehicleDispData { speedText__ speedBarEnd__ \
                              jobText__ modeText__ passText__ nudgeText__ \
                              manualText__ } {

        # Delegate to the .tractorDisplay component
        CurveDisp::actVehicleDispData $speedText__ $speedBarEnd__ \
            $jobText__ $modeText__ $passText__ $nudgeText__ $manualText__
    }

    proc actSteerCodeDisp { turningWheelText__ killText__ clutchText__ \
            parkText__ resetReqText__ roadingText__ comsBadText__ \
            notReadyText__ inxUnsText__ } {

        # Delegate to the .curveDisp component
        CurveDisp::actSteerCodeDisp $turningWheelText__ $killText__ \
            $clutchText__ $parkText__ $resetReqText__ $roadingText__ \
            $comsBadText__ $notReadyText__ $inxUnsText__
    }

    proc actConfigDiagText { line__ text__ } {
        # Delegate to the .tractorDisplay component
        CurveDisp::actConfigDiagText $line__ $text__
    }

    proc actConfigBusyText { text__ } {
        # Delegate to the .tractorDisplay component
        CurveDisp::actConfigBusyText $text__
    }

    proc actConfigRecordBtn { text__ } {
        # Delegate to the .tractorDisplay component
        CurveDisp::actConfigRecordBtn $text__
    }

    proc actConfigRecordText { text__ color__} {
        # Delegate to the .tractorDisplay component
        CurveDisp::actConfigRecordText $text__ $color__
    }

    proc actSliderValue { sliderNum val notch } {
        Sliders::actSliderValue $sliderNum $val $notch
    }
    
    proc actFieldBoundary {} {
        # MLE-040115: So that tcl doesn't call an empty procedure
    }

    proc actToggleNudge { text__ } {
        .ftop.sn.nudges.l0 configure -text $text__
    }

    proc actConfigCpuLoadText { text__ } {
        .ftop.cpuload.l configure -text $text__
    }
}
