##############################################################################
#
# vc/src/tcl/baseDisplay.tcl
#
# Screen to display details about and edit an existing implement. Used when
# adding or editing an implement.
#
# 20020830 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Title
    label .ftop.title -text "??Space for title"

    # Input frame
    frame .ftop.input

    # Row 1
    frame .ftop.input.r1
    label .ftop.input.r1.l -text "Name:" -font $big_font -width 10 -anchor e
    label .ftop.input.r1.e -text "foo" -font $big_font \
                -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r1.l -side left -pady 5
    pack .ftop.input.r1.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r1.b btnBlueMU btnBlueMU 0.5 \
                         "beepOnce; post $DISP_BTN2_SIG 2;" "Change"
       
    # Row 2
    frame .ftop.input.r2
    label .ftop.input.r2.l -text "Type:" -font $big_font -width 10 -anchor e
    label .ftop.input.r2.e -text "Hitched" -font $big_font \
                  -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r2.l -side left -pady 5 -anchor w
    pack .ftop.input.r2.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r2.b btnBlueMU btnBlueMU 0.5 \
                         "beepOnce; post $DISP_BTN3_SIG 3;" "Change"
    
    # Row 3
    frame .ftop.input.r3
    label .ftop.input.r3.l -text "Width:" -font $big_font -width 10 -anchor e
    label .ftop.input.r3.e -text "xx feet xx inch" -font $big_font \
                  -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r3.l -side left -pady 5 -anchor w
    pack .ftop.input.r3.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r3.b btnBlueMU btnBlueMD 0.5 \
                         "beepOnce; post $DISP_BTN4_SIG 4;" "Change"

    # Row 4
    frame .ftop.input.r4
    label .ftop.input.r4.l -text "Offset:" -font $big_font -width 10 -anchor e
    label .ftop.input.r4.e -text "xx feet xx inch" -font $big_font \
                  -width 32 -anchor w -relief sunken -borderwidth 2
    pack .ftop.input.r4.l -side left -pady 5 -anchor w
    pack .ftop.input.r4.e -side left -padx 10 -pady 5
    SnazzyButton::create .ftop.input.r4.b btnBlueMU btnBlueMD 0.5 \
                         "beepOnce; post $DISP_BTN5_SIG 5;" "Change"

    # Pack rows
    pack .ftop.input.r1 -side top -anchor w -fill x
    pack .ftop.input.r2 -side top -anchor w -fill x
    pack .ftop.input.r3 -side top -anchor w -fill x
    pack .ftop.input.r4 -side top -anchor w -fill x
    
    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel btnKhakiU btnKhakiD 0.5 \
                         "beepOnce; post $DISP_BTN0_SIG 0;" "Cancel"
    SnazzyButton::create .ftop.input2.accept btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN1_SIG 1;" "Accept"                     
        
    pack .ftop.input2.cancel -side left -padx 10 -pady 10
    pack .ftop.input2.accept -side right -padx 10 -pady 10

    # Pack .ftop
    pack .ftop.title -side top -pady 10 -fill both -expand yes
    pack .ftop.input -side top -pady 10 -pady 5
    pack .ftop.input2 -side bottom -anchor se -fill both -expand yes
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {

        eval $packProc__
        pack .ftop -fill both -expand yes

    }


    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    proc actDisplayBasestation {name__ lat__ long__ alt__} {
        .ftop.input.r1.e configure -text $name__
        .ftop.input.r2.e configure -text $lat__
        .ftop.input.r3.e configure -text $long__
        .ftop.input.r4.e configure -text $alt__
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
    proc packAdd { title nameText latText lonText altText \
                   cancelBtn acceptBtn } {
        .ftop.title configure -text $title
        .ftop.input.r1.l configure -text $nameText
        .ftop.input.r2.l configure -text $latText
        .ftop.input.r3.l configure -text $lonText
        .ftop.input.r4.l configure -text $altText
        SnazzyButton::setText .ftop.input2.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.input2.accept $acceptBtn 0.5
    }


    proc packEdit { title nameText changeBtn latText lonText altText\
                    cancelBtn acceptBtn } {
        global huge_font color3
        
        pack .ftop.input.r1.b -side right
        pack .ftop.input.r2.b -side right
        pack .ftop.input.r3.b -side right
        pack .ftop.input.r4.b -side right

        .ftop.title configure -text $title
        .ftop.input.r1.l configure -text $nameText
        SnazzyButton::setText .ftop.input.r1.b $changeBtn 0.5
        .ftop.input.r2.l configure -text $latText
        .ftop.input.r3.l configure -text $lonText
        .ftop.input.r4.l configure -text $altText
        SnazzyButton::setText .ftop.input2.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.input2.accept $acceptBtn 0.5        
   }
}
