##############################################################################
#
# al/src/tcl/calibration.tcl
#
# autolevel calibration screen
#
# 20050610  DEH Created
#
# Copyright (c) 2005 Novariant
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop

    # Title
    label .ftop.title -text "AutoLevel Blade Calibration" -font $huge_font
    pack .ftop.title -side top

    frame .ftop.data

    frame .ftop.data.range
    label .ftop.data.range.vertRangeTag      -text "    Range       "   -font $medium_font
    label .ftop.data.range.vertRange         -text ""            -font $medium_font
    pack .ftop.data.range.vertRangeTag       -side top
    pack .ftop.data.range.vertRange          -side bottom

    frame .ftop.data.raise
    label .ftop.data.raise.raiseVelocityTag  -text "  Raise Speed   " -font $medium_font
    label .ftop.data.raise.raiseVelocity     -text ""            -font $medium_font
    pack .ftop.data.raise.raiseVelocityTag   -side top
    pack .ftop.data.raise.raiseVelocity      -side bottom

    frame .ftop.data.lower
    label .ftop.data.lower.lowerVelocityTag  -text "  Lower Speed   " -font $medium_font
    label .ftop.data.lower.lowerVelocity     -text ""            -font $medium_font
    pack .ftop.data.lower.lowerVelocityTag   -side top
    pack .ftop.data.lower.lowerVelocity      -side bottom

    pack .ftop.data.range  -side left
    pack .ftop.data.raise  -side left
    pack .ftop.data.lower  -side left

    # Bottom input frame
    frame .ftop.input
    frame .ftop.inputRight
    frame .ftop.inputLeft

    # Right panel input frame

    SnazzyButton::create .ftop.inputRight.right btnBigRightNudgeU btnBigRightNudgeD 0.0 \
                         "beepOnce; post $DISP_BTN6_SIG 0"


    # Left panel input frame
    SnazzyButton::create .ftop.inputLeft.left btnBigLeftNudgeU btnBigLeftNudgeD 0.5 \
                         "beepOnce; post $DISP_BTN6_SIG 1"

    pack .ftop.inputRight.right -side right
    pack .ftop.inputLeft.left -side left

    # Accept/Reject Subframe
    frame .ftop.input.acceptReject
    # Cancel Button
    button .ftop.input.acceptReject.cancel \
            -text "Cancel" \
            -command { beepOnce; post $DISP_BTN9_SIG 0 } \
            -width 8 -height 3 \
            -background $color0 -activebackground $color0
    pack .ftop.input.acceptReject.cancel -side left -anchor s -padx 10 -pady 5
    # Recalculate Button
    button .ftop.input.acceptReject.recalc \
            -text "Recalculate\nCalibration\nCurves" \
            -command { beepOnce; post $DISP_BTN1_SIG 0 } \
            -width 8 -height 3 \
            -background $color5 -activebackground $color5
    pack .ftop.input.acceptReject.recalc -side left -anchor s -padx 10 -pady 5
    # Accept Button
    button .ftop.input.acceptReject.accept \
            -text "Accept\nNew\nCalibration" \
            -command { beepOnce; post $DISP_BTN2_SIG 0 } \
            -width 8 -height 3 \
            -background $color5 -activebackground $color5
    pack .ftop.input.acceptReject.accept -side left -anchor s -padx 10 -pady 5
    # Discard Button
    button .ftop.input.acceptReject.discard \
            -text "Discard\nMarked\nData Point" \
            -command { beepOnce; post $DISP_BTN3_SIG 0 } \
            -width 8 -height 3 \
            -background $color5 -activebackground $color5
    pack .ftop.input.acceptReject.discard -side left -anchor s -padx 10 -pady 5
    # Start Button
    button .ftop.input.acceptReject.start \
            -text "Start" \
            -command { beepOnce; post $DISP_BTN5_SIG 0 } \
            -width 8 -height 3 \
            -background $color2 -activebackground $color2
    pack .ftop.input.acceptReject.start -side left -anchor s -padx 10 -pady 5

    # Pack the Input Frame
    pack .ftop.input.acceptReject -side right -expand no


    # Pack the various elements
    pack .ftop.data -side top -expand false
    pack .ftop.input -side bottom -expand false
    pack .ftop.inputRight -side right -expand false
    pack .ftop.inputLeft -side left -expand false
    pack .calDataDisplay -in .ftop -side bottom -expand no
    raise .calDataDisplay
#    pack .calibrationTimeLineDisp -in .ftop -side bottom -expand no
#    raise .calibrationTimeLineDisp

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {

#        eval $packProc__

        pack .ftop -fill both -expand yes
    }
    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {

        destroy .ftop

    }


    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr
    proc actPlotCalData { } {
	CalDataDisplay::actPlotCalData
    }    

    proc actResetUrawMarker { } {
	CalDataDisplay::actResetUraMarker
    }

    proc actUpdateUrawMarker { color__ uraw__ } {
	CalDataDisplay::actUpdateUrawMarker $color__ $uraw__
    }

    proc actUpdateRawAngleMarker { color__ rawAngle__ } {
	CalDataDisplay::actUpdateRawAngleMarker $color__ $rawAngle__
    }

    proc actHideRawAngleMarker { } {
	CalDataDisplay::actHideRawAngleMarker
    }

    proc actUpdateLanguage { range__ raise__ lower__ } {
	.ftop.data.range itemconfigure vertRangeTag -text $range__
	.ftop.data.raise itemconfigure raiseVelocityTag -text $raise__
	.ftop.data.lower itemconfigure lowerVelocityTag -text $lower__
    }

    proc actUpdateRange { range__ } {
	.ftop.data.range.vertRange configure -text $range__
    }

    proc actUpdateRaise { raise__ } {
	.ftop.data.raise.raiseVelocity configure -text $raise__
    }

    proc actUpdateLower { lower__ } {
	.ftop.data.lower.lowerVelocity configure -text $lower__
    }

    proc actConfigureActive { } {
	pack forget \
	    .ftop.input.acceptReject.recalc \
	    .ftop.input.acceptReject.accept \
	    .ftop.input.acceptReject.discard \
	    .ftop.inputRight.right \
	    .ftop.inputLeft.left \
    }

    proc actConfigurePassive { } {
#	pack .ftop.input.acceptReject.start -side left -anchor s -padx 10 -pady 5
	pack .ftop.input.acceptReject.recalc -side left -anchor s -padx 10 -pady 5
	pack .ftop.input.acceptReject.accept -side left -anchor s -padx 10 -pady 5
	pack .ftop.input.acceptReject.discard -side left -anchor s -padx 10 -pady 5
	pack .ftop.inputLeft.left -side bottom 
	pack .ftop.inputRight.right -side bottom 
    }

    proc actConfigureNoStart { } {
	pack forget .ftop.input.acceptReject.start
    }

    proc actConfigureStart { } {
	pack .ftop.input.acceptReject.start -side left -anchor s -padx 10 -pady 5
    }
    #-------------------------------------------------------------------------
    # Local procedures
    #-------------------------------------------------------------------------

}
