##############################################################################
#
# al/src/tcl/selectVehicle.tcl
#
# Screen to allow user configuration of SAMs 
#
# 20060817 DEH Created
#
# Copyright (c) 2006 Novariant Inc.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text ""

    
    frame .ftop.display
    frame .ftop.display.steps

    # Display Frame - displays up to 2 lines of text at a time
    label .ftop.display.l0
    label .ftop.display.l1

    frame .ftop.input
    
    #device list box
    frame .ftop.input.listdevframe
    label .ftop.input.listdevframe.label -text "Vehicle List" -justify left
    listbox .ftop.input.listdevframe.lbox -background white -font $big_font\
            -width 35 -height 3 

    # Create frame for buttons
    frame .ftop.input.b
    SnazzyButton::create .ftop.input.b.cancel \
                 btnBlueU btnBlueD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;" "Return To\nPrevious\nMenu"

    # get device list frame
    SnazzyButton::create .ftop.input.b.vehicle \
             btnBlueU btnBlueD 0.5 \
             "beepOnce; post $DISP_BTN0_SIG 0;" "Set"

    # Pack .ftop
    pack .ftop.title -side top -pady 10
    
    pack .ftop.input.listdevframe -side top -anchor n
    pack .ftop.input.b -side bottom -fill both -anchor s
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes

               
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { cancelBtn title } {
        global big_font
        global huge_font

        .ftop.title configure -text $title -font $huge_font
        #pack .ftop.display.l0 -side top
        
        SnazzyButton::setText .ftop.input.b.cancel $cancelBtn 0.5
        pack .ftop.input.b.cancel -side left -anchor w -padx 5
        pack .ftop.input.b.vehicle -side right -anchor w -padx 5
        
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actShowList {configLbl} {
        global big_font

	.ftop.input.listdevframe.label configure -text $configLbl
        pack .ftop.input.listdevframe.label -side top
        pack .ftop.input.listdevframe.lbox -side right
   
    }

    bind .ftop.input.listdevframe.lbox <ButtonPress-1> {
      beepOnce; post $DISP_CANVAS0_SIG 1;  
    } 



    proc actListboxInsert { item } {
        .ftop.input.listdevframe.lbox insert end $item
#        .ftop.input.listdevframe.lbox selection set 0
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.input.listdevframe.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.input.listdevframe.lbox selection set $index
        .ftop.input.listdevframe.lbox see $index
    }

    proc actListboxGetCurselection {} {
        if { [.ftop.input.listdevframe.lbox index end] != 0} {
            set index [lindex [.ftop.input.listdevframe.lbox curselection] 0]
            return [.ftop.input.listdevframe.lbox get $index]
        } else {
            return "!"             ;# ! tells the C side the listbox was empty
        }
    }

    proc actListboxGetCurindex {} {
      if { [.ftop.input.listdevframe.lbox index end] != 0} {
          return [lindex [.ftop.input.listdevframe.lbox curselection] 0]
      } else {
          return -1             ;# -1 tells the C side the listbox was empty
      }
    }
}
