##############################################################################
#
# vc/src/tcl/setimezone.tcl
#
# Screen to set time zone.
#
# 20040129 QC - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Space for title"

    # Input frame
    frame .ftop.input

    frame .ftop.input.choice0
    radiobutton .ftop.input.choice0.0 -height 2 -width 50 -variable timezone \
        -command {beepOnce; post $DISP_BTN1_SIG 1} -activebackground $color6 \
        -text "Pacific Standard Time" -font $big_font -value 0 -anchor sw
    frame .ftop.input.choice1
    radiobutton .ftop.input.choice1.1 -height 2 -width 50 -variable timezone \
        -command {beepOnce; post $DISP_BTN2_SIG 2} -activebackground $color6 \
        -text "Mountain Standard Time" -font $big_font -value 1 -anchor sw
    frame .ftop.input.choice2
    radiobutton .ftop.input.choice2.2 -height 2 -width 50 -variable timezone \
        -command {beepOnce; post $DISP_BTN3_SIG 3} -activebackground $color6 \
        -text "Central Standard Time" -font $big_font -value 2 -anchor sw
    frame .ftop.input.choice3
    radiobutton .ftop.input.choice3.3 -height 2 -width 50 -variable timezone \
        -command {beepOnce; post $DISP_BTN4_SIG 4} -activebackground $color6 \
        -text "Eastern Standard Time" -font $big_font -value 3 -anchor sw
    frame .ftop.input.choice4
    radiobutton .ftop.input.choice4.4 -height 2 -width 50 -variable timezone \
        -command {beepOnce; post $DISP_BTN5_SIG 5} -activebackground $color6 \
        -text "Other" -font $big_font -value 4 -anchor sw
    pack .ftop.input.choice0.0 -side top -padx 30 -anchor sw
    pack .ftop.input.choice1.1 -side top -padx 30 -anchor sw
    pack .ftop.input.choice2.2 -side top -padx 30 -anchor sw
    pack .ftop.input.choice3.3 -side top -padx 30 -anchor sw
    pack .ftop.input.choice4.4 -side top -padx 30 -anchor sw
    pack .ftop.input.choice0 -side top -padx 50 -anchor sw
    pack .ftop.input.choice1 -side top -padx 50 -anchor sw
    pack .ftop.input.choice2 -side top -padx 50 -anchor sw
    pack .ftop.input.choice3 -side top -padx 50 -anchor sw
    pack .ftop.input.choice4 -side top -padx 50 -anchor sw

    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;" "Return To Previous Menu"
    SnazzyButton::create .ftop.input2.accept btnBlueU btnBlueD 0.5 \
                 "beepOnce; post $DISP_BTN0_SIG 0;" "Accept"            
        
    pack .ftop.input2.cancel -side left -padx 10 -pady 10
    pack .ftop.input2.accept -side right -padx 10 -pady 10

    # Pack .ftop
    pack .ftop.title -side top -pady 10 -fill both -expand yes
    pack .ftop.input -side top -padx 100
    pack .ftop.input2 -side bottom -anchor se -fill both -expand yes
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {titleLbl pstLbl mstLbl cstLbl estLbl returnBtn \
                   acceptBtn valtimezone} {
        set timezone $valtimezone
        puts stdout "timezone: $timezone"
        set btnid [expr $timezone + 8]
        puts stdout "btnid: $btnid"
        if {$btnid >= 0 && $btnid <= 3} { 
          puts stdout "timezone: normal"
          .ftop.input.choice$btnid.$btnid select
        } else {
          .ftop.input.choice4.4 select
          puts stdout "timezone: other"
        }
         
        .ftop.title configure -text \
                               "$titleLbl (Current GMT Offset = $valtimezone)"
        SnazzyButton::setText .ftop.input2.cancel $returnBtn 0.5
        SnazzyButton::setText .ftop.input2.accept $acceptBtn 0.5
        
        .ftop.input.choice0.0 configure -text $pstLbl
        .ftop.input.choice1.1 configure -text $mstLbl
        .ftop.input.choice2.2 configure -text $cstLbl
        .ftop.input.choice3.3 configure -text $estLbl
        
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actDisplayTimeZone {valtimezone titleLbl} {
        set timezone $valtimezone
        set btnid [expr $timezone + 8]
        .ftop.input.choice$btnid.$btnid select 
        .ftop.title configure -text \
                               "$titleLbl (Current GMT Offset = $valtimezone)"

    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
