##############################################################################
#
# vc/src/tcl/adjustAutoSteerKickout.tcl
#
# Screen to allow user to adjust pressure transducer kickout limit.
#
# 20080822 RCM - created
#
# Copyright (c) 2002-2003 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # title text
    #-------------------------------------------------------------------------
    frame .ftop.title
    label .ftop.title.mainTxt -font $huge_font
    pack .ftop.title.mainTxt -side top -pady 5 
    
    # Divider between title and content
    #-------------------------------------------------------------------------
    label .ftop.title.divider -image imgDivider 
    pack .ftop.title.divider -side top
    
    # Subtitle text
    #-------------------------------------------------------------------------
    label .ftop.title.subtitleTxt -font $medium_font
    pack .ftop.title.subtitleTxt -side top -pady 2
    
    # Adjust Control
    #-------------------------------------------------------------------------
    frame .ftop.control -bd 1 -relief solid
    frame .ftop.control.title -bd 1 -relief solid -bg lightgray
    label .ftop.control.title.txt -text "Manual Override" -font $medium_font \
      -bd 1 -bg lightgray

    frame .ftop.control.content 

    # Sensitivity Slider
    #-------------------------------------------------------------------------
    frame .ftop.control.content.slider
    pack .s8 -in .ftop.control.content.slider -side top -fill both -expand yes
    raise .s8
    frame .ftop.control.content.inc
    label .ftop.control.content.inc.tag -text "Increment" -font $medium_font 
    label .ftop.control.content.inc.val -text "10 %" -font $medium_font \
	-relief sunken -borderwidth 2
    SnazzyButton::create .ftop.control.content.inc.toggle \
	  btnBlueMS5U btnBlueMS5D 0.5 \
      "beepOnce; post $DISP_BTN1_SIG 0" "Toggle"
    pack .ftop.control.content.inc.tag -side left -padx 3 -pady 3
    pack .ftop.control.content.inc.val -side left -padx 3 -pady 3
    pack .ftop.control.content.inc.toggle -side left -padx 3 -pady 3

    # Pressure Transducer and HIGH_PRESS_LIM bars
    #-------------------------------------------------------------------------
    frame .ftop.control.content.adjust
    frame .ftop.control.content.adjust.pressure
    set barWidth  180
    set barHeight 20
    canvas .ftop.control.content.adjust.pressure.bar -background $color6 \
      -width $barWidth -height $barHeight -relief sunken -borderwidth 2
    incr barHeight        
    .ftop.control.content.adjust.pressure.bar create rectangle 0 0 0 $barHeight \
      -outline black -fill $colorMedium -tags gauge
    .ftop.control.content.adjust.pressure.bar create text [expr $barWidth/5] 6 \
      -font $small_font -anchor nw -text "Transducer: 0" -tags value
            

    # Kill Switch Status
    #-------------------------------------------------------------------------
    label .ftop.control.content.adjust.pressure.killStatus -font $large_font \
      -text "Disengage Switch: Off" -relief sunken -bd 2 
           
    frame .ftop.control.content.adjust.lvl
    label .ftop.control.content.adjust.lvl.tag -text "Limit:" -font $medium_font 
    label .ftop.control.content.adjust.lvl.val -text "0         " -font $medium_font \
	-relief sunken -borderwidth 2
    SnazzyButton::create .ftop.control.content.adjust.lvl.reset \
	  btnBlueMS5U btnBlueMS5D 0.5 \
      "beepOnce; post $DISP_BTN3_SIG 1" "Reset"
    pack .ftop.control.content.adjust.lvl.tag -side left -padx 5
    pack .ftop.control.content.adjust.lvl.val -side left -padx 5
    pack .ftop.control.content.adjust.lvl.reset -side left -padx 5

    #pack .ftop.control.content.adjust.pressure.killStatus -side top
    pack .ftop.control.content.adjust.pressure.bar -side top -pady 2 -anchor n
    pack .ftop.control.content.adjust.pressure -side top -anchor n -fill x
    pack .ftop.control.content.adjust.lvl -side top -anchor n -fill x


    # pack control
    #-------------------------------------------------------------------------   
    pack .ftop.control.title -side top -fill x 
    pack .ftop.control.title.txt -side top -fill x 
    pack .ftop.control.content.slider -side top
    pack .ftop.control.content.inc -side top -pady 3
    pack .ftop.control.content.adjust -side top -pady 3
    pack .ftop.control.content -side top -fill x

    # buttons
    #-------------------------------------------------------------------------   
    frame .ftop.buttons
    frame .ftop.buttons.c
    frame .ftop.buttons.l -width 350
    frame .ftop.buttons.spacer -width 160
    frame .ftop.buttons.r

    # STOP/GO buttons
    #-------------------------------------------------------------------------   
    SnazzyBlendedButton::create .ftop.buttons.c.stop btnBigStopU \
         btnBigStopD 0.5 \
        "beepOnce; post $DISP_BTN0_SIG 0" " " $color6
        
    SnazzyBlendedButton::create .ftop.buttons.c.go btnBigGoU \
         btnBigGoD 0.5 \
        "beepOnce; post $DISP_BTN0_SIG 1" " " $color6
    SnazzyButton::create .ftop.buttons.reset btnBlueMU btnBlueMD 0.5 \
      "beepOnce; post $DISP_BTN3_SIG 3" "Reset"
    SnazzyButton::create .ftop.buttons.r.return btnBlueU btnBlueD 0.5 \
      "beepOnce; post $DISP_BTN9_SIG 9" "Return to\nPrevious\nMenu"
        
    # Pack Buttons
    #-------------------------------------------------------------------------
    #pack .ftop.buttons.reset -side bottom
    pack .ftop.buttons.r.return -side right -anchor sw -padx 2 -pady 2 
    pack .ftop.buttons.c.go -side bottom -anchor s -padx 10 -pady 10
    pack .ftop.buttons.r -side right
    pack .ftop.buttons.spacer -side right
    pack .ftop.buttons.c -side right
    pack .ftop.buttons.l -side left
    
    
    
     
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    
    proc actEntry { titleLbl subtitleLbl resetBtn  returnBtn incrementLbl \
		    incrementToggle } {
   
        global huge_font big_font
   
        .ftop.title.mainTxt configure     -text $titleLbl
        .ftop.title.subtitleTxt configure -text $subtitleLbl
        .ftop.buttons.reset configure    -text $resetBtn
        .ftop.buttons.r.return configure    -text $returnBtn
	.ftop.control.content.inc.tag configure -text $incrementLbl
	.ftop.control.content.inc.toggle configure -text $incrementToggle
        pack .ftop.title -side top -fill x -expand yes -anchor n -pady 1
        pack .ftop.control -side top -anchor n -padx 12
        pack .ftop.buttons -side bottom -fill x -expand yes -anchor s -pady 1
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # other action procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    proc actDisplayPressureTransducer { killSwitchTxt__ killSwitch__ \
                                        transducer__ kickoutLimit__ } { 
         
      .ftop.control.content.adjust.pressure.killStatus configure \
        -text $killSwitchTxt__$killSwitch__
      if { $transducer__ < $kickoutLimit__ } {
        .ftop.control.content.adjust.pressure.bar itemconfigure gauge -fill green
      }
      if { $transducer__ > $kickoutLimit__ } {
        .ftop.control.content.adjust.pressure.bar itemconfigure gauge -fill red
      }
      .ftop.control.content.adjust.pressure.bar itemconfigure value \
        -text "Transducer: $transducer__"

      .ftop.control.content.adjust.pressure.bar coords gauge 1 1 \
           [expr ($transducer__/38000)*$Screen::barWidth] $Screen::barHeight
    }
    
    proc setKickOutLvl { lvl } {
	.ftop.control.content.adjust.lvl.val configure -text $lvl
    }
    
    proc actPackGoButton { } {
      pack forget .ftop.buttons.c.stop
      pack .ftop.buttons.c.go -side bottom -anchor s -padx 2 -pady 2
    }

    proc actPackStopButton { } {
      pack forget .ftop.buttons.c.go
      pack .ftop.buttons.c.stop -side right -anchor e -padx 2 -pady 2
    }
    
    proc actSetIncrement { incr } {
      .ftop.control.content.inc.val configure -text $incr
    }
    
    proc actSliderValue { sliderNum val notch } {
        Sliders::actSliderValue $sliderNum $val $notch
    }
}
