
##############################################################################
#
# vc/src/tcl/autofarm2.tcl
#
# Main AutoFarm screen --- used for row lineup and AutoSteer modes.
#
# 20020411 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop -background $backGroundColor

    # master frame for the curve display
    frame .ftop.curve -background orange
    
	# master frame for opengl widget
	frame .ftop.curve.f -background #00A5FF
    pack .ftop.curve.f -side bottom -expand yes -fill both

    # header frame
    frame .ftop.curve.header -bg #00A5FF
    label .ftop.curve.header.l1 -text "MANUAL STEERING" -pady 5 -bg orange
    bind .ftop.curve.header.l1 <ButtonPress-1> \
        { beepOnce; post $DISP_CANVAS0_SIG 0 }
    button .ftop.curve.header.zoomout -image zoomout \
        -command { beepOnce; post $DISP_BTN1_SIG 0 } \
        -highlightthickness 0 -bd 0 -bg orange
    button .ftop.curve.header.zoomin -image zoomin \
        -command { beepOnce; post $DISP_BTN1_SIG 1 } \
		-highlightthickness 0 -bd 0 -bg orange

    pack .ftop.curve.header.zoomout -side left -padx 5 -anchor s
    pack .ftop.curve.header.zoomin -side right -padx 5 -anchor s
    pack .ftop.curve.header.l1 -side top -anchor center -padx 10 -pady 0
    pack .ftop.curve.header -side top -fill both -expand yes
    
    # Slider and Nudge container
    frame .ftop.sn -background $backGroundColor
    frame .ftop.sn.r1 -background $backGroundColor
    frame .ftop.sn.r2 -background $backGroundColor
    # Slider frame
    frame .ftop.sn.r1.sliders -background $backGroundColor
    #pack .s0 -in .ftop.sn.r1.sliders -side top -fill both -expand yes
    #raise .s0
    
    # Nudge frame
    frame .ftop.sn.r1.nudges -height 80 -width 300 -background $backGroundColor
    label .ftop.sn.r1.nudges.l0 -text "Nudge (10.0 inches)" -font $medium_font -background $backGroundColor
    frame .ftop.sn.r1.nudges.r -background $backGroundColor
    SnazzyButton::create .ftop.sn.r1.nudges.r.toggle \
	     btnBlueMS4U btnBlueMS4D 0.5 \
		"beepOnce; post $DISP_BTN8_SIG 2" "Toggle"
    SnazzyBlendedButton::create .ftop.sn.r1.nudges.r.left \
	    btnMediumLeftNudgeU btnBigLeftNudgeD 0.5 "beepOnce; post $DISP_BTN8_SIG 0" \
	"  " $backGroundColor
    SnazzyBlendedButton::create .ftop.sn.r1.nudges.r.right \
		btnMediumRightNudgeU btnBigRightNudgeD 0.5 "beepOnce; post $DISP_BTN8_SIG 1" \
	"  " $backGroundColor

    # Pack nudge frame
    pack .ftop.sn.r1.nudges.l0 -side top -padx 0 -pady 0
    pack .ftop.sn.r1.nudges.r.left -side left -expand yes -fill y
    pack .ftop.sn.r1.nudges.r.toggle -side left -padx 3 -pady 0
    pack .ftop.sn.r1.nudges.r.right -side right -expand yes -fill y
    pack .ftop.sn.r1.nudges.r -side top -padx 1 -expand yes -fill both -pady 3 

    frame .ftop.sn.r1.isteercontrol -height 80 -background $backGroundColor
    #pack propagate .ftop.sn.r1.isteercontrol 0
    SnazzyBlendedButton::create .ftop.sn.r1.isteercontrol.disable btnExitKhakiSquareUp \
         btnExitKhakiSquareDown 0.5 \
        "beepOnce; post $DISP_BTN6_SIG 1" "Disable\nTracker" $backGroundColor
    pack .ftop.sn.r1.isteercontrol.disable -pady 8

    SnazzyBlendedButton::create .ftop.sn.r1.isteercontrol.enable btnBlueSquareUp \
         btnBlueSquareDown 0.5 \
        "beepOnce; post $DISP_BTN6_SIG 1" "Enable\nTracker" $backGroundColor


    # Nudge proxy frame and label
	# {2008/01/28 YB: This is used to display a message to the user, explaining
	# that the nudge widget isn't available for the current job type. Displayed
	# instead of the Nudge frame.}
    frame .ftop.sn.r1.nudgesProxy -height 80 -width 300 -background $backGroundColor
#    pack propagate .ftop.sn.r1.nudgesProxy 0
    label .ftop.sn.r1.nudgesProxy.note \
       -text "\nNudge Function Not Available\nin OFFSET CURVE Mode" \
       -font $medium_font -anchor c
	
	pack propagate .ftop.sn.r1.nudgesProxy 0; # {20080125 YB: This forces the frame to keep
		                                      #  it's size, even if it's slaves are bigger.}  
    #pack .ftop.sn.r1.nudgesProxy.note -side top -anchor n

	# Begin End/Pass frame and button widgets
	# {20080128 YB: This frame is not packed right away, it will only be if the job
	# is a MASTER_CURVE_JOB. In that case it is displayed instead of the nudge frame.}
	frame .ftop.sn.r1.beginEndPassFrame -bg $backGroundColor
	label .ftop.sn.r1.beginEndPassFrame.l0 -text "Begin/End Pass" -font $medium_font -bg $backGroundColor -height 1
	SnazzyButton::create .ftop.sn.r1.beginEndPassFrame.beginPassBtn \
	     btnBeginPassUp btnBeginPassDown 0.5 \
		"beepOnce; post $DISP_BTN7_SIG 0" "Begin Pass"
	SnazzyButton::setBackground .ftop.sn.r1.beginEndPassFrame.beginPassBtn $backGroundColor
	SnazzyButton::create .ftop.sn.r1.beginEndPassFrame.endPassBtn \
		 btnEndPassUp btnEndPassDown 0.5 \
		"beepOnce; post $DISP_BTN7_SIG 1" "End Pass"
	SnazzyButton::setBackground .ftop.sn.r1.beginEndPassFrame.endPassBtn $backGroundColor		
		
    # {20080128 YB: I don't know what this is.}
    #frame .ftop.sn.r1.idrive -height 90 -width 240
    #SnazzyButton::create .ftop.sn.idrive.engage btnBlueM4U \
    #   btnBlueM4D 0.5 "beepOnce; post $DISP_BTN2_SIG 10"
    #pack .ftop.sn.r1.idrive.engage -side top

    # Toggle Control 
    button .ftop.sn.r1.toggleControlBtn -text "Cycle Control" -font $btn_font \
       -command { beepOnce; post $DISP_BTN6_SIG 0 } \
       -width 200 -height 1 \
       -background $color7 -activebackground $color7 \
       -bd 2 -highlightthickness 0
#    SnazzyBlendedButton::create .ftop.sn.r1.toggleControlBtn btnBlueRectUp \
 \#        btnBlueRectDown 0.5 \
   \#     "beepOnce; post $DISP_BTN6_SIG 0" "Toggle\nControl" $backGroundColor

    frame .ftop.sn.r2.isteerstatus -height 120 -width 300  -background orange
    frame .ftop.sn.r2.isteerstatus.f  -background orange
    frame .ftop.sn.r2.isteerstatus.tb -height 1 -width 300 -background black
    frame .ftop.sn.r2.isteerstatus.t -height 15 -width 300 -background $backGroundColor
    frame .ftop.sn.r2.isteerstatus.b -height 2 -width 300 -background orange
    frame .ftop.sn.r2.isteerstatus.bb -height 1 -width 300 -background black
    pack .ftop.sn.r2.isteerstatus.bb -side bottom -anchor s  
    pack .ftop.sn.r2.isteerstatus.b -side bottom -anchor s  
    pack .ftop.sn.r2.isteerstatus.t -side top -anchor n 
    pack .ftop.sn.r2.isteerstatus.tb -side top -anchor n 
    pack .ftop.sn.r2.isteerstatus.f -side bottom -anchor s -pady 4 -padx 4 \
	   -expand yes -fill y

    # Pack .ftop.sn
    pack .ftop.sn.r1.nudges -side top -pady 0 -anchor n -expand yes -fill both
    pack .ftop.sn.r1.sliders -side top -pady 0
    pack .ftop.sn.r1.toggleControlBtn -side bottom -anchor s -fill x -pady 5
    pack .ftop.sn.r1 -side top -padx 1
    pack .ftop.sn.r2 -side top -padx 1 -expand yes -fill x
#    pack .ftop.sn.r2.isteerstatus

    #{20080128 YB: I don't know what this is.}
    # CPU loading frame
    frame .ftop.cpuload
    label .ftop.cpuload.t -text "CPU Loading" -font $small_font
    label .ftop.cpuload.l -text "No data yet" -font {6x13}
    #pack .ftop.cpuload.t -side top -anchor nw -padx 5 -pady 0
    pack .ftop.cpuload.l -side top -anchor nw -padx 5 -pady 5

    # Pan control frame and widgets
    frame .ftop.pan -bd 2 -relief groove
    label .ftop.pan.title -text "Pan and Zoom Mode:" \
       -font $medium_font -anchor w
    label .ftop.pan.note -text "Note:" \
       -font $medium_font -anchor c
    frame .ftop.pan.controls
    button .ftop.pan.controls.center -text "C" -font $btn_font \
       -command { beepOnce; post $DISP_BTN8_SIG 10 } \
       -width 3 -height 3 \
       -background $color7 -activebackground $color7 \
       -bd 2
    button .ftop.pan.controls.west -text "W" -font $btn_font \
       -command { beepOnce; post $DISP_BTN8_SIG 11 } \
       -width 3 -height 3 \
       -background $color7 -activebackground $color7 \
       -bd 2
    button .ftop.pan.controls.east -text "E" -font $btn_font \
       -command { beepOnce; post $DISP_BTN8_SIG 12 } \
       -width 3 -height 3 \
       -background $color7 -activebackground $color7 \
       -bd 2
    button .ftop.pan.controls.north -text "N" -font $btn_font \
       -command { beepOnce; post $DISP_BTN8_SIG 13 } \
       -width 3 -height 2 \
       -background $color7 -activebackground $color7 \
       -bd 2
    button .ftop.pan.controls.south -text "S" -font $btn_font \
       -command { beepOnce; post $DISP_BTN8_SIG 14 } \
       -width 3 -height 2 \
       -background $color7 -activebackground $color7 \
       -bd 2

    pack .ftop.pan.title -side top -fill x -padx 5 -pady 5 
    pack .ftop.pan.note -side bottom -fill x -padx 5 -pady 5 
    pack .ftop.pan.controls.north -side top
    pack .ftop.pan.controls.south -side bottom
    pack .ftop.pan.controls.west -side left
    pack .ftop.pan.controls.center -side left -fill both
    pack .ftop.pan.controls.east -side right
    pack .ftop.pan.controls -side top -padx 5 -pady 5 -anchor c

    # Input frame
#    frame .ftop.input
    frame .ftop.input1 -background $backGroundColor 
    frame .ftop.input2 -background $backGroundColor
    frame .ftop.input2.row1 -background $backGroundColor
    frame .ftop.input2.row1.left -background $backGroundColor
    frame .ftop.input2.row1.right -background $backGroundColor
    frame .ftop.input2.row2 -background $backGroundColor

    SnazzyBlendedButton::create .ftop.input1.cancel btnExitKhakiSquareUp \
         btnExitKhakiSquareDown 0.5 \
        "beepOnce; post $DISP_BTN9_SIG 9" "Exit" $backGroundColor

    # Open/Close menu buttons
    SnazzyBlendedButton::create .ftop.input1.menuOpen btnBlueSquareUp \
         btnBlueSquareDown 0.5 \
        "beepOnce; post $DISP_BTN2_SIG 1" "Menu" $backGroundColor
    SnazzyBlendedButton::create .ftop.input1.menuClose btnExitKhakiSquareUp \
         btnExitKhakiSquareDown 0.5 \
        "beepOnce; post $DISP_BTN2_SIG 0" "Close\nMenu" $backGroundColor

    SnazzyBlendedButton::create .ftop.input2.row1.left.endPass btnEndPassUp \
         btnEndPassDown 0.5 \
        "beepOnce; post $DISP_BTN7_SIG 1" "Engage I-Drive" $backGroundColor
    SnazzyBlendedButton::create .ftop.sn.r1.engageIdrive btnBlueM4U btnBlueM4D 0.5 \
        "beepOnce; post $DISP_BTN2_SIG 10" "Disengage I-Drive" $backGroundColor
    
	# Toggle Coverage label and button
	label .ftop.input2.row1.left.toggleCoverageLabel -text "Coverage OFF" \
	-font $medium_font -background $backGroundColor -anchor n
	SnazzyButton::create .ftop.input2.row1.left.toggleCoverageOffBtn \
	   btnToggleOff btnToggleOff 0.5 \
	   "beepOnce; post $DISP_CANVAS1_SIG 0" "Toggle\nCoverage"
	SnazzyButton::setBackground .ftop.input2.row1.left.toggleCoverageOffBtn $backGroundColor
	SnazzyButton::create .ftop.input2.row1.left.toggleCoverageOnBtn \
	   btnToggleOn btnToggleOn 0.5 \
	   "beepOnce; post $DISP_CANVAS1_SIG 1" "Toggle\nCoverage"
	SnazzyButton::setBackground .ftop.input2.row1.left.toggleCoverageOnBtn $backGroundColor		
    
    # STOP/GO buttons
    SnazzyBlendedButton::create .ftop.input2.row1.right.stop btnBigStopU \
         btnBigStopD 0.5 \
        "beepOnce; post $DISP_BTN0_SIG 0" " " $backGroundColor
    SnazzyBlendedButton::create .ftop.input2.row1.right.go btnBigGoU \
         btnBigGoD 0.5 \
        "beepOnce; post $DISP_BTN0_SIG 1" " " $backGroundColor
        
    # Data Frame
    frame .ftop.data
    frame .ftop.data.position
    frame .ftop.data.areahours
    frame .ftop.data.distance
    
    # Vehicle Position
    label .ftop.data.position.title -text "Position" -font $medium_font
    label .ftop.data.position.divider -image imgDividerDash
    label .ftop.data.position.latTxt -text "Lat:" -font $small_font
    label .ftop.data.position.lonTxt -text "Lon:" -font $small_font
    label .ftop.data.position.altTxt -text "Alt:" -font $small_font
    label .ftop.data.position.lat -text "0.00" -font $small_font
    label .ftop.data.position.lon -text "0.00" -font $small_font
    label .ftop.data.position.alt -text "0.00" -font $small_font
    
    # Amount of AutoFarm Hours / Area
    label .ftop.data.areahours.title -text "Autofarm Hours / Area" -font $medium_font
    label .ftop.data.areahours.divider -image imgDividerDash
    label .ftop.data.areahours.areaTxt -text "Area:" -font $small_font
    label .ftop.data.areahours.hourTxt -text "Hours:" -font $small_font
    label .ftop.data.areahours.area -text "0.00" -font $small_font
    label .ftop.data.areahours.hour -text "0.00" -font $small_font
    
    # Distance from Base Station
    label .ftop.data.distance.title -text "Distance to Base" -font $medium_font
    label .ftop.data.distance.divider -image imgDividerDash
    label .ftop.data.distance.distanceTxt -text "Distance:" -font $small_font
    label .ftop.data.distance.distance -text "0.00" -font $small_font
    
    # Pack Data Display
    # Position
    pack .ftop.data.position.title -side top -anchor nw
    pack .ftop.data.position.divider -side top 
    pack .ftop.data.position.latTxt -side left
    pack .ftop.data.position.lat -side left
    pack .ftop.data.position.lonTxt -side left
    pack .ftop.data.position.lon -side left
    pack .ftop.data.position.altTxt -side left
    pack .ftop.data.position.alt -side left
    
    # Autofarm Hours / Acres
    pack .ftop.data.areahours.title -side top -anchor nw
    pack .ftop.data.areahours.divider -side top 
    pack .ftop.data.areahours.areaTxt -side left
    pack .ftop.data.areahours.area -side left
    pack .ftop.data.areahours.hourTxt -side left
    pack .ftop.data.areahours.hour -side left
    
    # Distance to Base Station
    pack .ftop.data.distance.title -side top -anchor nw
    pack .ftop.data.distance.divider -side top
    pack .ftop.data.distance.distanceTxt -side left
    pack .ftop.data.distance.distance -side left
    
    # Pack Data Display Components
    pack .ftop.data.position -side top -pady 5
    pack .ftop.data.areahours -side top -pady 5
    pack .ftop.data.distance -side top -pady 5
    
    
    # Pack input frames
    pack .ftop.input1.cancel -side right -anchor ne
    pack .ftop.input1.menuOpen -side left -anchor nw

    pack .ftop.input2.row1.right.go -side right -anchor se -padx 2 -pady 2 -fill x
    pack .ftop.input2.row1.right -side right -anchor s -padx 0 -pady 0 \
                                 -fill x
    pack .ftop.input2.row1.left -side left -anchor sw -padx 0 -pady 0 -fill x \
                                -expand no
    pack .ftop.input2.row1.left.toggleCoverageLabel -side top		

    # Menu frames
    frame .ftop.menu -background $backGroundColor
    image create photo marrowfor -file ${tclPath}gif/menuarrowforward.gif
    image create photo marrowback -file ${tclPath}gif/menuarrowbackward.gif

    # Menu level 0 frame
    frame .ftop.menu.level0 -bd 1 -relief groove -background $backGroundColor
    frame .ftop.menu.level0.fl -width 100 -height 15 -background $backGroundColor 
    pack propagate .ftop.menu.level0.fl 0
    label .ftop.menu.level0.fl.l -text "Menu 0:" -font $medium_font -bg $backGroundColor

    frame .ftop.menu.level0.f0 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level0.f0 0
    button .ftop.menu.level0.f0.b0 -text "Button0" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 0 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $backGroundColor -activebackground $backGroundColor \
        -bd 2
    frame .ftop.menu.level0.f1 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level0.f1 0
    button .ftop.menu.level0.f1.b1 -text "Button1" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 1 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level0.f2 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level0.f2 0
    button .ftop.menu.level0.f2.b2 -text "Button2" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 2 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level0.f3 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level0.f3 0
    button .ftop.menu.level0.f3.b3 -text "Button3" -font $btn_font \
        -command { beepOnce; post $DISP_BTN3_SIG 3 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2

    # Menu level 1 frame
    frame .ftop.menu.level1 -bd 1 -relief groove -background $backGroundColor
    frame .ftop.menu.level1.fl -width 100 -height 15 -background $backGroundColor
    pack propagate .ftop.menu.level1.fl 0
    label .ftop.menu.level1.fl.l -text "Menu 1:" -font $medium_font -bg $backGroundColor
    label .ftop.menu.level1.m -image marrowfor

    frame .ftop.menu.level1.f0 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level1.f0 0
    button .ftop.menu.level1.f0.b0 -text "Button0" -font $btn_font \
        -command { beepOnce; post $DISP_BTN4_SIG 0 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level1.f1 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level1.f1 0
    button .ftop.menu.level1.f1.b1 -text "Button1" -font $medium_font \
        -command { beepOnce; post $DISP_BTN4_SIG 1 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level1.f2 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level1.f2 0
    button .ftop.menu.level1.f2.b2 -text "Button2" -font $medium_font \
        -command { beepOnce; post $DISP_BTN4_SIG 2 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level1.f3 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level1.f3 0
    button .ftop.menu.level1.f3.b3 -text "Button3" -font $btn_font \
        -command { beepOnce; post $DISP_BTN4_SIG 3 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2

    # Menu level 2 frame
    frame .ftop.menu.level2 -bd 1 -relief groove -background $backGroundColor
    frame .ftop.menu.level2.fl -width 100 -height 15 -background $backGroundColor
    pack propagate .ftop.menu.level2.fl 0
    label .ftop.menu.level2.fl.l -text "Menu 2:" -font $medium_font -bg $backGroundColor

    frame .ftop.menu.level2.f0 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level2.f0 0
    button .ftop.menu.level2.f0.b0 -text "Button0" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 0 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level2.f1 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level2.f1 0
    button .ftop.menu.level2.f1.b1 -text "Button1" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 1 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level2.f2 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level2.f2 0
    button .ftop.menu.level2.f2.b2 -text "Button2" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 2 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2
    frame .ftop.menu.level2.f3 -width 100 -height 60 -background $backGroundColor
    pack propagate .ftop.menu.level2.f3 0
    button .ftop.menu.level2.f3.b3 -text "Button3" -font $btn_font \
        -command { beepOnce; post $DISP_BTN5_SIG 3 } \
        -compound center -image "" \
        -width 100 -height 60 \
        -background $color7 -activebackground $color7 \
        -bd 2

    # CheckButton Menu
    frame .ftop.cbm -bd 1 -relief groove
    label .ftop.cbm.title -text "Select an Option:" -font $medium_font -anchor w
    checkbutton .ftop.cbm.b0 -text "Option 1" -height 2 -anchor w
    checkbutton .ftop.cbm.b1 -text "Option 2" -height 2 -anchor w
    checkbutton .ftop.cbm.b2 -text "Option 3" -height 2 -anchor w
    checkbutton .ftop.cbm.b3 -text "Option 4" -height 2 -anchor w
    checkbutton .ftop.cbm.b4 -text "Option 5" -height 2 -anchor w
    checkbutton .ftop.cbm.b5 -text "Option 6" -height 2 -anchor w

    # Pack screen
    pack .ftop.curve -side left -anchor e -fill both
    pack .ftop.input1 -side top -anchor nw -fill both -padx 1
    #pack .ftop.data -side top -anchor n -fill both -expand yes -pady 3
    #pack .ftop.sn -side top -padx 1 -pady 0 -fill x -anchor n
    pack .ftop.input2.row1 -side bottom -anchor s  -padx 0 -pady 1 -expand yes -fill both
    pack .ftop.input2 -side bottom -anchor s -padx 2 -pady 0 -expand yes -fill both
    pack .ftop.sn -side bottom -padx 1 -pady 0  -anchor n -expand yes -fill both



    
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {} {
        pack .glCurveDisp -in .ftop.curve.f -side bottom \
           -anchor s -padx 5 -pady 2
        raise .glCurveDisp
        pack .ftop -fill both -expand yes
    }
    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr
    proc actConfigISteer {} {
	actConfigISteerPassive
        pack .glImplementStatusDisp -in .ftop.sn.r2.isteerstatus.f -side bottom \
            -anchor s
        raise .glImplementStatusDisp
	pack .ftop.sn.r2.isteerstatus -expand yes -fill x
    }

    proc actConfigISteerActive {} {
        set frameColor "LimeGreen"
	.ftop.sn.r2.isteerstatus.f  configure -background $frameColor
	.ftop.sn.r2.isteerstatus  configure -background $frameColor
    }

    proc actConfigISteerPassive {} {
        global target_platform
        set frameColor "orange"
        if { $target_platform == "A5"} {
            set frameColor #00A5FF  
        }
	.ftop.sn.r2.isteerstatus.f  configure -background $frameColor
	.ftop.sn.r2.isteerstatus  configure -background $frameColor
    }

    proc actConfigISteerError {} {
        global target_platform
        set frameColor "red"
        if { $target_platform == "A5"} {
            set frameColor #0000FF  
        }
	.ftop.sn.r2.isteerstatus.f  configure -background $frameColor
	.ftop.sn.r2.isteerstatus  configure -background $frameColor
    }
    

    proc actConfigureInitial { manualLbl manualSteeringText \
                               toggleControlBtnTxt panzoom__ normalmode__
                               inAuto__ menuopen__ menuclose__ cancel__ 
			       togglenudge__ } {
        global huge_font
	global color10
        pack forget .ftop.input2.row1.right.stop
        pack .ftop.input2.row1.right.go -side bottom -anchor se
        .ftop.input2.row1.right.go configure -state disabled
        .ftop.sn.r1.toggleControlBtn configure -text $toggleControlBtnTxt 
	.ftop.input1.menuOpen configure -text $menuopen__
	.ftop.input1.menuClose configure -text $menuclose__
	.ftop.input1.cancel configure -text $cancel__
	.ftop.sn.r1.nudges.r.toggle configure -text $togglenudge__
        actConfigureHeader $manualLbl $huge_font $color10
        actConfigureZoomBtns $panzoom__ $normalmode__ $inAuto__
    }

    proc actEnableGoBtn { } {
        .ftop.input2.row1.right.go configure -state normal
    }
    
    proc actDisableGoBtn { } {
        .ftop.input2.row1.right.go configure -state disabled
    }
    
    proc actConfigureRowlineup { manualLbl manualSteeringText \
                                 panzoom__ normalmode__ inAuto__} {
        global huge_font
        pack forget .ftop.input2.row1.right.stop
        pack .ftop.input2.row1.right.go -side bottom -anchor se
        .ftop.input2.row1.right.go configure -state normal
        
		actConfigureHeader $manualLbl $huge_font orange
        actConfigureZoomBtns $panzoom__ $normalmode__ $inAuto__
    }

    proc actConfigureAutosteer { autoLbl panzoom__ normalmode__ inAuto__} {
        global huge_font
        pack forget .ftop.input2.row1.right.go
        pack .ftop.input2.row1.right.stop -side bottom -anchor se

        actConfigureHeader $autoLbl $huge_font LimeGreen
        actConfigureZoomBtns $panzoom__ $normalmode__ $inAuto__
    }

    proc actConfigurePanAndZoom { pnzLbl manualSteeringText \
                                  title__ note__ panzoom__ normalmode__ \
                                  inAuto__} {
        global huge_font
        pack forget \
            .ftop.input2.row1.right.stop \
            .ftop.input2.row1.right.go \
            .ftop.input2.row1.left.beginPass \
            .ftop.input1.menuOpen \
            .ftop.sn \
            .ftop.cpuload

        .ftop.pan.title configure -text $title__
        .ftop.pan.note configure -text $note__
        pack .ftop.pan -side top -padx 5 -pady 5 -fill both -expand yes
        actConfigureHeader $pnzLbl $huge_font orange
        actConfigureZoomBtns $panzoom__ $normalmode__ $inAuto__
    }

    proc actConfigureHeader { text__ font__ color__ } {
      global huge_font big_font target_platform
      
      #RCM: 060221 Added platform awareness to TCL to fix RGB color 
      #     swapping problem.  TCL on the MPC5200 platform seems to swap
      #     the RGB values causing orange and red to be displayed as blue
      #     instead of the intended color.  This fix is intended to be
      #     temporary and eventually will need to be fixed once the 
      #     undelying TCL error is resolved.  This fix has also been 
      #     implemented in msbox.tcl
      set frameColor $color__ 
      if { $target_platform == "A5"} {
        if { $color__ == "orange"} {
          set frameColor #00A5FF
        }
        if { $color__ == "red"} {
          set frameColor #0000FF  
        } 
      }
      
      .ftop.curve.f configure -background $frameColor
      .ftop.curve configure -background $frameColor
      eval {.ftop.curve.header.l1 configure -text $text__ -font} $font__ \
           {-background $color__}
      .ftop.curve.header configure -background $frameColor
      .ftop.curve.header.zoomout configure -background $color__ \
                                           -activebackground $color__
      .ftop.curve.header.zoomin configure  -background $color__ \
                                           -activebackground $color__
      # Configure zoom in/out button color by changing image
      switch $color__ {
        "orange" {
          .ftop.curve.header.zoomout configure -image zoomout
          .ftop.curve.header.zoomin configure  -image zoomin 
        }
        "LimeGreen" {
          .ftop.curve.header.zoomout configure -image zoomoutGrn
          .ftop.curve.header.zoomin configure  -image zoominGrn
        }
        "red" {
          .ftop.curve.header.zoomout configure -image zoomoutRed
          .ftop.curve.header.zoomin configure  -image zoominRed
        }
      }
    }

    proc actConfigureZoomBtns { panzoom__ normalmode__ inAuto__} {
      if { $panzoom__ == 1} {
        if {$inAuto__ == 1} {
          .ftop.curve.header.zoomout configure -image panandzoomGrn
        }
        if {$inAuto__ == 0} {
          .ftop.curve.header.zoomout configure -image panandzoom
        }
      } 
      if { $panzoom__ == 0} {
        if {$inAuto__ == 1} {
          .ftop.curve.header.zoomout configure -image zoomoutGrn
        }
        if {$inAuto__ == 0} {
          .ftop.curve.header.zoomout configure -image zoomout
        }
      }
      if { $normalmode__ == 1} {
        if {$inAuto__ == 1} {
          .ftop.curve.header.zoomin configure -image normalmodeGrn
        }
        if {$inAuto__ == 0} {
          .ftop.curve.header.zoomin configure -image normalmode 
        }
      } 
      if { $normalmode__ == 0} {
        if {$inAuto__ == 1} {  
          .ftop.curve.header.zoomin configure -image zoominGrn
        }
        if {$inAuto__ == 0} {
          .ftop.curve.header.zoomin configure -image zoomin
        }
      }
    }

    proc actConfigureMenu {} {
        pack forget \
            .ftop.input1.menuOpen \
            .ftop.sn \
            .ftop.cpuload \
            .ftop.cbm \
            .ftop.pan
        pack .ftop.input1.menuClose -side left -anchor sw -padx 0 -pady 0
        pack .ftop.menu -side top -pady 0 -fill both -expand yes
    }

    proc actConfigureNoMenu {} {
        pack forget \
            .ftop.input1.menuClose \
            .ftop.menu \
            .ftop.menu.level0 \
            .ftop.menu.level1 \
            .ftop.menu.level2 \
            .ftop.cbm \
            .ftop.pan
        pack .ftop.sn -side top -pady 10 -fill both -expand yes
        pack .ftop.input1.menuOpen -side left -anchor sw -padx 0 -pady 0
        actUnHighlightMenuLevel 0
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureCheckButtonMenu { title__ \
                                           b0__ b0Id__ b0State__ \
                                           b1__ b1Id__ b1State__ \
                                           b2__ b2Id__ b2State__ \
                                           b3__ b3Id__ b3State__ \
                                           b4__ b4Id__ b4State__ \
                                           b5__ b5Id__ b5State__ } {
        pack forget \
            .ftop.menu .ftop.menu.level0 .ftop.menu.level1 .ftop.menu.level2 \
            .ftop.cbm.b0 .ftop.cbm.b1 .ftop.cbm.b2 \
            .ftop.cbm.b3 .ftop.cbm.b4 .ftop.cbm.b5

        .ftop.cbm.title configure -text $title__
        pack .ftop.cbm.title -side top -fill x -padx 5 -pady 5 

        if {$b0__ != "!"} {
            .ftop.cbm.b0 configure -text $b0__ \
                -command "beepOnce; post \$DISP_BTN6_SIG $b0Id__"
            if {$b0State__ == 1} {
                .ftop.cbm.b0 select
            } else {
                .ftop.cbm.b0 deselect
            }
            pack .ftop.cbm.b0 -side top -fill x -padx 5 -pady 5
        }
        if {$b1__ != "!"} {
            .ftop.cbm.b1 configure -text $b1__ \
                -command "beepOnce; post \$DISP_BTN6_SIG $b1Id__"
            if {$b1State__ == 1} {
                .ftop.cbm.b1 select
            } else {
                .ftop.cbm.b1 deselect
            }
            pack .ftop.cbm.b1 -side top -fill x -padx 5 -pady 5
        }
        if {$b2__ != "!"} {
            .ftop.cbm.b2 configure -text $b2__ \
                -command "beepOnce; post \$DISP_BTN6_SIG $b2Id__"
            if {$b2State__ == 1} {
                .ftop.cbm.b2 select
            } else {
                .ftop.cbm.b2 deselect
            }
            pack .ftop.cbm.b2 -side top -fill x -padx 5 -pady 5
        }
        if {$b3__ != "!"} {
            .ftop.cbm.b3 configure -text $b3__ \
                -command "beepOnce; post \$DISP_BTN6_SIG $b3Id__"
            if {$b3State__ == 1} {
                .ftop.cbm.b3 select
            } else {
                .ftop.cbm.b3 deselect
            }
            pack .ftop.cbm.b3 -side top -fill x -padx 5 -pady 5
        }
        if {$b4__ != "!"} {
            .ftop.cbm.b4 configure -text $b4__ \
                -command "beepOnce; post \$DISP_BTN6_SIG $b4Id__"
            if {$b4State__ == 1} {
                .ftop.cbm.b4 select
            } else {
                .ftop.cbm.b4 deselect
            }
            pack .ftop.cbm.b4 -side top -fill x -padx 5 -pady 5
        }
        if {$b5__ != "!"} {
            .ftop.cbm.b5 configure -text $b5__ \
                -command "beepOnce; post \$DISP_BTN6_SIG $b5Id__"
            if {$b5State__ == 1} {
                .ftop.cbm.b5 select
            } else {
                .ftop.cbm.b5 deselect
            }
            pack .ftop.cbm.b5 -side top -fill x -padx 5 -pady 5
        }

        pack .ftop.cbm -side top -padx 5 -pady 5 -fill both -expand yes
    }

    proc actConfigureCpuLoad {} {
        pack forget .ftop.input1.menuClose \
            .ftop.menu .ftop.menu.level0 .ftop.menu.level1 .ftop.menu.level2
        pack .ftop.cpuload -side top -fill both -expand yes -pady 10
        pack .ftop.input1.menuOpen -side left -anchor sw -padx 0 -pady 0
        actUnHighlightMenuLevel 0
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureMenuLevel0 { title__ \
                                      b0__ b0Id__ b0Hi__ \
                                      b1__ b1Id__ b1Hi__ \
                                      b2__ b2Id__ b2Hi__ \
                                      b3__ b3Id__ b3Hi__ } {

        global color5 color7 color9
        pack forget \
            .ftop.menu.level1 \
            .ftop.menu.level0.l \
            .ftop.menu.level0.fl \
            .ftop.menu.level0.f0 \
            .ftop.menu.level0.f1 \
            .ftop.menu.level0.f2 \
            .ftop.menu.level0.f3 \
            .ftop.menu.level0.f0.b0 \
            .ftop.menu.level0.f1.b1 \
            .ftop.menu.level0.f2.b2 \
            .ftop.menu.level0.f3.b3

        .ftop.menu.level0.fl.l configure -text $title__
        pack .ftop.menu.level0.fl -side top -anchor n
        pack .ftop.menu.level0.fl.l -side top -anchor n

        if {$b0__ != "!"} {
            .ftop.menu.level0.f0.b0 configure -text $b0__ \
                -command "beepOnce; post \$DISP_BTN3_SIG $b0Id__" \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b0Id__ == 0} {
                .ftop.menu.level0.f0.b0 configure -state disabled \
                    -background $color9
            }
            if {$b0Hi__ >= 1} {
                .ftop.menu.level0.f0.b0 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f0 -side top -anchor n
            pack .ftop.menu.level0.f0.b0 -side left -padx 2 -pady 5
        }
        if {$b1__ != "!"} {
            .ftop.menu.level0.f1.b1 configure -text $b1__ \
                -command " beepOnce; post \$DISP_BTN3_SIG $b1Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b1Id__ == 0} {
                .ftop.menu.level0.f1.b1 configure -state disabled \
                    -background $color9
            }
            if {$b1Hi__ >= 1} {
                .ftop.menu.level0.f1.b1 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f1 -side top -anchor n
            pack .ftop.menu.level0.f1.b1 -side left -padx 2 -pady 5
        }
        if {$b2__ != "!"} {
            .ftop.menu.level0.f2.b2 configure -text $b2__ \
                -command " beepOnce; post \$DISP_BTN3_SIG $b2Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b2Id__ == 0} {
                .ftop.menu.level0.f2.b2 configure -state disabled \
                    -background $color9
            }
            if {$b2Hi__ >= 1} {
                .ftop.menu.level0.f2.b2 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f2 -side top -anchor n
            pack .ftop.menu.level0.f2.b2 -side left -padx 2 -pady 5
        }
        if {$b3__ != "!"} {
            .ftop.menu.level0.f3.b3 configure -text $b3__ \
                -command " beepOnce; post \$DISP_BTN3_SIG $b3Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b3Id__ == 0} {
                .ftop.menu.level0.f3.b3 configure -state disabled \
                    -background $color9
            }
            if {$b3Hi__ >= 1} {
                .ftop.menu.level0.f3.b3 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level0.f3 -side top -anchor n
            pack .ftop.menu.level0.f3.b3 -side left -padx 2 -pady 5
        }

        pack .ftop.menu.level0 -side right -padx 5 -pady 5 -anchor nw

        # MLE-040130: Cheating; this should be done in C side
        global level0list
        set level0list \
            [list \
                 "$b0Id__ .ftop.menu.level0.f0 .ftop.menu.level0.f0.b0" \
                 "$b1Id__ .ftop.menu.level0.f1 .ftop.menu.level0.f1.b1" \
                 "$b2Id__ .ftop.menu.level0.f2 .ftop.menu.level0.f2.b2" \
                 "$b3Id__ .ftop.menu.level0.f3 .ftop.menu.level0.f3.b3" ]
    }

    proc actConfigureMenuLevel1 { title__ \
                                      b0__ b0Id__ b0Hi__ \
                                      b1__ b1Id__ b1Hi__ \
                                      b2__ b2Id__ b2Hi__ \
                                      b3__ b3Id__ b3Hi__} {

        global color5 color7 color9
        pack forget \
            .ftop.menu.level0 \
            .ftop.menu.level2 \
            .ftop.menu.level1.l \
            .ftop.menu.level1.fl \
            .ftop.menu.level1.f0 \
            .ftop.menu.level1.f1 \
            .ftop.menu.level1.f2 \
            .ftop.menu.level1.f3 \
            .ftop.menu.level1.f0.b0 \
            .ftop.menu.level1.f1.b1 \
            .ftop.menu.level1.f2.b2 \
            .ftop.menu.level1.f3.b3

        .ftop.menu.level1.fl.l configure -text $title__
        pack .ftop.menu.level1.fl -side top -anchor n
        pack .ftop.menu.level1.fl.l -side top -anchor n

        if {$b0__ != "!"} {
            .ftop.menu.level1.f0.b0 configure -text $b0__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b0Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b0Id__ == 0} {
                .ftop.menu.level1.f0.b0 configure -state disabled \
                    -background $color9
            }
            if {$b0Hi__ >= 1} {
                .ftop.menu.level1.f0.b0 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f0 -side top -anchor n
            pack .ftop.menu.level1.f0.b0 -side left -padx 2 -pady 5
        }
        if {$b1__ != "!"} {
            .ftop.menu.level1.f1.b1 configure -text $b1__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b1Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b1Id__ == 0} {
                .ftop.menu.level1.f1.b1 configure -state disabled \
                    -background $color9
            }
            if {$b1Hi__ >= 1} {
                .ftop.menu.level1.f1.b1 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f1 -side top -anchor n
            pack .ftop.menu.level1.f1.b1 -side left -padx 2 -pady 5
        }
        if { $b2__ != "!" } {
            .ftop.menu.level1.f2.b2 configure -text $b2__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b2Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b2Id__ == 0} {
                .ftop.menu.level1.f2.b2 configure -state disabled \
                    -background $color9
            }
            if {$b2Hi__ >= 1} {
                .ftop.menu.level1.f2.b2 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f2 -side top -anchor n
            pack .ftop.menu.level1.f2.b2 -side left -padx 2 -pady 5
        }
        if { $b3__ != "!" } {
            .ftop.menu.level1.f3.b3 configure -text $b3__ \
                -command " beepOnce; post \$DISP_BTN4_SIG $b3Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b3Id__ == 0} {
                .ftop.menu.level1.f3.b3 configure -state disabled \
                    -background $color9
            }
            if {$b3Hi__ >= 1} {
                .ftop.menu.level1.f3.b3 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level1.f3 -side top -anchor n
            pack .ftop.menu.level1.f3.b3 -side left -padx 2 -pady 5
        }

        pack .ftop.menu.level1 -side right -padx 5 -pady 5 -anchor nw
        pack .ftop.menu.level0 -side left -padx 5 -pady 5 -anchor nw

        # MLE-040130: Cheating; this should be done in C side
        global level1list
        set level1list \
            [list \
                 "$b0Id__ .ftop.menu.level1.f0 .ftop.menu.level1.f0.b0" \
                 "$b1Id__ .ftop.menu.level1.f1 .ftop.menu.level1.f1.b1" \
                 "$b2Id__ .ftop.menu.level1.f2 .ftop.menu.level1.f2.b2" \
                 "$b3Id__ .ftop.menu.level1.f3 .ftop.menu.level1.f3.b3" ]
    }

    proc actConfigureMenuLevel2 { title__ \
                                      b0__ b0Id__ b0Hi__ \
                                      b1__ b1Id__ b1Hi__ \
                                      b2__ b2Id__ b2Hi__ \
                                      b3__ b3Id__ b3Hi__ } {

        global color5 color7 color9
        pack forget \
            .ftop.menu.level1 \
            .ftop.menu.level2.l \
            .ftop.menu.level2.fl \
            .ftop.menu.level2.f0 \
            .ftop.menu.level2.f1 \
            .ftop.menu.level2.f2 \
            .ftop.menu.level2.f3 \
            .ftop.menu.level2.f0.b0 \
            .ftop.menu.level2.f1.b1 \
            .ftop.menu.level2.f2.b2 \
            .ftop.menu.level2.f3.b3

        .ftop.menu.level2.fl.l configure -text $title__
        pack .ftop.menu.level2.fl -side top -anchor n
        pack .ftop.menu.level2.fl.l -side top -anchor n

        if {$b0__ != "!"} {
            .ftop.menu.level2.f0.b0 configure -text $b0__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b0Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b0Id__ == 0} {
                .ftop.menu.level2.f0.b0 configure -state disabled \
                    -background $color9
            }
            if {$b0Hi__ >= 1} {
                .ftop.menu.level2.f0.b0 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f0 -side top -anchor n
            pack .ftop.menu.level2.f0.b0 -side left -padx 2 -pady 5
        }
        if {$b1__ != "!"} {
            .ftop.menu.level2.f1.b1 configure -text $b1__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b1Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b1Id__ == 0} {
                .ftop.menu.level2.f1.b1 configure -state disabled \
                    -background $color9
            }
            if {$b1Hi__ >= 1} {
                .ftop.menu.level2.f1.b1 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f1 -side top -anchor n
            pack .ftop.menu.level2.f1.b1 -side left -padx 2 -pady 5
        }
        if {$b2__ != "!"} {
            .ftop.menu.level2.f2.b2 configure -text $b2__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b2Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b2Id__ == 0} {
                .ftop.menu.level2.f2.b2 configure -state disabled \
                    -background $color9
            }
            if {$b2Hi__ >= 1} {
                .ftop.menu.level2.f2.b2 configure \
                -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f2 -side top -anchor n
            pack .ftop.menu.level2.f2.b2 -side left -padx 2 -pady 5
        }
        if {$b3__ != "!"} {
            .ftop.menu.level2.f3.b3 configure -text $b3__ \
                -command " beepOnce; post \$DISP_BTN5_SIG $b3Id__ " \
                -state normal -image "" \
                -background $color7 -activebackground $color7
            if {$b3Id__ == 0} {
                .ftop.menu.level2.f3.b3 configure -state disabled \
                    -background $color9
            }
            if {$b3Hi__ >= 1} {
                .ftop.menu.level2.f3.b3 configure \
                    -background $color5 -activebackground $color5
            }
            pack .ftop.menu.level2.f3 -side top -anchor n
            pack .ftop.menu.level2.f3.b3 -side left -padx 2 -pady 5
        }
        
        pack .ftop.menu.level2 -side left -padx 5 -pady 5 -anchor nw
        
        # MLE-040130: Cheating; this should be done in C side
        global level2list
        set level2list \
            [list \
                 "$b0Id__ .ftop.menu.level2.f0 .ftop.menu.level2.f0.b0" \
                 "$b1Id__ .ftop.menu.level2.f1 .ftop.menu.level2.f1.b1" \
                 "$b2Id__ .ftop.menu.level2.f2 .ftop.menu.level2.f2.b2" \
                 "$b3Id__ .ftop.menu.level2.f3 .ftop.menu.level2.f3.b3" ]
    }

    proc actConfigureMenuLevel0Only { } {

        pack forget \
            .ftop.menu.level0 \
            .ftop.menu.level1 \
            .ftop.menu.level2 
        pack .ftop.menu.level0 -side left -anchor nw -padx 5 -pady 5
        actUnHighlightMenuLevel 0
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureMenuLevel01Only { } {

        pack forget \
            .ftop.menu.level0 \
            .ftop.menu.level1 \
            .ftop.menu.level2 
        pack .ftop.menu.level0 -side left -anchor nw -padx 5 -pady 5
        pack .ftop.menu.level1 -side left -anchor nw -padx 5 -pady 5
        actUnHighlightMenuLevel 1
        actUnHighlightMenuLevel 2
    }

    proc actConfigureMenuBtn { level__ btn__ text__ id__ arrow__ } {
        set sigNum [expr 3 + $level__]
        .ftop.menu.level$level__.f$btn__.b$btn__ configure -text $text__ \
            -command " beepOnce; post \$DISP_BTN${sigNum}_SIG $id__ "
        if {$arrow__ == 0} {
            .ftop.menu.level$level__.f$btn__.b$btn__ configure -image ""
        } elseif {$arrow__ == 1} {
            .ftop.menu.level$level__.f$btn__.b$btn__ \
                configure -image marrowfor
        } elseif {$arrow__ == 2} {
            .ftop.menu.level$level__.f$btn__.b$btn__ \
                configure -image marrowback
        }
    }

    proc actHighlightLevel0MenuBtn { btnId__ highlight__ } {
        global level0list color8 color10
        actUnHighlightMenuLevel 0
        foreach e $level0list {
            if {[lindex $e 0] == $btnId__} {
                if {$highlight__ > 0} {
                    [lindex $e 2] configure -background $color8 \
                        -activebackground $color8
                }
                if {$highlight__ == 2} {
                    [lindex $e 2] configure -image marrowfor
                } elseif {$highlight__ == 3} {
                    [lindex $e 2] configure -image marrowback
                }
            }
        }
    }

    proc actHighlightLevel1MenuBtn { btnId__ highlight__ } {
        global level1list color8
        #actUnHighlightMenuLevel 1
        foreach e $level1list {
            if {[lindex $e 0] == $btnId__} {
                if {$highlight__ > 0} {
                    [lindex $e 2] configure -background $color8 \
                        -activebackground $color8
                }
                if {$highlight__ == 2} {
                    [lindex $e 2] configure -image marrowfor
                } elseif {$highlight__ == 3} {
                    [lindex $e 2] configure -image marrowback
                }
            }
        }
    }

    proc actHighlightLevel2MenuBtn { btnId__ highlight__ } {
        global level2list color8
        #actUnHighlightMenuLevel 2
        foreach e $level2list {
            if {[lindex $e 0] == $btnId__} {
                if {$highlight__ > 0} {
                    [lindex $e 2] configure -background $color8 \
                        -activebackground $color8
                }
                if {$highlight__ == 2} {
                    [lindex $e 2] configure -image marrowfor
                } elseif {$highlight__ == 3} {
                    [lindex $e 2] configure -image marrowback
                }
            }
        }
    }

    proc actUnHighlightMenuLevel { level__ } {
        global color7
        foreach ii [list 0 1 2 3] {
            if {[.ftop.menu.level$level__.f$ii.b$ii cget -state] != "disabled"} {
                .ftop.menu.level$level__.f$ii.b$ii configure \
                    -background $color7 -activebackground $color7 -image ""
            }
        }
    }

    proc actConfigureSecondSlider { sliderNum } {
        pack .s$sliderNum -in .ftop.sn.r1.sliders -side top \
            -fill both -expand yes
        raise .s$sliderNum
	    Sliders::sliderConfigureBackground .s$sliderNum $backGroundColor
    }

    proc actConfigureISteerSlider { sliderNum } {
        pack .s$sliderNum -in .ftop.sn.r1.sliders -side top \
            -fill both -expand yes
        raise .s$sliderNum
	    Sliders::sliderConfigureBackground .s$sliderNum $backGroundColor
    }
    
    proc actConfigISteer {} {
	   pack .glImplementStatusDisp -in .ftop.sn.r2.isteerstatus.f -side bottom \
	      -anchor s -pady 5
	   raise .glImplementStatusDisp
	   pack .ftop.sn.r2.isteerstatus
	}		
		
    proc actConfigureImplementDrive { text } { 
        pack .ftop.sn.r1.engageIdrive -side bottom
        SnazzyBlendedButton::setText .ftop.sn.r1.engageIdrive $text 0.5
    }
    
    proc actConfigureImplementDriveText {  } {
        
    }
    
    proc actPackBeginEndPass { passlabel } {
	   # {20080128 YB: Forget nudge or nudge proxy frames.}	
	   pack forget .ftop.sn.r1.nudgesProxy .ftop.sn.r1.nudges

	   # {20080128 YB: Pack the begin/end pass frame and widget.}
       pack .ftop.sn.r1.beginEndPassFrame -side top -fill both -pady 0 -expand yes -anchor n
	   
	   # pack the label children after, otherwise the "side" attribute won't work (packing order is important)
	   pack .ftop.sn.r1.beginEndPassFrame.l0 -side top -anchor center -padx 5 -pady 0		
	   .ftop.sn.r1.beginEndPassFrame.l0 configure -text $passlabel
    }
    
    proc actForgetBeginEndPass {} {
	  pack forget .ftop.sn.r1.beginEndPassFrame   	
    }
		
    proc actPackNudgeProxy {} {
        pack forget .ftop.sn.r1.nudges .ftop.sn.r1.nudgesProxy
	pack forget .ftop.sn.r1.isteercontrol
        pack .ftop.sn.r1.nudgesProxy -side top -pady 0
    }

    proc actPackISteerControl {} {
        pack forget .ftop.sn.r1.nudges .ftop.sn.r1.nudgesProxy
        pack .ftop.sn.r1.isteercontrol -side top -pady 0
    }

    proc actPackISteerEnable { enabletext } {
        pack forget .ftop.sn.r1.isteercontrol.disable
        pack .ftop.sn.r1.isteercontrol.enable -side top -pady 0
	.ftop.sn.r1.isteercontrol.enable configure -text $enabletext
    }

    proc actPackISteerDisable { disabletext } {
        pack forget .ftop.sn.r1.isteercontrol.enable
        pack .ftop.sn.r1.isteercontrol.disable
	.ftop.sn.r1.isteercontrol.disable configure -text $disabletext
    }

    proc actForgetNudgeProxy {} {
        pack forget .ftop.sn.r1.nudges .ftop.sn.r1.nudgesProxy
        pack .ftop.sn.r1.nudges -side top -pady 0
    }

    proc actConfigureBeginEndPass { text__ id__ } {
       if { $id__ == 0 } {
          pack forget .ftop.sn.r1.beginEndPassFrame.endPassBtn
          pack .ftop.sn.r1.beginEndPassFrame.beginPassBtn -side top -anchor n -pady 0
		  .ftop.sn.r1.beginEndPassFrame.beginPassBtn configure -text $text__
       } else {
          pack forget .ftop.sn.r1.beginEndPassFrame.beginPassBtn
          pack .ftop.sn.r1.beginEndPassFrame.endPassBtn -side top -anchor n -pady 0
	      .ftop.sn.r1.beginEndPassFrame.endPassBtn configure -text $text__
       }
		
		#printf actConfigureBeginEndPass\n
    }

	proc actForgetToggleCoverage {} {	
		pack forget .ftop.input2.row1.left.toggleCoverageLabel \
					.ftop.input2.row1.left.toggleCoverageOffBtn \
					.ftop.input2.row1.left.toggleCoverageOnBtn
	}
		
	proc actDisableToggleCoverage {} {
      .ftop.input2.row1.left.toggleCoverageOffBtn configure -state disabled
	  .ftop.input2.row1.left.toggleCoverageOnBtn configure -state disabled		
	}
		
	proc actConfigureToggleCoverage { btntext__  text__ id__ } {
	   if { $id__ == 0 } {
	       pack forget .ftop.input2.row1.left.toggleCoverageOffBtn
	       pack .ftop.input2.row1.left.toggleCoverageOnBtn -side left -anchor w -padx 2 -pady 2
	       .ftop.input2.row1.left.toggleCoverageLabel configure -text $text__
	       .ftop.input2.row1.left.toggleCoverageOnBtn configure -text $btntext__ 
	   } else {
	       pack forget .ftop.input2.row1.left.toggleCoverageOnBtn
	       pack .ftop.input2.row1.left.toggleCoverageOffBtn -side left -anchor w -padx 2 -pady 2
	       .ftop.input2.row1.left.toggleCoverageLabel configure -text $text__
	       .ftop.input2.row1.left.toggleCoverageOffBtn configure -text $btntext__ 
	   }
	}		
		
    proc actSliderValue { sliderNum val notch } {
       Sliders::actSliderValue $sliderNum $val $notch
    }
    
    proc actFieldBoundary {} {
        # MLE-040115: So that tcl doesn't call an empty procedure
    }

    proc actToggleNudge { text__ } {
        .ftop.sn.r1.nudges.l0 configure -text $text__
    }

    proc actConfigCpuLoadText { text__ } {
        .ftop.cpuload.l configure -text $text__
    }
    
    proc actToggleControl { controlNumOld__ controlNumNew__} {
		global backGroundColor
	
    	# forget isteer control
    	pack forget .ftop.sn.r1.isteercontrol
    	
		# forget the previous control (controlNumOld__) in the control cycle 
		if {$controlNumOld__ == -1} {
          pack forget .ftop.sn.r1.nudges .ftop.sn.r1.beginEndPassFrame
        }
		#else
		#{	
          pack forget .s$controlNumOld__
		#}
		
		# pack the new control (controlNumNew__)
        pack .ftop.sn.r1.sliders -side top
        pack .s$controlNumNew__ -in .ftop.sn.r1.sliders -side top -fill both -expand yes
        raise .s$controlNumNew__  
	    Sliders::sliderConfigureBackground .s$controlNumNew__ $backGroundColor
    }
    
    proc actPackNudgeButtons {} {
	actForgetBeginEndPass
        pack .ftop.sn.r1.nudges -side top -pady 0    
    }
    
    proc actForgetLastControl { controlNumOld__ controlNumNew__ } {
        pack forget .s$controlNumNew__ .s$controlNumOld__
        pack forget .ftop.sn.r1.sliders
	pack forget .ftop.sn.r1.isteercontrol
    }
    
    proc actDisableExitBtn {} {
      .ftop.input1.cancel configure -state disabled
    }
    
    proc actActivateExitBtn {} {
      .ftop.input1.cancel configure -state normal
    }
}
