##############################################################################
#
# vc/src/tcl/calibImpCtrlr.tcl
#
# Screen to show SATEL frequencies
#
# 20051115 SSJ - created
#
# Copyright (c) 2005 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Orthman Controller Calibration" -font $huge_font

    frame .ftop.input
    frame .ftop.input.display

    # Display Frame - displays up to 3 lines of text at a time
    label .ftop.input.display.l0 -text "line 0"
    label .ftop.input.display.l1 -text "line 1"
    label .ftop.input.display.l2 -text "line 2"
    label .ftop.input.display.l3 -text "line 3"
    label .ftop.input.display.l4 -text "line 4"
    label .ftop.input.display.l5 -text "line 5"

    frame .ftop.input.b
    # Cancel Button
    SnazzyButton::create .ftop.input.b.cancel \
                 btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;"
    pack .ftop.input.b.cancel -side left -anchor sw

    # Calib Buttons
    SnazzyButton::create .ftop.input.b.calibStart \
                 btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN1_SIG 1;"
    pack .ftop.input.b.calibStart -side right -anchor se

    SnazzyButton::create .ftop.input.b.calibStop \
                 btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN0_SIG 0;"
    pack .ftop.input.b.calibStop -side right -anchor se

    # Pack .ftop
    pack .ftop.title -side top
    pack .ftop.input.b -side bottom -anchor s -fill both
    pack .ftop.input.display.l0 -side top
    pack .ftop.input.display.l1 -side top
    pack .ftop.input.display.l2 -side top
    pack .ftop.input.display.l3 -side top
    pack .ftop.input.display.l4 -side top
    pack .ftop.input.display.l5 -side top
    pack .ftop.input.display -side top -anchor n -pady 25 -fill both -expand yes
    pack .ftop.input -side bottom 
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {infoLbl warnLbl step1Lbl step2Lbl step3Lbl step4Lbl \
                   cancelBtn calibStartBtn calibStopBtn} {
        global big_font medium_font

        .ftop.input.display.l0 configure -text $infoLbl -font $medium_font
        .ftop.input.display.l1 configure -text $warnLbl -font $big_font
        .ftop.input.display.l2 configure -text $step1Lbl -font $big_font
        .ftop.input.display.l3 configure -text $step2Lbl -font $big_font
        .ftop.input.display.l4 configure -text $step3Lbl -font $big_font
        .ftop.input.display.l5 configure -text $step4Lbl -font $big_font
        SnazzyButton::setText .ftop.input.b.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.input.b.calibStart $calibStartBtn 0.5
        SnazzyButton::setText .ftop.input.b.calibStop $calibStopBtn 0.5
        .ftop.input.b.calibStop configure -state disabled
 
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actStartOCcalibration {errorSigLbl} {
        global big_font

        .ftop.input.display.l1 configure -text $errorSigLbl -font $big_font
        .ftop.input.b.calibStart configure -state disabled
        .ftop.input.b.calibStop configure -state normal
    }

    proc actStopOCcalibration {nextDirLbl doneLbl} {

        .ftop.input.b.calibStart configure -state normal
        SnazzyButton::setText .ftop.input.b.calibStart $nextDirLbl 0.5
        .ftop.input.b.calibStop configure -state disabled
        if {$doneLbl != "!"} {
           SnazzyButton::setText .ftop.input.b.cancel $doneLbl 0.5
        }
    }

    proc actDispErrSig {errSigLbl} {
        global big_font

        .ftop.input.display.l1 configure -text $errSigLbl -font $big_font
    }

}

