##############################################################################
#
# vc/src/tcl/hardcore.tcl
#
# Hardcore controller-tuning screen
#
# 20021101 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop

    # Title
    label .ftop.title -text "CAT Steering Calibration" -font $huge_font
    pack .ftop.title -side top

    # Input frame
    frame .ftop.input

    # Accept/Reject Subframe
    frame .ftop.input.acceptReject
    SnazzyButton::create .ftop.input.acceptReject.cancel \
	     btnKhakiM6U btnKhakiM6U 0.5 \
		"beepOnce; post $DISP_BTN9_SIG 0" ""
    pack .ftop.input.acceptReject.cancel -side left -padx 3 -pady 2
    
    SnazzyButton::create .ftop.input.acceptReject.recalc \
	     btnKhakiM6U btnKhakiM6U 0.5 \
		"beepOnce; post $DISP_BTN1_SIG 0" "Recalculate\nCalibration\nCurves"
    pack .ftop.input.acceptReject.recalc -side left -padx 3 -pady 2
    
    SnazzyButton::create .ftop.input.acceptReject.accept \
	     btnKhakiM6U btnKhakiM6U 0.5 \
		"beepOnce; post $DISP_BTN2_SIG 0" "Accept\nNew\nCalibration"
    pack .ftop.input.acceptReject.accept -side left -padx 3 -pady 2
    
    SnazzyButton::create .ftop.input.acceptReject.discard \
	     btnKhakiM6U btnKhakiM6U 0.5 \
		"beepOnce; post $DISP_BTN3_SIG 0" "Discard\nMarked\nData Point" 
    pack .ftop.input.acceptReject.discard -side left -padx 3 -pady 2
    
    SnazzyButton::create .ftop.input.acceptReject.toggle \
	     btnKhakiM6U btnKhakiM6U 0.5 \
		"beepOnce; post $DISP_BTN4_SIG 0" "Toggle\nPlot"
    pack .ftop.input.acceptReject.toggle -side left -padx 3 -pady 2

    # Stop and Go subframe
    frame .ftop.input.stopGo
    SnazzyUnclippedButton::create .ftop.input.stopGo.stop \
	     btnSmallStopU btnSmallStopD 0.5 \
		"beepOnce; post $DISP_BTN0_SIG 0" ""
            
    SnazzyUnclippedButton::create .ftop.input.stopGo.go \
	     btnSmallGoU btnSmallGoD 0.5 \
		"beepOnce; post $DISP_BTN0_SIG 1" ""        
            
    # Pack the Input Frame
    pack .ftop.input.stopGo -side right -padx 0
    pack .ftop.input.acceptReject -side right -padx 3
    
    # Left input frame
    frame .ftop.inputL
    
    SnazzyButton::create .ftop.inputL.smallL \
	     btnBlueBLRU btnBlueBLRD 0.5 \
		"beepOnce; post $DISP_BTN5_SIG 0" "Small\nLeft"        
    pack .ftop.inputL.smallL -side top -padx 5 -pady 5
    
    SnazzyButton::create .ftop.inputL.bigL \
	     btnBlueBLRU btnBlueBLRD 0.5 \
		"beepOnce; post $DISP_BTN5_SIG 1" "Big\nLeft"        
    pack .ftop.inputL.bigL -side top -padx 5 -pady 5
    
    SnazzyButton::create .ftop.inputL.maxL \
	     btnBlueMaxLRU btnBlueMaxLRD 0.5 \
		"beepOnce; post $DISP_BTN5_SIG 4" "Max\nLeft" 
    label .ftop.inputL.hint -font $small_font

    # Right input frame
    frame .ftop.inputR
    
    SnazzyButton::create .ftop.inputR.smallR \
	     btnBlueBLRU btnBlueBLRD 0.5 \
		"beepOnce; post $DISP_BTN5_SIG 2" "Small\nRight"
    pack .ftop.inputR.smallR -side top -padx 5 -pady 5
    
    SnazzyButton::create .ftop.inputR.bigR \
	     btnBlueBLRU btnBlueBLRD 0.5 \
		"beepOnce; post $DISP_BTN5_SIG 3" "Big\nRight"        
    pack .ftop.inputR.bigR -side top -padx 5 -pady 5
    
    SnazzyButton::create .ftop.inputR.maxR \
	     btnBlueMaxLRU btnBlueMaxLRD 0.5 \
		"beepOnce; post $DISP_BTN5_SIG 5" "Max\nRight"
    
    # small .cpf controls subframe
    frame .ftop.l
    frame .ftop.l.scpf
    button .ftop.l.scpf.confA -text "A" \
            -background $color3 -activebackground $color3 \
            -command { beepOnce; post $DISP_BTN5_SIG 8 } \
            -width 3 -height 1
    button .ftop.l.scpf.confB -text "B" \
            -background $color3 -activebackground $color3 \
            -command { beepOnce; post $DISP_BTN5_SIG 9 } \
            -width 3 -height 1
    button .ftop.l.scpf.confC -text "C" \
            -background $color3 -activebackground $color3 \
            -command { beepOnce; post $DISP_BTN5_SIG 10 } \
            -width 3 -height 1
    button .ftop.l.scpf.exportdata -text "Exp.: Off" \
            -background $color3 -activebackground $color3 \
            -command { beepOnce; post $DISP_BTN5_SIG 7 } \
            -width 6 -height 1

    # Pack the various elements
    pack .ftop.input -side bottom -pady 5 -expand yes -fill x
    pack .ftop.inputL -side left -fill y -expand true
    pack .ftop.inputR -side right -fill y -expand true
    pack .calDataDisplay -in .ftop -side left -expand yes
    raise .calDataDisplay

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {

        eval $packProc__

        pack .ftop -fill both -expand yes
    }
    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {

        destroy .ftop

    }

    proc setMessage { msgId msgString } {
	StateHistoryDisplay::setMessage $msgId $msgString
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr

    proc actToggleCalPlot { option__ } {

        pack forget .calDataDisplay .tractorDisplay .glContDataDisp .stateHistoryDisplay
        if { $option__ == 1 } {
            pack .calDataDisplay -in .ftop -side left -expand yes
            raise .calDataDisplay
        } elseif { $option__ == 2 } {
            pack .tractorDisplay -in .ftop -side left -expand yes
            raise .tractorDisplay
        } elseif { $option__ == 3 } {
            pack .glContDataDisp -in .ftop -side left -expand yes
            raise .glContDataDisp
        } elseif { $option__ == 4 } {
	    pack .stateHistoryDisplay -in .ftop -side left -expand yes
	    raise .stateHistoryDisplay
	}
    }

    proc actConfigureInactive { manualSteeringText__ } {

        pack forget .ftop.input.stopGo.stop
        pack .ftop.input.stopGo.go -side top
        TractorDisplay::actConfigureRowlineup $manualSteeringText__

    }

    proc actConfigureActive { } {

        pack forget .ftop.input.stopGo.go
        pack .ftop.input.stopGo.stop -side top
        TractorDisplay::actConfigureAutosteer

    }

    proc actConfigTractorIcon { tractorType__ tractorColor__ \
            implWidth__ implOffset__} {
        # Delegate to the .tractorDisplay component
        TractorDisplay::actConfigTractorIcon \
                $tractorType__ $tractorColor__ $implWidth__ $implOffset__
    }

    proc actVehicleDispData { velDispText__ Vx__ VxMax__ \
            headingError__ posError__ \
            passWidth__ fanAngle__ rowNumText__ nudgeDistText__ \
            turboMessageText__ ENHANCED_RLM__ \
            ERLM_HE_ENTER__ ERLM_HE_EXIT__ \
            ERLM_YC_ENTER__ ERLM_YC_EXIT__ \
            inTightMode__} {

        # Delegate to the .tractorDisplay component
        TractorDisplay::actVehicleDispData $velDispText__ $Vx__ $VxMax__ \
                $headingError__ $posError__ $passWidth__ $fanAngle__ \
                $rowNumText__ $nudgeDistText__ \
                $turboMessageText__ $ENHANCED_RLM__ $ERLM_HE_ENTER__ \
                $ERLM_HE_EXIT__ $ERLM_YC_ENTER__ $ERLM_YC_EXIT__ \
                $inTightMode__
    }

    proc actSteerCodeDisp { turningWheelText__ killText__ clutchText__ \
            parkText__ resetReqText__ roadingText__ comsBadText__ \
            notReadyText__ inxUnsText__ } {

        # Delegate to the .tractorDisplay component
        TractorDisplay::actSteerCodeDisp $turningWheelText__ $killText__ \
                $clutchText__ $parkText__ $resetReqText__ $roadingText__ \
                $comsBadText__ $notReadyText__ $inxUnsText__
    }

    proc actPlotCalData { } {
        CalDataDisplay::actPlotCalData
    }

    proc actPlotCalDataWork { filename__ } {
        CalDataDisplay::actPlotCalDataWork $filename__
    }

    proc actResetUrawMarker { } {
        CalDataDisplay::actResetUrawMarker
    }

    proc actUpdateUrawMarker { color__ uraw__ } {
        puts "actUpdateUrawMarker: uraw__ = $uraw__"
        CalDataDisplay::actUpdateUrawMarker $color__ $uraw__
    }

    proc actUpdateRawAngleMarker { color__ rawAngle__ } {
        CalDataDisplay::actUpdateRawAngleMarker $color__ $rawAngle__
    }

    proc actHideRawAngleMarker { } {
        CalDataDisplay::actHideRawAngleMarker
    }

    proc actConfigureHint { text__ } {
        .ftop.inputL.hint configure -text $text__ 
    }
    
    proc actPackHint { text__ } {
        .ftop.inputL.hint configure -text $text__
        pack .ftop.inputL.hint -side top
    }

    proc actToggleExportData { text__ } {

        .ftop.l.scpf.exportdata configure -text "Exp.: $text__"

    }

    proc actPackSmallCpf {} {
        global color3
        .ftop.l.scpf.confA \
                configure -background $color3 -activebackground $color3
        .ftop.l.scpf.confB \
                configure -background $color3 -activebackground $color3
        .ftop.l.scpf.confC \
                configure -background $color3 -activebackground $color3
        pack .ftop.l.scpf.confA -side top -padx 5 -pady 5 -expand yes
        pack .ftop.l.scpf.confB -side top -padx 5 -pady 5 -expand yes
        pack .ftop.l.scpf.confC -side top -padx 5 -pady 5 -expand yes
        pack .ftop.l.scpf.exportdata -side top -padx 5 -pady 5 -expand yes
	pack .ftop.l.scpf -side top -expand yes
	pack .ftop.l  -side right -expand yes
     }

    proc actConfigA {} {
        global color3
        .ftop.l.scpf.confA \
                configure -background SteelBlue4 -activebackground SteelBlue4
        .ftop.l.scpf.confB \
                configure -background $color3 -activebackground $color3
        .ftop.l.scpf.confC \
                configure -background $color3 -activebackground $color3
    }    

    proc actConfigB {} {
        global color3
        .ftop.l.scpf.confA \
                configure -background $color3 -activebackground $color3
        .ftop.l.scpf.confB \
                configure -background SteelBlue4 -activebackground SteelBlue4
        .ftop.l.scpf.confC \
                configure -background $color3 -activebackground $color3
    }    

    proc actConfigC {} {
        global color3
        .ftop.l.scpf.confA \
                configure -background $color3 -activebackground $color3
        .ftop.l.scpf.confB \
                configure -background $color3 -activebackground $color3
        .ftop.l.scpf.confC \
                configure -background $color3 -activebackground SteelBlue4
    }    

    proc actConfigureCDPanelInfo { onoff__ ms0__ ms1__ } {
        GlContDataDisp::actConfigureCDPanelInfo $onoff__ $ms0__ $ms1__
    }

    proc actConfigureCDPanelInput { visible__ chan__ twin__ dwin__ \
                                   freeze__ save__ export__ exit__ } {
        GlContDataDisp::actConfigureCDPanelInput $visible__ \
            $chan__ $twin__ $dwin__ $freeze__  $save__ $export__ $exit__
        if { $visible__ == 1 } {
            pack forget .tractorDisplay
        } else {
            pack .tractorDisplay -in .ftop.r -side top -fill both
            raise .tractorDisplay
        }
    }

    #-------------------------------------------------------------------------
    # Local procedures
    #-------------------------------------------------------------------------
    proc packDeereTrackStep2 {titleLbl smallLeftBtn bigLeftBtn smallRightBtn \
        bigRightBtn cancelBtn recalculateBtn acceptBtn discardBtn toggleBtn} {
        
        .ftop.title configure -text $titleLbl
        .ftop.input.acceptReject.cancel configure  -text $cancelBtn
        .ftop.input.acceptReject.recalc configure  -text $recalculateBtn
        .ftop.input.acceptReject.accept configure  -text $acceptBtn
        .ftop.input.acceptReject.discard configure -text $discardBtn
        .ftop.input.acceptReject.toggle configure  -text $toggleBtn

        .ftop.inputL.smallL configure              -text $smallLeftBtn
        .ftop.inputL.bigL configure                -text $bigLeftBtn
        .ftop.inputR.smallR configure              -text $smallRightBtn
        .ftop.inputR.bigR configure                -text $bigRightBtn
    }


    #-------------------------------------------------------------------------
    # Local procedures
    #-------------------------------------------------------------------------
    proc packImplementCalib {titleLbl cancelBtn acceptBtn toggleBtn} {
        
        .ftop.title configure -text $titleLbl
        .ftop.input.acceptReject.cancel configure -text $cancelBtn
        .ftop.input.acceptReject.accept configure -text $acceptBtn
        .ftop.input.acceptReject.toggle configure -text $toggleBtn

        pack forget .ftop.input.acceptReject.discard
        pack forget .ftop.input.acceptReject.recalc
        pack forget .ftop.inputL.smallL 
        pack forget .ftop.inputL.bigL 
        pack forget .ftop.inputR.smallR 
        pack forget .ftop.inputR.bigR 

	
    }


    proc packWheeledStep3 {titleLbl smallLeftBtn bigLeftBtn \
            smallRightBtn bigRightBtn cancelBtn recalculateBtn \
            acceptBtn discardBtn toggleBtn} {
        
        .ftop.title configure -text $titleLbl
        .ftop.input.acceptReject.cancel configure -text $cancelBtn
        .ftop.input.acceptReject.recalc configure -text $recalculateBtn
        .ftop.input.acceptReject.accept configure -text $acceptBtn
        .ftop.input.acceptReject.discard configure -text $discardBtn
        .ftop.input.acceptReject.toggle configure -text $toggleBtn

        .ftop.inputL.smallL configure -text $smallLeftBtn
        .ftop.inputL.bigL configure -text $bigLeftBtn
        .ftop.inputR.smallR configure -text $smallRightBtn
        .ftop.inputR.bigR configure -text $bigRightBtn
    }


    proc packWheeledStep4 {titleLbl smallLeftBtn bigLeftBtn maxLeftBtn \
        smallRightBtn bigRightBtn maxRightBtn cancelBtn recalculateBtn \
        acceptBtn discardBtn toggleBtn} {
        
        .ftop.title configure -text $titleLbl
        .ftop.input.acceptReject.cancel configure -text $cancelBtn
        .ftop.input.acceptReject.recalc configure -text $recalculateBtn
        .ftop.input.acceptReject.accept configure -text $acceptBtn
        .ftop.input.acceptReject.discard configure -text $discardBtn
        .ftop.input.acceptReject.toggle configure -text $toggleBtn

        .ftop.inputL.smallL configure -text $smallLeftBtn
        .ftop.inputL.bigL configure -text $bigLeftBtn
        .ftop.inputL.maxL configure -text $maxLeftBtn
        .ftop.inputR.smallR configure -text $smallRightBtn
        .ftop.inputR.bigR configure -text $bigRightBtn
        .ftop.inputR.maxR configure -text $maxRightBtn

        pack .ftop.inputL.maxL -side top -padx 5 -pady 5
        pack .ftop.inputR.maxR -side top -padx 5 -pady 5
    }


    proc packCatTrackStep2 {titleLbl smallLeftBtn bigLeftBtn smallRightBtn \
        bigRightBtn cancelBtn recalculateBtn acceptBtn discardBtn toggleBtn} {
        
        .ftop.title configure -text $titleLbl
        .ftop.input.acceptReject.cancel configure -text $cancelBtn
        .ftop.input.acceptReject.recalc configure -text $recalculateBtn
        .ftop.input.acceptReject.accept configure -text $acceptBtn
        .ftop.input.acceptReject.discard configure -text $discardBtn
        .ftop.input.acceptReject.toggle configure -text $toggleBtn

        .ftop.inputL.smallL configure -text $smallLeftBtn
        .ftop.inputL.bigL configure -text $bigLeftBtn
        .ftop.inputR.smallR configure -text $smallRightBtn
        .ftop.inputR.bigR configure -text $bigRightBtn

        pack .ftop.inputL.hint -side top -padx 5 -pady 5
    }


    proc packMTStep1 {titleLbl smallLeftBtn bigLeftBtn smallRightBtn \
        bigRightBtn cancelBtn recalculateBtn acceptBtn discardBtn toggleBtn} {
        
        .ftop.title configure -text $titleLbl
        .ftop.input.acceptReject.cancel configure -text $cancelBtn
        .ftop.input.acceptReject.recalc configure -text $recalculateBtn
        .ftop.input.acceptReject.accept configure -text $acceptBtn
        .ftop.input.acceptReject.discard configure -text $discardBtn
        .ftop.input.acceptReject.toggle configure -text $toggleBtn

        .ftop.inputL.smallL configure -text $smallLeftBtn
        .ftop.inputL.bigL configure -text $bigLeftBtn
        .ftop.inputR.smallR configure -text $smallRightBtn
        .ftop.inputR.bigR configure -text $bigRightBtn
    }

    proc packCamecoHarvStep1 {titleLbl smallLeftBtn bigLeftBtn smallRightBtn \
        bigRightBtn cancelBtn recalculateBtn acceptBtn discardBtn toggleBtn} {
        
        .ftop.title configure -text $titleLbl
        .ftop.input.acceptReject.cancel configure -text $cancelBtn
        .ftop.input.acceptReject.recalc configure -text $recalculateBtn
        .ftop.input.acceptReject.accept configure -text $acceptBtn
        .ftop.input.acceptReject.discard configure -text $discardBtn
        .ftop.input.acceptReject.toggle configure -text $toggleBtn

        .ftop.inputL.smallL configure -text $smallLeftBtn
        .ftop.inputL.bigL configure -text $bigLeftBtn
        .ftop.inputR.smallR configure -text $smallRightBtn
        .ftop.inputR.bigR configure -text $bigRightBtn
    }

    proc ToBeCompleted {} {

    }

}
