##############################################################################
#
# vc/src/tcl/dropdownlist.tcl
#
# A modal-dialog-type dropdownlist.
#
# 20020906 MLE, QC - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Modal { 

    #-------------------------------------------------------------------------
    # Define and pack the dropdownlist
    #-------------------------------------------------------------------------
    # Top level frame
    frame .fmodal

    # display frame
    frame .fmodal.display
    label .fmodal.display.prompt -text "Space for the prompt"
    pack .fmodal.display.prompt -side top -padx 5 -pady 10 \
            -fill both -expand yes

    # Button Frame
    frame .fmodal.buttons
    
    # Input frame
    frame .fmodal.input

    # spacer
    frame .fmodal.input.spacer -height 220 -width 0
    pack .fmodal.input.spacer -side left
    
    
    # Cancel button
    SnazzyButton::create .fmodal.buttons.b0 btnKhakiU btnKhakiD 0.5 \
                "beepOnce; post $DISP_BTN0_SIG 0;" "Cancel"

    # Select button
    SnazzyButton::create .fmodal.buttons.b1 btnBlueU btnBlueD 0.5 \
                "beepOnce; post $DISP_BTN1_SIG 1;" "Select"

    # {MLE-020701: Are these -commands too intelligent?}
    scrollbar .fmodal.input.sbar \
            -command { .fmodal.input.lbox yview }
    listbox .fmodal.input.lbox -width 35 \
            -yscrollcommand {.fmodal.input.sbar set}
    bind .fmodal.input.lbox <ButtonRelease-1> \
         { set index [lindex [.fmodal.input.lbox curselection] 0];
           if { [.fmodal.input.lbox get $index] == "Parallel rows" } {
               SnazzyButton::setImage .fmodal.buttons.b1 \
                             btnParallelRowsU btnParallelRowsD 0.5
               SnazzyButton::setText .fmodal.buttons.b1 "Select" 0.2;
           }; 
           if { [.fmodal.input.lbox get $index] == "Fan rows" } {
               SnazzyButton::setImage .fmodal.buttons.b1 \
                             btnFanRowsU btnFanRowsD 0.5 
               SnazzyButton::setText .fmodal.buttons.b1 "Select" 0.2;
           }; 
           if { [.fmodal.input.lbox get $index] == "Box rows" } {
               SnazzyButton::setImage .fmodal.buttons.b1 \
                             btnBoxRowsU btnBoxRowsD 0.5
               SnazzyButton::setText .fmodal.buttons.b1 "Select" 0.2;
           }; 
           if { [.fmodal.input.lbox get $index] == "Circle rows" } {
               SnazzyButton::setImage .fmodal.buttons.b1 \
                             btnCircleRowsU btnCircleRowsD 0.5
               SnazzyButton::setText .fmodal.buttons.b1 "Select" 0.2;
           }; 
           if { [.fmodal.input.lbox get $index] == "Curve rows" } {
               SnazzyButton::setImage .fmodal.buttons.b1 \
                             btnCurveRowsU btnCurveRowsD 0.5
               SnazzyButton::setText .fmodal.buttons.b1 "Select" 0.2;
           }; 
         }        

    # pack input frame
    pack .fmodal.buttons.b0 -side left -padx 5 -pady 5 -anchor sw
    pack .fmodal.input.lbox -side left -pady 5 -fill both -expand yes
    pack .fmodal.input.sbar -side left -pady 5 -fill y -expand yes
    pack .fmodal.buttons.b1 -side right -padx 5 -pady 5 -anchor se

    # Pack dropdownlist
    pack .fmodal.display -side top -pady 5 -fill both -expand yes
    pack .fmodal.input -side top -pady 5 -expand yes -anchor n
    pack .fmodal.buttons -side bottom -pady 5 -expand yes -fill x -anchor s

    #-------------------------------------------------------------------------
    # Entry and exit procedures
    #-------------------------------------------------------------------------
    proc actEntry {} {
        pack forget .ftop
        pack .fmodal -fill both -expand yes
    }

    proc actExit {} {
        destroy .fmodal
        pack .ftop -fill both -expand yes
    }

    #-------------------------------------------------------------------------
    # Action procedures
    #-------------------------------------------------------------------------
    proc actConfigure { prompt__ cancelBtn__ selectBtn__ } {
        .fmodal.display.prompt configure -text $prompt__
        SnazzyButton::setText .fmodal.buttons.b0 $cancelBtn__ 0.5
        SnazzyButton::setText .fmodal.buttons.b1 $selectBtn__ 0.5 

#       .fmodal.input.b0 configure -text $cancelBtn__
#       .fmodal.input.b1 configure -text $selectBtn__
    }


    proc actListboxInsert { item__ } {
        .fmodal.input.lbox insert end $item__
    }
    

    proc actListboxSelectionSet { selectBtn__ index } {
        .fmodal.input.lbox selection set $index
        if { [.fmodal.input.lbox get $index] == "Parallel rows" } {
           SnazzyButton::setImage .fmodal.input.b1 \
                         btnParallelRowsU btnParallelRowsD 0.5
           SnazzyButton::setText .fmodal.buttons.b1 $selectBtn__ 0.2
        } else {
           SnazzyButton::setText .fmodal.buttons.b1 $selectBtn__ 0.5 
        }
    }

    proc showSpecialRowsPictures { } {
         puts stdout "Hello showSpecialRowsPictures\n"
    }
    
    proc actListboxGetCurselection {} {
        if { [.fmodal.input.lbox index end] != 0} {
            set index [lindex [.fmodal.input.lbox curselection] 0]
            return [.fmodal.input.lbox get $index]
        } else {
            return "!"             ;# ! tells the C side the listbox was empty
        }
    }


    proc actListboxGetCurindex {} {
        if { [.fmodal.input.lbox index end] != 0} {
            return [lindex [.fmodal.input.lbox curselection] 0]
        } else {
            return -1             ;# -1 tells the C side the listbox was empty
        }
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.fmodal.input.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .fmodal.input.lbox selection set $index
        .fmodal.input.lbox see $index
    }
    

    proc actListboxDeleteAll { } {
        .fmodal.input.lbox delete 0 end
    }

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    

}
