##############################################################################
#
# vc/src/tcl/gpslog.tcl
#
# Indemnity warning screen,
#
# 20030625 DGL - created
#
# Copyright (c) 2003 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # title and error indicator
    label .ftop.title -text "GPS Log"
    place .ftop.title -relx 0.5 -rely 0.0 -anchor n
    
    # gps log output
    frame .ftop.out
    scrollbar .ftop.out.vsbar -orient vertical \
              -command { .ftop.out.lbox yview }
    scrollbar .ftop.out.hsbar -orient horizontal \
              -command { .ftop.out.lbox xview }
    listbox .ftop.out.lbox -width 80 -height 12 -font $small_font \
            -xscrollcommand {.ftop.out.hsbar set} \
            -yscrollcommand {.ftop.out.vsbar set}
    pack .ftop.out.hsbar -side bottom -ipadx 228 -anchor sw
    pack .ftop.out.vsbar -side right -pady 5 -fill y -anchor ne
    pack .ftop.out.lbox -side top -pady 5 -fill both -expand yes
    place .ftop.out -relx 0.5 -rely 0.4 -y -10 -anchor c

    # buttons
    SnazzyButton::create .ftop.clear btnRedU btnRedD 0.5 \
            "beepOnce; post $DISP_BTN1_SIG 1" "Clear Log"

    place .ftop.clear -relx 0.5 -x -90 -rely 1.0 -y -5 -anchor se
    SnazzyButton::create .ftop.return btnKhakiU btnKhakiD 0.5 \
            "beepOnce; post $DISP_BTN9_SIG 9" "Return To\nPrevious\nMenu"
 
    place .ftop.return -relx 0.5 -x -320 -rely 1.0 -y -5 -anchor sw

    label .ftop.waitText -text "Copying Data\nPlease Wait" -font $medium_font
    
    frame .ftop.input
    frame .ftop.input.r0
    SnazzyButton::create .ftop.input.r0.copylogs btnBlueM5U btnBlueM5D 0.5 \
           "beepOnce; post $DISP_BTN2_SIG 2" "Open Internal\nRaw Storage"
    SnazzyButton::create .ftop.input.r0.closepostfile btnBlueM5U btnBlueM5D 0.5 \
           "beepOnce; post $DISP_BTN3_SIG 3" "Open External\nRaw Storage"
    frame .ftop.input.r1
    SnazzyButton::create .ftop.input.r1.pfileinternal btnBlueM5U btnBlueM5D 0.5 \
           "beepOnce; post $DISP_BTN4_SIG 4" "Close\nRaw Storage"
    SnazzyButton::create .ftop.input.r1.pfileexternal btnBlueM5U btnBlueM5D 0.5 \
           "beepOnce; post $DISP_BTN5_SIG 5" "Copy Internal\n->External"
    pack .ftop.input -side right -anchor se -padx 5 -pady 5       

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    
    set theLogFname ""
    proc actEntry {fname ecpf clear return prompt } {
        global theLogFname
        set theLogFname $fname
        set fd 0
	.ftop.clear configure -text $clear
	.ftop.return configure -text $return
	.ftop.title configure -text $prompt
        if [catch {open $fname r} fd] {
           set fd 0
           .ftop.out.lbox insert end "empty"           
        } else {
           gets $fd str
           while {$str != ""} {
               .ftop.out.lbox insert end $str           
               gets $fd str
           }
           catch {close $fd}
        }
        .ftop.out.lbox see end
        
        if {$ecpf != "9"} {
          pack .ftop.input.r0.copylogs -side left
          pack .ftop.input.r0.closepostfile -side left -padx 5
          pack .ftop.input.r0 -side top
          pack .ftop.input.r1.pfileinternal -side left
          pack .ftop.input.r1.pfileexternal -side left -padx 5
          pack .ftop.input.r1 -side bottom
        }   
        
        pack .ftop -fill both -expand yes
    }

    proc actClear {} {
        global theLogFname
        file delete $theLogFname
        .ftop.out.lbox delete 0 end           
        .ftop.out.lbox insert end "empty"           
        .ftop.out.lbox see end
    }

    proc actEnableReturnBtn {} {
      .ftop.return configure -state active  
    }
    
    proc actDisableReturnBtn {} {
      .ftop.return configure -state disabled
    }
    
    proc actShowCopyText { text__ } {
      .ftop.waitText configure -text $text__
      place .ftop.waitText -relx 0.6 -x -20 -rely 1.0 -y -40 -anchor se
    }
    
    proc actHideCopyText {} {
      place forget .ftop.waitText
    }
    
    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

}
