##############################################################################
#
# vc/src/tcl/jobaddtype.tcl
#
# Iconify Job Type Selection screen
#
# 20040611 MLE - created from specialrows.tcl
#
# Copyright (c) 2004 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # Screen has display and input frames
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes

    # Cancel button
    SnazzyButton::create .ftop.input.cancel btnKhakiU btnKhakiD 0.5 \
            "beepOnce; post $DISP_BTN9_SIG 9" "Cancel"

    # Display Frame
    label .ftop.display.title -text "Title" -font $huge_font

    # Input frame 
    # Standard Jobs
    frame .ftop.input.f1
    label .ftop.input.f1.l1 -text "Standard Jobs" -font $big_font
    
    frame .ftop.input.f1.r1
    SnazzyButton::create .ftop.input.f1.r1.b0 btnParallelRowsU btnParallelRowsD \
            0.5 "beepOnce; post $DISP_BTN0_SIG 0" "ParallelRows"
    SnazzyButton::create .ftop.input.f1.r1.b1 btnFanRowsU btnFanRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 1" "FanRows"
    SnazzyButton::create .ftop.input.f1.r1.b2 btnBoxRowsU btnBoxRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 2" "BoxRows"
    SnazzyButton::create .ftop.input.f1.r1.b3 btnCircleRowsU btnCircleRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 3" "CircleRows"
    pack .ftop.input.f1.r1 -side bottom -anchor se

    # Record and Repeat Jobs
    frame .ftop.input.f2
    label .ftop.input.f2.l1 -text "Record and Repeat Jobs" -font $big_font
    pack .ftop.input.f2.l1 -side top -padx 10 -pady 10 -anchor w

    frame .ftop.input.f2.r2
    SnazzyButton::create .ftop.input.f2.r2.b4 btnABPathU btnABPathD  0.5 \
            "beepOnce; post $DISP_BTN0_SIG 4" "AB Path\nMaster"
    SnazzyButton::create .ftop.input.f2.r2.b5 btnCurveRowsU btnCurveRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 5" "Curve Path\nMaster"
    SnazzyButton::create .ftop.input.f2.r2.b6 btnRepeatJobU btnRepeatJobD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 6" "Repeat Job"
    SnazzyButton::create .ftop.input.f2.r2.b7 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 7" "Button 7"
    pack .ftop.input.f2.r2 -side bottom -anchor se

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {titleLbl cancelBtn
                   standardTtl jobtype0 jobtype1 jobtype2 jobtype3 
                   rrTtl jobtype0ab jobtype5 jobrepeat} {
        # Title
        .ftop.display.title configure -text "$titleLbl"
        pack .ftop.display.title -side top -pady 40

        # Cancel button
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw

        # Standard jobs
        if {$standardTtl != "!" } {
          .ftop.input.f1.l1 configure -text "$standardTtl"
          pack .ftop.input.f1.l1 -side top -padx 10 -pady 10 -anchor w
        }
        SnazzyButton::setText .ftop.input.f1.r1.b0 $jobtype0 0.2
        SnazzyButton::setText .ftop.input.f1.r1.b1 $jobtype1 0.2
        SnazzyButton::setText .ftop.input.f1.r1.b2 $jobtype2 0.2
        SnazzyButton::setText .ftop.input.f1.r1.b3 $jobtype3 0.2
        pack .ftop.input.f1.r1.b0 -side right
        if {$jobtype1 != "!"} {
          pack .ftop.input.f1.r1.b1 -side right -padx 5
        }
        if {$jobtype2 != "!"} {
          pack .ftop.input.f1.r1.b2 -side right
        }
        if {$jobtype3 != "!"} {
          pack .ftop.input.f1.r1.b3 -side right -padx 5
        }
        pack .ftop.input.f1 -side top -padx 5 -pady 5 -anchor se \
            -fill both -expand yes

        # Record and Repeat Jobs
        if {$rrTtl != "!"} {
            .ftop.input.f2.l1 configure -text "$rrTtl"
            pack .ftop.input.f2 -side top -padx 5 -pady 5 -anchor se \
                -fill both -expand yes
            if {$jobtype0ab != "!"} {
                SnazzyButton::setText .ftop.input.f2.r2.b4 $jobtype0ab 0.2
                pack .ftop.input.f2.r2.b4 -side right
            }
            if {$jobtype5 != "!"} {
                SnazzyButton::setText .ftop.input.f2.r2.b5 $jobtype5 0.2
                pack .ftop.input.f2.r2.b5 -side right -padx 5
            }
            if {$jobrepeat != "!"} {
                SnazzyButton::setText .ftop.input.f2.r2.b6 $jobrepeat 0.2
                pack .ftop.input.f2.r2.b6 -side right
            }
        }
        
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }


    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

}
