##############################################################################
#
# vc/src/tcl/language.tcl
#
# Screen to display language selection.
#
# 20030110 QC - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop
    
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes -padx 5 -pady 10

    # Exit button
    SnazzyButton::create .ftop.input.exit btnExitKhakiU btnExitKhakiD 0.2 \
                         "beepOnce; guiExit" "Exit"
#    button .ftop.input.exit -text "Exit\nProgram" \
#            -width 10 -height 6 \
#            -background $color5 -activebackground $color5 \
#            -command { beepOnce; guiExit }

    label .ftop.display.l0 -text "line 0"
    label .ftop.display.l1 -text "line 1" -font $big_font
    label .ftop.display.l2 -text "line 2" -font $big_font
    label .ftop.display.l3 -text "line 3" -font $big_font

    frame .ftop.input.r1
    SnazzyButton::create .ftop.input.r1.b0 btnBlueU btnBlueD 0.5 \
            {beepOnce; post $DISP_BTN0_SIG 0} "English"
    SnazzyButton::create .ftop.input.r1.b1 btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN1_SIG 1" "Espaol"
    SnazzyButton::create .ftop.input.r1.b2 btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN2_SIG 2" "Franais"
    SnazzyButton::create .ftop.input.r1.b3 btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN3_SIG 3" "Deutsch"
    frame .ftop.input.r2
    SnazzyButton::create .ftop.input.r2.b4 btnBlueU btnBlueD 0.5 \
            {beepOnce; post $DISP_BTN0_SIG 4} "English"
    SnazzyButton::create .ftop.input.r2.b5 btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN1_SIG 5" "Espaol"
    SnazzyButton::create .ftop.input.r2.b6 btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN2_SIG 6" "Franais"
    SnazzyButton::create .ftop.input.r2.b7 btnBlueU btnBlueD 0.5 \
                         "beepOnce; post $DISP_BTN3_SIG 7" "Deutsch"
#    button .ftop.input.r1.b0 -text "English" \
#            -background $color3 -activebackground $color3 \
#            -height 6 -width 10 \
#            -command {beepOnce; post $DISP_BTN0_SIG 0 }
#    button .ftop.input.r1.b1  -text "English" \
#            -background $color3 -activebackground $color3 \
#            -height 6 -width 10 \
#            -command {beepOnce; post $DISP_BTN1_SIG 1 }

    # pack the exit button
    pack .ftop.input.exit -side left -padx 5 -pady 5 -anchor sw

    pack .ftop.input.r1 -side bottom -anchor se
    pack .ftop.input.r2 -side bottom -anchor se

    .ftop.display.l0 configure -text "Choose a language" -font $huge_font

    pack .ftop.display.l0 -side top -pady 5
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {} {

        pack .ftop -fill both -expand yes

    }


    proc actSetPrompt { prompt } {
	global huge_font
	.ftop.display.l0 configure -text $prompt -font $huge_font
    }

    proc actSetLanguageButton { prompt id } {
	if { $id == "0" } {
	    SnazzyButton::setText .ftop.input.r1.b0 $prompt 0.5
	    pack .ftop.input.r1.b0 -side left -padx 5 -pady 5
	}
	if { $id == "1" } {
	    SnazzyButton::setText .ftop.input.r1.b1 $prompt 0.5
	    pack .ftop.input.r1.b1 -side left -padx 5 -pady 5
	}
	if { $id == "2" } {
	    SnazzyButton::setText .ftop.input.r1.b2 $prompt 0.5
	    pack .ftop.input.r1.b2 -side left -padx 5 -pady 5
	}
	if { $id == "3" } {
	    SnazzyButton::setText .ftop.input.r1.b3 $prompt 0.5
	    pack .ftop.input.r1.b3 -side left -padx 5 -pady 5 
	}
	if { $id == "4" } {
	    SnazzyButton::setText .ftop.input.r2.b4 $prompt 0.5
	    pack .ftop.input.r2.b4 -side left -padx 5 -pady 5
	}
	if { $id == "5" } {
	    SnazzyButton::setText .ftop.input.r2.b5 $prompt 0.5
	    pack .ftop.input.r2.b5 -side left -padx 5 -pady 5
	}
	if { $id == "6" } {
	    SnazzyButton::setText .ftop.input.r2.b6 $prompt 0.5
	    pack .ftop.input.r2.b6 -side left -padx 5 -pady 5
	}
	if { $id == "7" } {
	    SnazzyButton::setText .ftop.input.r2.b7 $prompt 0.5
	    pack .ftop.input.r2.b7 -side left -padx 5 -pady 5
	}
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
