##############################################################################
#
# vc/src/tcl/entrywidgets.tcl
#
# Defines packable widgets to facilitate entry of various data types
# 
# 20080319 DEH Created
#
# Copyright (c) 2008 Novariant Inc
# All Rights Reserved. 
##############################################################################


#-------------------------------------------------------------------------
# DropDownList
#-------------------------------------------------------------------------
namespace eval DropDownList { 

    #-------------------------------------------------------------------------
    # Define and pack the dropdownlist
    #-------------------------------------------------------------------------
    # Top level frame
    frame .dropdownlist

    # display frame
    frame .dropdownlist.display
    label .dropdownlist.display.prompt
    pack .dropdownlist.display.prompt -side top -fill both -padx 5 -pady 1 \
          -expand yes

    # Input frame
    frame .dropdownlist.input

    # label
    label .dropdownlist.input.prompt -font $medium_font
    pack .dropdownlist.input.prompt -side top -anchor nw

    # spacer
    frame .dropdownlist.input.spacer -height 220 -width 0
    pack .dropdownlist.input.spacer -side left
    
    
    scrollbar .dropdownlist.input.sbar \
            -command { .dropdownlist.input.lbox yview }
    listbox .dropdownlist.input.lbox -width 35 \
            -yscrollcommand {.dropdownlist.input.sbar set}

    # pack input frame
    pack .dropdownlist.input.lbox -side left -pady 5 -fill both -expand yes
    pack .dropdownlist.input.sbar -side left -pady 5 -fill y -expand yes

    # Pack dropdownlist
    pack .dropdownlist.display -side top -pady 5 -fill both -expand yes
    pack .dropdownlist.input -side top -pady 5 -expand yes -anchor n

    # Button frame
    frame .dropdownlist.buttons

    #Utility button1
    SnazzyButton::create .dropdownlist.buttons.b0 btnBlueSquareUp btnExitKhakiSquareDown 0.5 \
                         "beepOnce; post $DISP_WIZARD_LISTBOX0_SIG 52" 
    #Utility button2
    SnazzyButton::create .dropdownlist.buttons.b1 btnBlueSquareUp btnBlueSquareDown 0.5 \
                         "beepOnce; post $DISP_WIZARD_LISTBOX1_SIG 53"
    pack .dropdownlist.buttons -side bottom -anchor se

    #-------------------------------------------------------------------------
    # Action procedures
    #-------------------------------------------------------------------------
    proc actEntry { prompt__ } {
	pack forget .dropdownlist.display
	pack forget .dropdownlist.input

        .dropdownlist.display.prompt configure -text $prompt__
	pack .dropdownlist.display.prompt -side top -padx 5 -pady 10 \
            -fill both -expand yes
	pack .dropdownlist.display -side top -pady 5 -fill both -expand yes
	pack .dropdownlist.input -side top -pady 5 -expand yes -anchor n
    }


    proc actListboxInsert { item__ } {
        .dropdownlist.input.lbox insert end $item__
    }
    

    proc actListboxSelectionSet { selectBtn__ index } {
        .dropdownlist.input.lbox selection set $index
        if { [.dropdownlist.input.lbox get $index] == "Parallel rows" } {
           SnazzyButton::setImage .dropdownlist.input.b1 \
                         btnParallelRowsU btnParallelRowsD 0.5
           SnazzyButton::setText .dropdownlist.buttons.b1 $selectBtn__ 0.2
        } else {
           SnazzyButton::setText .dropdownlist.buttons.b1 $selectBtn__ 0.5 
        }
    }

    
    proc actListboxGetCurselection {} {
        if { [.dropdownlist.input.lbox index end] != 0} {
            set index [lindex [.dropdownlist.input.lbox curselection] 0]
            return [.dropdownlist.input.lbox get $index]
        } else {
            return "!"             ;# ! tells the C side the listbox was empty
        }
    }

 
    proc actListboxGetCurindex {} {
        if { [.dropdownlist.input.lbox index end] != 0} {
            return [lindex [.dropdownlist.input.lbox curselection] 0]
        } else {
            return -1             ;# -1 tells the C side the listbox was empty
        }
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.dropdownlist.input.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .dropdownlist.input.lbox selection set $index
        .dropdownlist.input.lbox see $index
    }
    
    proc actListboxDeleteAll { } {
        .dropdownlist.input.lbox delete 0 end
    }

    proc actNewTitle { title } {
         .dropdownlist.display.prompt configure -text $title
    }

    proc actAddListBoxButtons { BtnText0 BtnText1 } {

        pack forget .dropdownlist.buttons
	pack .dropdownlist.buttons -side bottom -anchor se

        SnazzyButton::setText .dropdownlist.buttons.b0 $BtnText0 0.5
        pack .dropdownlist.buttons.b0 -side right -padx 5 -pady 5

        SnazzyButton::setText .dropdownlist.buttons.b1 $BtnText1 0.5
	pack .dropdownlist.buttons.b1 -side right -padx 5 -pady 5

    }

    proc actDeleteListBoxButtons { } {

        pack forget .dropdownlist.buttons.b0
	pack forget .dropdownlist.buttons.b1
        pack forget .dropdownlist.buttons
    }

    proc actModifySpacer {height} {

	pack forget .dropdownlist.input.spacer 
	.dropdownlist.input.spacer configure -height $height -width 0
	pack .dropdownlist.input.spacer -side left 
    }

    proc actAddListBoxPrompt {text} {

#	pack forget .dropdownlist.input.prompt

	.dropdownlist.input.prompt configure -text $text

	pack .dropdownlist.input.prompt -side top -anchor nw
    }

   proc actDeleteListBoxPrompt {} {

	pack forget .dropdownlist.input.prompt
    }
}


