##############################################################################
#
# vc/src/tcl/nmeaviewer.tcl
#
# A modal-dialog-type NMEA viewer
#
# 20081217 RCM - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Modal { 

    #-------------------------------------------------------------------------
    # Define and pack the numpad
    #-------------------------------------------------------------------------
    # Top level frame
    frame .fmodal

    # main content frame
    frame .fmodal.title
    frame .fmodal.display
    frame .fmodal.buttons
    frame .fmodal.buttons.action
    frame .fmodal.buttons.ports
    frame .fmodal.buttons.ports.row1
    frame .fmodal.buttons.ports.row2
    frame .fmodal.buttons.ports.row3

    # Title frame
    label .fmodal.title.titletxt -text "NMEA Viewer" -font $huge_font
    pack .fmodal.title.titletxt -side top -anchor n -pady 5
    
    # Divider between title and content
    label .fmodal.title.divider -image imgDivider
    pack .fmodal.title.divider -side top -anchor n -pady 5
    
    # Infor text for screen
    label .fmodal.title.infotext -text "The A5 application can only detect the GGA, VTG and RMC NMEA strings." -font $large_font
    pack .fmodal.title.infotext -side top -anchor n -pady 0

    # Display frame
    scrollbar .fmodal.display.sbar -command { .fmodal.display.disp yview }
    text .fmodal.display.disp -font $small_font -background white \
      -yscrollcommand {.fmodal.display.sbar set} -width 80 -height 12
    pack .fmodal.display.disp -side left 
    pack .fmodal.display.sbar -side left -pady 0 -fill y -anchor w
    
    # User port settings display
    label .fmodal.buttons.ports.row1.title -text "Text For User Config" \
                                  -font $large_font 
    label .fmodal.buttons.ports.row2.user1 -text "Text For User Port1 Config" \
                                  -font $medium_font
    label .fmodal.buttons.ports.row2.status -text "Text For User Port1 Config" \
                                  -font $medium_font
    label .fmodal.buttons.ports.row2.usr1Baud -text "Text For User Port1 Config" \
                                  -font $medium_font                                                             
    label .fmodal.buttons.ports.row3.user2 -text "Text For User Port2 Config" \
                                  -font $medium_font
    label .fmodal.buttons.ports.row3.status -text "Text For User Port1 Config" \
                                  -font $medium_font
    label .fmodal.buttons.ports.row3.usr2Baud -text "Text For User Port1 Config" \
                                  -font $medium_font  
                                  
    pack .fmodal.buttons.ports.row1.title -side left -padx 0
    pack .fmodal.buttons.ports.row2.user1 -side left  
    pack .fmodal.buttons.ports.row2.status -side right 
    pack .fmodal.buttons.ports.row2.usr1Baud -side left   
    pack .fmodal.buttons.ports.row3.user2 -side left
    pack .fmodal.buttons.ports.row3.status -side right    
    pack .fmodal.buttons.ports.row3.usr2Baud -side left
    
    pack .fmodal.buttons.ports.row1 -side top -padx 0 -anchor w
    pack .fmodal.buttons.ports.row2 -side top -padx 5 -anchor w
    pack .fmodal.buttons.ports.row3 -side top -padx 5 -anchor w  
    
    # Buttons frame
    SnazzyButton::create .fmodal.buttons.action.return btnKhakiU btnKhakiD 0.2 \
      "beepOnce; post $DISP_BTN9_SIG 9;" "Return To\nPrevious\nMenu"
    pack .fmodal.buttons.action.return -side left -padx 2 -pady 3 -anchor sw

    pack .fmodal.title -side top -fill x -expand yes -padx 0 -anchor n
    pack .fmodal.display -side top -fill x -expand yes -padx 10
    pack .fmodal.buttons.action -side left
    pack .fmodal.buttons.ports -side left -padx 100
    pack .fmodal.buttons -side bottom -fill x -expand yes -padx 0 -anchor s

    #-------------------------------------------------------------------------
    # Entry and exit procedures
    #-------------------------------------------------------------------------
    proc actEntry {returnBtn titleText titleInfo porttitle portLbl} {
        SnazzyButton::setText .fmodal.buttons.action.return $returnBtn 0.5
        .fmodal.title.titletxt configure -text $titleText 
        .fmodal.title.infotext configure -text $titleInfo
        .fmodal.buttons.ports.row1.title configure -text $porttitle
		.fmodal.buttons.ports.row2.user1 configure -text "${portLbl}1:"
		.fmodal.buttons.ports.row2.status configure -text "Status"
		.fmodal.buttons.ports.row2.usr1Baud configure -text "Baud Rate"      
		.fmodal.buttons.ports.row3.user2 configure -text "${portLbl}2:"
		.fmodal.buttons.ports.row3.status configure -text "Status"
		.fmodal.buttons.ports.row3.usr2Baud configure -text "Baud Rate"
        pack .fmodal -fill both -expand yes
    }

    proc actExit {} {
        destroy .fmodal
        pack .ftop -fill both -expand yes
    }

    #-------------------------------------------------------------------------
    # Action procedures
    #-------------------------------------------------------------------------
    proc actDisplayNMEAString {NMEAStr__} {
      regsub -all {[\r]} $NMEAStr__ "" newStr
      .fmodal.display.disp insert 1.0 $newStr
    }
    
    proc actDispUsr1Config { status__ baud__ } {
      .fmodal.buttons.ports.row2.status configure -text $status__
      .fmodal.buttons.ports.row2.usr1Baud configure -text $baud__  
    } 
    
    proc actDispUsr2Config { status__ baud__ } {
      .fmodal.buttons.ports.row3.status configure -text $status__
      .fmodal.buttons.ports.row3.usr2Baud configure -text $baud__  
    }

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    

}
