##############################################################################
#
# vc/src/tcl/rmassert.tcl
#
# Screen to show RM Assert Logs
#
# 20050513 SSJ - created
#
# Copyright (c) 2005 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "Roof Module Assert Log"

    frame .ftop.input
    
    frame .ftop.input.display

    # Display Frame - displays 1 line of text at a time
    label .ftop.input.display.l0 -text ".... Loading ...." -font $medium_font

	#frequecy list box
    frame .ftop.input.listfreqframe
    scrollbar .ftop.input.listfreqframe.sbar -orient vertical -width 30 \
            -command { .ftop.input.listfreqframe.lbox yview }
    listbox .ftop.input.listfreqframe.lbox -background white -font $medium_font\
            -yscrollcommand {.ftop.input.listfreqframe.sbar set} \
			-width 60 -height 30
    pack .ftop.input.listfreqframe.sbar -side right -fill y
    pack .ftop.input.listfreqframe.lbox -side right

    # button frame
    frame .ftop.r1
    SnazzyButton::create .ftop.r1.b0 btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN0_SIG 0;"
    pack .ftop.r1.b0 -side right

    # Pack .ftop
    pack .ftop.title -side top -pady 10
    pack .ftop.r1 -side right -anchor se -padx 5 -pady 5
	pack .ftop.input.display.l0 -side top
    pack .ftop.input.display -side top -fill both -expand yes
    pack .ftop.input.listfreqframe -side bottom
    pack .ftop.input -side bottom -padx 5 -pady 5
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { titleLbl okBtn } {
		global huge_font

        .ftop.title configure -text $titleLbl -font $huge_font
        .ftop.r1.b0 configure -state disabled
 
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actShowOkBtn {okBtn} {
        .ftop.r1.b0 configure -state normal
        SnazzyButton::setText .ftop.r1.b0 $okBtn 0.5
    }

    proc actDispErrTypeLbl { errLbl } {
        global medium_font

        .ftop.input.display.l0 configure -text $errLbl -font $medium_font
    }

    proc actListboxInsert { item } {
        .ftop.input.listfreqframe.lbox insert end $item
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.input.listfreqframe.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.input.listfreqframe.lbox selection set $index
        .ftop.input.listfreqframe.lbox see $index
    }

    proc actListboxGetCurselection {} {
        if { [.ftop.input.listfreqframe.lbox index end] != 0} {
            set index [lindex [.ftop.input.listfreqframe.lbox curselection] 0]
            return [.ftop.input.listfreqframe.lbox get $index]
        } else {
            return "!"             ;# ! tells the C side the listbox was empty
        }
    }

    proc actListboxGetCurindex {} {
      if { [.ftop.input.listfreqframe.lbox index end] != 0} {
          return [lindex [.ftop.input.listfreqframe.lbox curselection] 0]
      } else {
          return -1             ;# -1 tells the C side the listbox was empty
      }
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
