##############################################################################
#
# vc/src/tcl/samdiagnostics.tcl
#
# Screen to show SAM diagnostics messages.
#
# 20040916 QC - created
#
# Copyright (c) 2004 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout

    # Title
    label .ftop.title -text "SAM Diagnostics"

    frame .ftop.input
    frame .ftop.input.listboxframe
    scrollbar .ftop.input.listboxframe.sbar -orient vertical -width 30 \
            -command { .ftop.input.listboxframe.lbox yview }
    listbox .ftop.input.listboxframe.lbox -font $big_font \
            -yscrollcommand {.ftop.input.listboxframe.sbar set} \
            -width 60 -height 4
    pack .ftop.input.listboxframe.sbar -side right -fill y
    pack .ftop.input.listboxframe.lbox -side right

    frame .ftop.input.textboxframe
    scrollbar .ftop.input.textboxframe.sbar -orient vertical -width 30 \
            -command [list .ftop.input.textboxframe.txt yview]
    text .ftop.input.textboxframe.txt -background white -width 55 -height 20 \
            -font $big_font \
            -yscrollcommand [list .ftop.input.textboxframe.sbar set]
    pack .ftop.input.textboxframe.sbar -side right -anchor se -fill y
    pack .ftop.input.textboxframe.txt -side right

    # Cancel/Accept frame
    frame .ftop.input2
    SnazzyButton::create .ftop.input2.cancel \
                 btnKhakiU btnKhakiD 0.5 \
                 "beepOnce; post $DISP_BTN9_SIG 9;" "Return To Previous Menu"
        
    pack .ftop.input2.cancel -side left

    # Pack .ftop
    pack .ftop.title -side top -pady 10
    pack .ftop.input2 -side left -anchor sw -padx 5 -pady 5
    pack .ftop.input.listboxframe -side top
    pack .ftop.input.textboxframe -side bottom
    pack .ftop.input -side bottom -padx 5 -pady 5
                
    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { titleLbl returnBtn } {
        .ftop.title configure -text $titleLbl
        SnazzyButton::setText .ftop.input2.cancel $returnBtn 0.5
 
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

    proc actTextboxInsert { msg } {
        .ftop.input.textboxframe.txt insert 1.0 $msg
        set lastLineIndex [.ftop.input.textboxframe.txt index end]
        if { $lastLineIndex > 100 } {
          .ftop.input.textboxframe.txt delete [expr $lastLineIndex - 10] end
        }
    }

    proc actListboxInsert { item } {
        .ftop.input.listboxframe.lbox insert end $item
    }

    proc actListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.input.listboxframe.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.input.listboxframe.lbox selection set $index
        .ftop.input.listboxframe.lbox see $index
    }

    bind .ftop.input.listboxframe.lbox <ButtonPress-1> {
      beepOnce; post $DISP_BTN1_SIG 1;  
    } 

    proc actListboxGetCurindex {} {
      if { [.ftop.input.listboxframe.lbox index end] != 0} {
          return [lindex [.ftop.input.listboxframe.lbox curselection] 0]
      } else {
          return -1             ;# -1 tells the C side the listbox was empty
      }
    }

    proc actHighLightBtn {subMsgId} {
        .ftop.input.listboxframe.lbox selection set $subMsgId
        .ftop.input.listboxframe.lbox see $subMsgId
    }

    proc actTextboxDeleteAll { } {
      .ftop.input.textboxframe.txt delete 1.0 end
    }

    #-------------------------------------------------------------------------
    # Delegated procedures
    #-------------------------------------------------------------------------

    #-------------------------------------------------------------------------
    # Local procedures
    # {MLE-020418: Tcl/Tk goal should be to get rid of all local procedures, 
    # because they represent intelligence, which the display should not have.}
    #-------------------------------------------------------------------------
    # Local procedures
}
