##############################################################################
#
# vc/src/tcl/specialrows.tcl
#
# Iconify Job Type Selection screen
#
# 20040216 QC - created
#
# Copyright (c) 2004 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop

    # Define and pack the screen layout
    # Screen has display and input frames
    frame .ftop.display         ;# Display Frame
    frame .ftop.input           ;# Input Frame
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes

    # Cancel button
    SnazzyButton::create .ftop.input.cancel btnKhakiU btnKhakiD 0.5 \
            "beepOnce; post $DISP_BTN9_SIG 9" "Cancel"

    # Display Frame
    label .ftop.display.title -text "Title" -font $huge_font

    # Input frame 
    #   - up to 2 rows of up to 4 buttons each
    frame .ftop.input.r1
    SnazzyButton::create .ftop.input.r1.b0 btnParallelRowsU btnParallelRowsD \
            0.5 "beepOnce; post $DISP_BTN0_SIG 0" "ParallelRows"
    SnazzyButton::create .ftop.input.r1.b1 btnFanRowsU btnFanRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 1" "FanRows"
    SnazzyButton::create .ftop.input.r1.b2 btnBoxRowsU btnBoxRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 2" "BoxRows"
    SnazzyButton::create .ftop.input.r1.b3 btnCircleRowsU btnCircleRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 3" "CircleRows"

    frame .ftop.input.r2
    SnazzyButton::create .ftop.input.r2.b4 btnCurveRowsU btnCurveRowsD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 4" "CurveRows"
    SnazzyButton::create .ftop.input.r2.b5 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 5" "Repeat job"
    SnazzyButton::create .ftop.input.r2.b6 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 6" "Button 6"
    SnazzyButton::create .ftop.input.r2.b7 btnBlueU btnBlueD 0.5 \
            "beepOnce; post $DISP_BTN0_SIG 7" "Button 7"

    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry {titleLbl jobname cancelBtn jobtype0 jobtype1 jobtype2 \
                   jobtype3 jobtype5 jobrepeat} {
        .ftop.display.title configure -text "$titleLbl $jobname"
        SnazzyButton::setText .ftop.input.cancel $cancelBtn 0.5
        SnazzyButton::setText .ftop.input.r1.b0 $jobtype0 0.2
        SnazzyButton::setText .ftop.input.r1.b1 $jobtype1 0.2
        SnazzyButton::setText .ftop.input.r1.b2 $jobtype2 0.2
        SnazzyButton::setText .ftop.input.r1.b3 $jobtype3 0.2
        pack .ftop.display.title -side top -pady 40
        pack .ftop.input.cancel -side left -padx 5 -pady 5 -anchor sw
        pack .ftop.input.r1 -side bottom -padx 5 -pady 5 -anchor se
        pack .ftop.input.r2 -side bottom -padx 5 -pady 5 -anchor se
        pack .ftop.input.r1.b0 -side right
        pack .ftop.input.r1.b1 -side right -padx 5
        pack .ftop.input.r1.b2 -side right
        pack .ftop.input.r1.b3 -side right -padx 5
        if {$jobtype5 != "!"} {
          SnazzyButton::setText .ftop.input.r2.b4 $jobtype5 0.2
          pack .ftop.input.r2.b4 -side right
        }
        if {$jobrepeat != "!"} {
          SnazzyButton::setText .ftop.input.r2.b5 $jobrepeat 0.2
          pack .ftop.input.r2.b5 -side right
        }
        
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }


    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------

}
