##############################################################################
#
# vc/src/tcl/steeringresponsepanel.tcl
#
# Defines packable widgets to facilitate entry of various data types
# 
# 20080319 DEH Created
#
# Copyright (c) 2008 Novariant Inc
# All Rights Reserved. 
##############################################################################


#-------------------------------------------------------------------------
# SteeringResponsePanel
#-------------------------------------------------------------------------
namespace eval SteeringResponsePanel {

    set rsp 100

    #-------------------------------------------------------------------------
    # Define and pack the SteeringResponsePanel
    #-------------------------------------------------------------------------
    # Top level frame
    frame .steeringresponsepanel

    # Coulter Angle Frame
    frame .steeringresponsepanel.left
    frame .steeringresponsepanel.left.top
    frame .steeringresponsepanel.left.center
    frame .steeringresponsepanel.left.bottom
    label .steeringresponsepanel.left.top.label -text "Coulter Angle" -font $small_font
    label .steeringresponsepanel.left.bottom.coulterAngle -text "xxx" -font $small_font
    
    # Toggle button to rotate between coulter angle, voltage counts
    SnazzyButton::create .steeringresponsepanel.left.top.b2 btnBlueMU btnBlueMD 0.5 \
                         "beepOnce; post $DISP_WIZARD_TOGGLE_COULTER_RSP_SIG 59" 
    SnazzyButton::setText .steeringresponsepanel.left.top.b2 "TOGGLE" 0.5

    pack .steeringresponsepanel.left.top.b2 -side top -anchor n
    pack .steeringresponsepanel.left.top.label -side top -anchor n -fill x -expand yes -pady 3
    pack .steeringresponsepanel.left.bottom.coulterAngle -side top -anchor n -padx 3
    pack .steeringresponsepanel.left.top -side top
    pack .steeringresponsepanel.left.center -side top
    pack .steeringresponsepanel.left.bottom -side top
    pack .steeringresponsepanel.left -side left -padx 10 -fill both -expand yes

    frame .steeringresponsepanel.leftsep -height 220 -width 2 -borderwidth 0 \
            -background $colorInx
    pack .steeringresponsepanel.leftsep -side left

    # Button and text middle frame
    # middle1 and middle3 are padding
    frame .steeringresponsepanel.middle1 -width 50
    frame .steeringresponsepanel.middle2
    frame .steeringresponsepanel.middle2.toptext
    frame .steeringresponsepanel.middle2.buttons
    frame .steeringresponsepanel.middle2.bottomtext
    frame .steeringresponsepanel.middle3 -width 50

    # left Arrow
    SnazzyButton::create .steeringresponsepanel.middle2.buttons.b0 btnBigLeftNudgeU btnBigLeftNudgeU 0.5 \
                         "beepOnce; post $DISP_WIZARD_NUDGE_LEFT_SIG 55" 
    # Stop Button
    SnazzyButton::create .steeringresponsepanel.middle2.buttons.b1 btnBigStopU btnBigStopD 0.5 \
                         "beepOnce; post $DISP_WIZARD_STOP_SIG 54" 
    # right Arrow    
    SnazzyButton::create .steeringresponsepanel.middle2.buttons.b2 btnBigRightNudgeU btnBigRightNudgeU 0.5 \
                         "beepOnce; post $DISP_WIZARD_NUDGE_RIGHT_SIG 56" 
    
    # more text (per marketing swapping top with bottom)
    label .steeringresponsepanel.middle2.toptext.l1 -text "" -font $small_font
    label .steeringresponsepanel.middle2.bottomtext.l1 -text "" -font $small_font
    label .steeringresponsepanel.middle2.bottomtext.l2 -text "" -font $small_font
 
    # Pack .steeringresponsepanel.middle
    # (per marketing swapping top with bottom)
    pack .steeringresponsepanel.middle2.bottomtext.l2 -side bottom -pady 5 -anchor se
    pack .steeringresponsepanel.middle2.bottomtext.l1 -side bottom -pady 5
    pack .steeringresponsepanel.middle2.bottomtext -side top -pady 10 -pady 5

    pack .steeringresponsepanel.middle2.buttons.b0 -side left -anchor w
    pack .steeringresponsepanel.middle2.buttons.b1 -side left
    pack .steeringresponsepanel.middle2.buttons.b2 -side left
    pack .steeringresponsepanel.middle2.buttons -side top -pady 10 -pady 5

    # (per marketing swapping top with bottom)
    pack .steeringresponsepanel.middle2.toptext.l1 -side top -pady 5
    pack .steeringresponsepanel.middle2.toptext -side bottom -pady 5

    pack .steeringresponsepanel.middle1 -side left -pady 5
    pack .steeringresponsepanel.middle2 -side left -pady 5
    pack .steeringresponsepanel.middle3 -side left -pady 5

    # percentage Voltage Output frame

    frame .steeringresponsepanel.rightsep -height 220 -width 2 -borderwidth 0 \
            -background $colorInx
    pack .steeringresponsepanel.rightsep -side left

    frame .steeringresponsepanel.right
    label .steeringresponsepanel.right.label -text "" -font $small_font
    label .steeringresponsepanel.right.labelstored -text "" -font $small_font
    label .steeringresponsepanel.right.labelstoredvalue -text "" -font $small_font
    label .steeringresponsepanel.right.labelcurrent -text "" -font $small_font
    label .steeringresponsepanel.right.labelcurrentvalue -text "" -font $small_font

    SnazzyButton::create .steeringresponsepanel.right.b0 btnBlueMU btnBlueMD 0.5 \
                         "beepOnce; post $DISP_WIZARD_TOGGLE_STEERING_RSP_SIG 57" 
    SnazzyButton::setText .steeringresponsepanel.right.b0 "TOGGLE" 0.5
 
    SnazzyButton::create .steeringresponsepanel.right.b1 btnBlueS4U btnBlueS4D 0.5 \
                         "beepOnce; post $DISP_WIZARD_FIND_STEERING_RSP_SIG 58" 
    SnazzyButton::setText .steeringresponsepanel.right.b1 "FIND" 0.5

    scale .steeringresponsepanel.right.slider -from 100 -to 0 -orient vertical \
           -label "" -tickinterval 50 -showvalue true -variable rsp

    pack .steeringresponsepanel.right.b0 -side top -anchor n
    pack .steeringresponsepanel.right.label -side top -fill x -pady 3
    pack .steeringresponsepanel.right.slider -side top -anchor n
    pack .steeringresponsepanel.right -side right -padx 10 -fill both -expand yes


    proc initResponseRate { } {
	  global rsp
	  set rsp 100
	  .steeringresponsepanel.right.slider set 100
    }

    proc actGetResponseRate {  } {
	  global rsp
	  return $rsp
    }
	
    proc actShowAngleWidget {} {
	  pack .glImplementStatusDisp -in .steeringresponsepanel.left.center \
	                              -side bottom -anchor s
	  raise .glImplementStatusDisp
    }

    proc actDisplayWarning { informText warningText riskStatement } {
      .steeringresponsepanel.middle2.toptext.l1 configure -text $informText
      .steeringresponsepanel.middle2.bottomtext.l1 configure -text $warningText -foreground red
      .steeringresponsepanel.middle2.bottomtext.l2 configure -text $riskStatement 
    }

    proc actRemoveWarning { } {

        pack forget .steeringresponsepanel.toptext.l1 
        pack forget .steeringresponsepanel.bottomtext.l1 
        pack forget .steeringresponsepanel.bottomtext.l2 
    }

    proc actUpdateLeft {CoulterAngleText} {

      .steeringresponsepanel.left.top.label configure -text $CoulterAngleText
    }

    proc actUpdateCoulterAngle {CoulterAngleValue} {

      .steeringresponsepanel.left.bottom.coulterAngle configure -text $CoulterAngleValue
    }

   proc actUpdateRight {VoltagePercentText CurrentLabel CurrentValue StoredLabel StoredValue } {

      .steeringresponsepanel.right.label configure -text $VoltagePercentText

      .steeringresponsepanel.right.labelcurrent  configure -text $CurrentLabel

      .steeringresponsepanel.right.labelcurrentvalue configure -text $CurrentValue

      .steeringresponsepanel.right.labelstored configure -text $StoredLabel

      .steeringresponsepanel.right.labelstoredvalue configure -text $StoredValue
    }

   proc actToggleRight {whichOne__ labelText__} {

       if {$whichOne__ == 1} {

	    .steeringresponsepanel.right.label configure -text $labelText__
	    pack forget .steeringresponsepanel.right.slider

	    #  MAX RATE SCREEN

	    pack .steeringresponsepanel.right.b0 -side top -anchor n
	    pack .steeringresponsepanel.right.label -side top

        pack .steeringresponsepanel.right.labelstored -side top -pady 2
	    pack .steeringresponsepanel.right.labelstoredvalue -side top -pady 5
	    pack .steeringresponsepanel.right.labelcurrent -side top -pady 2
	    pack .steeringresponsepanel.right.labelcurrentvalue -side top -pady 2
	    pack .steeringresponsepanel.right.b1 -side top -anchor n -pady 20

	    pack .steeringresponsepanel.right -side right

	} else {

	    .steeringresponsepanel.right.label configure -text $labelText__

	    pack forget .steeringresponsepanel.right.labelcurrent
	    pack forget .steeringresponsepanel.right.labelcurrentvalue
	    pack forget .steeringresponsepanel.right.labelstored
	    pack forget .steeringresponsepanel.right.labelstoredvalue
	    pack forget .steeringresponsepanel.right.b1
 
	    #  OUTPUT SCALE SLIDER SCREEN

	    pack .steeringresponsepanel.right.b0 -side top -anchor n
	    pack .steeringresponsepanel.right.label -side top
	    pack .steeringresponsepanel.right.slider -side top

	    pack .steeringresponsepanel.right -side right -fill both -expand yes
        }
        
    }

}

