##############################################################################
#
# vc/src/tcl/survey.tcl
#
# Survey screen
#
# 20020408 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 

    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it in sExit
    frame .ftop

    # Input Frame
    frame .ftop.input

    # Buttons
    SnazzyButton::create .ftop.input.start \
        btnStartSurveyU btnStartSurveyD 0.5 \
        "beepOnce; post $DISP_BTN0_SIG 0" "Start"
    pack .ftop.input.start -side right -padx 5 -pady 5 -anchor se
    SnazzyButton::create .ftop.input.toggle \
        btnBlueU btnBlueD 0.5 \
        "beepOnce; post $DISP_BTN2_SIG 2" "Toggle Accuracy"
    SnazzyButton::create .ftop.input.skip btnKhakiU btnKhakiD 0.5 \
        "beepOnce; post $DISP_BTN9_SIG 9" "Skip Survey"
    pack .ftop.input.skip -side left -padx 5 -pady 5 -anchor sw
    SnazzyButton::create .ftop.input.examineGps btnKhakiU btnKhakiD 0.5 \
        "beepOnce; post $DISP_BTN1_SIG 0" "Examine\nGPS"
    pack .ftop.input.examineGps -side left -padx 5 -pady 5 -anchor sw
    pack .ftop.input -side left -anchor sw

    # Display Frame
    frame .ftop.display
    label .ftop.display.l 
    pack .ftop.display.l -side top -pady 15

    # Survey progress frame
    frame .ftop.display.progress

    label .ftop.display.progress.l1
    pack .ftop.display.progress.l1 -side top

    set barWidth 400
    set barHeight 20
    canvas .ftop.display.progress.bar -background $color6 \
            -width $barWidth -height $barHeight -relief sunken -borderwidth 2
    incr barHeight        
    .ftop.display.progress.bar create rectangle 0 0 0 $barHeight \
            -outline black -fill $colorMedium -tags gauge
    .ftop.display.progress.bar create text [expr $barWidth/2] 4 \
            -font $small_font -anchor nw -text "0%" -tags value
    pack .ftop.display.progress.bar -side bottom

    # Pack the various elements
    pack .ftop.input -side bottom -fill both -expand yes -anchor s
    pack .ftop.display -side bottom -fill both -expand yes
    pack .configDisplay -in .ftop -side left -anchor nw -fill y -expand yes \
            -pady 10 -padx 10
    raise .configDisplay
    pack .navDisplay -in .ftop -side right -anchor ne -pady 10 -padx 10
    raise .navDisplay


    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {
        
        eval $packProc__
        pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }


    #-------------------------------------------------------------------------
    # Screen action procedures (to be called by GuiMgr)
    #-------------------------------------------------------------------------
    # Update procedures of this template can be called by the GuiMgr
    proc actProgress { percentComplete color } {
        .ftop.display.progress.bar itemconfigure gauge -fill $color
        .ftop.display.progress.bar itemconfigure value -text "$percentComplete%"

        # MLE-040301: Tcl doing math!! Not allowed; fix this...
        .ftop.display.progress.bar coords gauge 1 1 \
             [expr 0.01*$percentComplete*$Screen::barWidth] $Screen::barHeight
    }

    #-------------------------------------------------------------------------
    # Local procedures
    #-------------------------------------------------------------------------

    proc packStartSurvey {stopTractor startSurvey toggleBtn skipBtn \
                              examineGpsBtn} {
        .ftop.display.l configure -text $stopTractor
        SnazzyButton::setText .ftop.input.start $startSurvey 0.95
        if {$toggleBtn != "!"} {
          SnazzyButton::setText .ftop.input.toggle $toggleBtn 0.5
          pack .ftop.input.toggle -side right -padx 5 -pady 5 -anchor se
        }
        SnazzyButton::setText .ftop.input.skip $skipBtn 0.5
        SnazzyButton::setText .ftop.input.examineGps $examineGpsBtn 0.5
    }

    proc actToggleAccuracyMode {toggleBtn} {
        SnazzyButton::setText .ftop.input.toggle $toggleBtn 0.5        
    }

    proc packSurveyInProgress { doNotMoveTxt__ surveyProgressTxt__ \
                                skipBtn examineGpsBtn } {
        .ftop.display.l configure -text $doNotMoveTxt__
        .ftop.display.progress.l1 configure -text $surveyProgressTxt__
        SnazzyButton::setText .ftop.input.skip $skipBtn 0.5
        SnazzyButton::setText .ftop.input.examineGps $examineGpsBtn 0.5
        pack forget .ftop.input.start
        pack .ftop.display.progress -side bottom -padx 40 -pady 15
    }
}
 
