##############################################################################
#
# vc/src/tcl/tuningpanel.tcl
#
# generic tuning panel
#
# 20080406 DEH - created
#
# Copyright (c) 2008 Novariant Inc.
# All Rights Reserved. 
##############################################################################
namespace eval TuningPanel { 

    #-------------------------------------------------------------------------
    # Define and pack the tuningpanel
    #-------------------------------------------------------------------------
    # Top level frame
    frame .tuningpanel

    # This screen is divided into three panels
    frame .tuningpanel.view
    frame .tuningpanel.control
    frame .tuningpanel.view.l
    frame .tuningpanel.view.r

    # Adjustable Parameters Subframe
    frame .tuningpanel.control.params 

    label .tuningpanel.control.params.l -text "Control Gain:" -font $medium_font
    label .tuningpanel.control.params.e -text "0" -anchor w\
          -font $medium_font -width 8 -relief sunken -borderwidth 2
    button .tuningpanel.control.params.change -text "Change" \
            -command { beepOnce; post $DISP_BTN1_SIG 0 } \
            -width 5 -height 1 \
            -background $color3 -activebackground $color3
    pack .tuningpanel.control.params.l -side left -padx 3
    pack .tuningpanel.control.params.e -side left -padx 3
    pack .tuningpanel.control.params.change -side left -padx 3
    pack .tuningpanel.control.params -side top -pady 10

    # Step-Response Subframe
    frame .tuningpanel.control.step

    button .tuningpanel.control.step.zero -text "0" \
         -command { beepOnce; post $DISP_BTN2_SIG 0 } \
         -width 3 -height 1 \
         -background $color3 -activebackground $color3

    frame .tuningpanel.control.step.neg
    button .tuningpanel.control.step.neg.b1 -text "<" \
         -command { beepOnce; post $DISP_BTN2_SIG 1 } \
         -width 3 -height 1 \
         -background $color3 -activebackground $color3
    button .tuningpanel.control.step.neg.b2 -text "<<" \
         -command { beepOnce; post $DISP_BTN2_SIG 2 } \
         -width 3 -height 1 \
         -background $color3 -activebackground $color3

    frame .tuningpanel.control.step.pos
    button .tuningpanel.control.step.pos.b1 -text ">" \
         -command { beepOnce; post $DISP_BTN2_SIG 3 } \
         -width 3 -height 1 \
         -background $color3 -activebackground $color3
    button .tuningpanel.control.step.pos.b2 -text ">>" \
         -command { beepOnce; post $DISP_BTN2_SIG 4 } \
         -width 3 -height 1 \
         -background $color3 -activebackground $color3

    pack .tuningpanel.control.step.neg.b2 -side left
    pack .tuningpanel.control.step.neg.b1 -side left
    pack .tuningpanel.control.step.neg -side left
    pack .tuningpanel.control.step.zero -side left
    pack .tuningpanel.control.step.pos.b1 -side left
    pack .tuningpanel.control.step.pos.b2 -side left
    pack .tuningpanel.control.step.pos -side left

    pack .tuningpanel.view.l -side left -padx 5 -anchor ne
    pack .tuningpanel.view.r -side right -padx 5 -anchor nw
    pack .tuningpanel.view -side top -expand yes -fill x
    pack .tuningpanel.control.step -side top -pady 5
    pack .tuningpanel.control.params -side top -pady 5
    pack .tuningpanel.control -side top -expand yes -fill x

    frame .tuningpanel.control.stopgo

    SnazzyUnclippedButton::create .tuningpanel.control.stopgo.stop \
	btnSmallStopU btnSmallStopD 0.5 "beepOnce; post $DISP_WIZARD_SELECT_SIG 45"
    SnazzyUnclippedButton::create .tuningpanel.control.stopgo.go \
	btnSmallGoU btnSmallGoD 0.5 "beepOnce; post $DISP_WIZARD_SELECT_SIG 45"
    

    proc actShowAngleWidget {} {
	pack .glImplementStatusDisp -in .tuningpanel.view.r -side top -fill both -expand yes
	raise .glImplementStatusDisp
    }

    proc actForgetControl {} {
	pack forget .tuningpanel.control.step
	pack forget .tuningpanel.control.params
	pack forget .tuningpanel.control
    }

    proc actPackStepped {} {
	actForgetControl
	# Pack the various elements
	pack .tuningpanel.control.step -side top -pady 5
	pack .tuningpanel.control.params -side top -pady 5
	pack .tuningpanel.control -side top -expand yes -fill x
    }

    proc actPackUnStepped {} {
	actForgetControl
	pack .tuningpanel.control.params -side top -pady 5
	pack .tuningpanel.control -side top -expand yes -fill x
    }

    proc actShowGraph {} {
	pack forget .glContDataDisp.panel.input
	pack .glContDataDisp -in .tuningpanel.view.l -side top -fill both -expand yes 
	raise .glContDataDisp
    }

     proc actShowGoButton {} {
	pack forget .tuningpanel.control.stopgo.stop
	pack .tuningpanel.control.stopgo.go
    }

     proc actShowStopButton {} {
	pack forget .tuningpanel.control.stopgo.go
	pack .tuningpanel.control.stopgo.stop
    }

    proc actUnHighlightStepButtons { } {
        global color3 colorGood
        .tuningpanel.control.step.zero configure -text "0"
        .tuningpanel.control.step.zero configure -background $color3 \
                                    -activebackground $color3
        .tuningpanel.control.step.neg.b1 configure -background $color3 \
                                    -activebackground $color3
        .tuningpanel.control.step.neg.b2 configure -background $color3 \
                                    -activebackground $color3
        .tuningpanel.control.step.pos.b1 configure -background $color3 \
                                    -activebackground $color3
        .tuningpanel.control.step.pos.b2 configure -background $color3 \
                                    -activebackground $color3
    }

    proc actHighlightStepButton {thisButton value} {
        # {MLE-030218: C side knows a little too much here in passing in 
        # .tuningpanel.control.step.pos.b3 etc., maybe can clean up later. }
        global color3 colorGood
        .tuningpanel.control.step.zero configure -text $value
        $thisButton configure -background $colorGood \
                                    -activebackground $colorGood
    }

    proc actSetGain { D10_K__ } {
        .tuningpanel.control.params.e configure -text $D10_K__
    }

    proc actSetGainLabel { gain } {
	.tuningpanel.control.params.l configure -text $gain
    } 
}
