##############################################################################
#
# vc/src/tcl/menu.tcl
#
# A configurable, reusable 8 button menu screen. Includes listbox with 
# scrollbar if desired.
#
# 20020701 MLE - created
#
# Copyright (c) 2002 IntegriNautics Corporation.
# All Rights Reserved. 
##############################################################################
namespace eval Screen { 
    set deflanguage     0
    set userlevel       0
    set flexmode        0
    set userlevelInd    0
    set deflanguageInd  0
    # $framelblue -padx 5 -pady 5
    #-------------------------------------------------------------------------
    # Define and pack the screen
    #-------------------------------------------------------------------------
    # All screens must create a top level frame .ftop and destroy it on exit
    frame .ftop 
    frame .ftop.title
    label .ftop.title.txt -text "User Preferences" -font $huge_font

    # Divider between title and content
    #-------------------------------------------------------------------------
    label .ftop.title.divider -image imgDivider 

    # pack title
    #-------------------------------------------------------------------------
    pack .ftop.title.txt -side top
    pack .ftop.title.divider -side top
    pack .ftop.title -side top


    #define a frame for user settings
    #-------------------------------------------------------------------------
    frame .ftop.user

    #define a frame for user language settings
    #we would like to use the relevant enum here, but the limitations
    #of tcl (or atleast of our use of tcl) disallow that
    #-------------------------------------------------------------------------
    frame .ftop.user.language 
    frame .ftop.user.language.main -bd 1 -relief solid
    frame .ftop.user.language.main.title -bd 1 -relief solid -bg lightgray
    frame .ftop.user.language.main.body -bd 1 -relief solid
    frame .ftop.user.language.main.body.r1
    frame .ftop.user.language.main.body.r2
    
    label .ftop.user.language.main.title.text -text "User Language" -font $medium_font \
      -bg lightgray 
    radiobutton .ftop.user.language.main.body.r1.prompt -text "Set Default Language" -font $medium_font        \
                 -variable defLanguage -value 0 -command "beepOnce; post $DISP_BTN4_SIG 9" 
    scrollbar .ftop.user.language.main.body.r2.sbar \
      -command { .ftop.user.language.main.body.r2.lbox yview } \
      -width 20
    listbox .ftop.user.language.main.body.r2.lbox \
      -yscrollcommand {.ftop.user.language.main.body.r2.sbar set} \
      -width 30 -height 1 \
      -font $medium_font -exportselection no

    #pack the language frame
    #-------------------------------------------------------------------------
    pack .ftop.user.language.main.body.r1.prompt -side top
    pack .ftop.user.language.main.body.r2.lbox -side left -pady 5 -fill both -expand yes
    pack .ftop.user.language.main.body.r2.sbar -side left -pady 5 -fill y
    pack .ftop.user.language.main.body.r1 -side top
    pack .ftop.user.language.main.body.r2 -side top
    pack .ftop.user.language.main.title.text -side left -anchor w -fill x
    pack .ftop.user.language.main.title -side top -anchor n -fill x -expand yes
    pack .ftop.user.language.main.body -side bottom -anchor sw -fill x -expand yes
    pack .ftop.user.language.main -side top -anchor sw -fill x -expand yes

    #define a frame for user level
    #-------------------------------------------------------------------------
    frame .ftop.user.level
    frame .ftop.user.level.main -bd 1 -relief solid
    frame .ftop.user.level.main.title -bd 1 -relief solid -bg lightgray
    frame .ftop.user.level.main.body -bd 1 -relief solid
    frame .ftop.user.level.main.body.r1
    frame .ftop.user.level.main.body.r2
    label .ftop.user.level.main.title.text -text "User Level" -font $medium_font -bg lightgray
    radiobutton .ftop.user.level.main.body.r1.prompt -text "Set User Level" -font $medium_font \
                 -variable userlevel -value 0  -command "beepOnce; post $DISP_BTN5_SIG 9" 
    scrollbar .ftop.user.level.main.body.r2.sbar \
      -command { .ftop.user.level.main.body.r2.lbox yview } \
      -width 20
    listbox .ftop.user.level.main.body.r2.lbox \
      -yscrollcommand {.ftop.user.level.main.body.r2.sbar set} \
      -width 30 -height 1 \
      -font $medium_font -exportselection no

    #pack the level frame
    #-------------------------------------------------------------------------
    pack .ftop.user.level.main.body.r1.prompt -side top -anchor n -expand yes
    pack .ftop.user.level.main.body.r2.lbox -side left -pady 5 -fill both -expand yes
    pack .ftop.user.level.main.body.r2.sbar -side left -pady 5 -fill y
    pack .ftop.user.level.main.body.r1 -side top -anchor n
    pack .ftop.user.level.main.body.r2 -side top
    pack .ftop.user.level.main.title.text -side left -anchor w -fill x
    pack .ftop.user.level.main.title -side top -anchor se -fill x -expand yes
    pack .ftop.user.level.main.body -side bottom -anchor se -fill x -expand yes
    pack .ftop.user.level.main -side top -anchor sw -fill x -expand yes

    #pack the user frame
    #-------------------------------------------------------------------------
    pack .ftop.user.language -side left -anchor sw -padx 5 -fill x -expand yes
    pack .ftop.user.level -side right -anchor se -padx 5 -fill x -expand yes

    #Define a frame for gps performance slider
    #-------------------------------------------------------------------------
    frame .ftop.flexmode
    frame .ftop.flexmode.main -bd 1 -relief solid
    frame .ftop.flexmode.main.title -bd 1 -relief solid -bg lightgray
    frame .ftop.flexmode.main.body -bd 1 -relief solid
    
    label .ftop.flexmode.main.title.text -text "Flex Mode Setting" \
      -font $medium_font -bg lightgray
    
    #divide the rest of the frame into three rows: Accuracy, FlexMode, GPS Mode
    #-------------------------------------------------------------------------
    frame .ftop.flexmode.main.body.r1; # Flexmode Accuracy
    frame .ftop.flexmode.main.body.r2; # Flexmode Slider
    frame .ftop.flexmode.main.body.r3; # Flexmode GPS Mode
    
    #Divide the first row into seven horizontally
    #-------------------------------------------------------------------------
    frame .ftop.flexmode.main.body.r1.rtkonly
    frame .ftop.flexmode.main.body.r1.15sec
    frame .ftop.flexmode.main.body.r1.30sec
    frame .ftop.flexmode.main.body.r1.60sec
    frame .ftop.flexmode.main.body.r1.always
    frame .ftop.flexmode.main.body.r1.waasonly
    frame .ftop.flexmode.main.body.r1.omnionly
    label .ftop.flexmode.main.body.r1.rtkonly.txt  -text "1 in\n2 cm"  -font $small_font
    label .ftop.flexmode.main.body.r1.15sec.txt    -text "2 in\n5 cm"  -font $small_font
    label .ftop.flexmode.main.body.r1.30sec.txt    -text "4 in\n10 cm"  -font $small_font
    label .ftop.flexmode.main.body.r1.60sec.txt    -text "6 in\n15 cm"  -font $small_font
    label .ftop.flexmode.main.body.r1.always.txt   -text "16 in\n40 cm" -font $small_font
    label .ftop.flexmode.main.body.r1.waasonly.txt -text "16 in\n40 cm" -font $small_font
    label .ftop.flexmode.main.body.r1.omnionly.txt -text "4 in\n10 cm"  -font $small_font
    
    #Second row holds the scale
    #-------------------------------------------------------------------------
    scale .ftop.flexmode.main.body.r2.range -label "" -bigincrement 1 -from 0 -to 6 \
    -showvalue false   -orient  horizontal -tickinterval 1 \
	-variable flexmode -length 590

    #Divide the third row into seven horizontally
    #-------------------------------------------------------------------------
    frame .ftop.flexmode.main.body.r3.rtkonly
    frame .ftop.flexmode.main.body.r3.15sec
    frame .ftop.flexmode.main.body.r3.30sec
    frame .ftop.flexmode.main.body.r3.60sec
    frame .ftop.flexmode.main.body.r3.always
    frame .ftop.flexmode.main.body.r3.waasonly
    frame .ftop.flexmode.main.body.r3.omnionly
    label .ftop.flexmode.main.body.r3.rtkonly.txt  -text "RTK\nOnly"      -font $small_font
    label .ftop.flexmode.main.body.r3.15sec.txt    -text "15 Sec"         -font $small_font
    label .ftop.flexmode.main.body.r3.30sec.txt    -text "30 Sec"         -font $small_font
    label .ftop.flexmode.main.body.r3.60sec.txt    -text "60 sec"         -font $small_font
    label .ftop.flexmode.main.body.r3.always.txt   -text "Always"         -font $small_font
    label .ftop.flexmode.main.body.r3.waasonly.txt -text "WAAS\nOnly"     -font $small_font
    label .ftop.flexmode.main.body.r3.omnionly.txt -text "OmniSTAR\nOnly" -font $small_font
    
    #pack the first row
    #-------------------------------------------------------------------------
    pack .ftop.flexmode.main.body.r1.rtkonly.txt  -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r1.15sec.txt    -side left -anchor nw -padx 30 -fill x
    pack .ftop.flexmode.main.body.r1.30sec.txt    -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r1.60sec.txt    -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r1.always.txt   -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r1.waasonly.txt -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r1.omnionly.txt -side left -anchor nw -padx 20 -fill x
    
    pack .ftop.flexmode.main.body.r1.rtkonly  -side left -anchor nw
    pack .ftop.flexmode.main.body.r1.15sec    -side left -anchor nw
    pack .ftop.flexmode.main.body.r1.30sec    -side left -anchor nw
    pack .ftop.flexmode.main.body.r1.60sec    -side left -anchor nw
    pack .ftop.flexmode.main.body.r1.always   -side left -anchor nw
    pack .ftop.flexmode.main.body.r1.waasonly -side left -anchor nw
    pack .ftop.flexmode.main.body.r1.omnionly -side left -anchor nw
    
    #pack the second row
    pack .ftop.flexmode.main.body.r2.range -side top -anchor n
    
    #pack the third row
    #-------------------------------------------------------------------------
    pack .ftop.flexmode.main.body.r3.rtkonly.txt  -side left -anchor nw -padx 20 -fill x
    pack .ftop.flexmode.main.body.r3.15sec.txt    -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r3.30sec.txt    -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r3.60sec.txt    -side left -anchor nw -padx 25 -fill x
    pack .ftop.flexmode.main.body.r3.always.txt   -side left -anchor nw -padx 15 -fill x
    pack .ftop.flexmode.main.body.r3.waasonly.txt -side left -anchor nw -padx 30 -fill x
    pack .ftop.flexmode.main.body.r3.omnionly.txt -side left -anchor nw -padx 5  -fill x
    
    pack .ftop.flexmode.main.body.r3.rtkonly  -side left -anchor nw
    pack .ftop.flexmode.main.body.r3.15sec    -side left -anchor nw
    pack .ftop.flexmode.main.body.r3.30sec    -side left -anchor nw
    pack .ftop.flexmode.main.body.r3.60sec    -side left -anchor nw
    pack .ftop.flexmode.main.body.r3.always   -side left -anchor nw
    pack .ftop.flexmode.main.body.r3.waasonly -side left -anchor nw
    pack .ftop.flexmode.main.body.r3.omnionly -side left -anchor nw
    
    #pack the flexmode frame
    #-------------------------------------------------------------------------
    pack .ftop.flexmode.main.title.text -side left -anchor nw
    pack .ftop.flexmode.main.body.r1    -side top -anchor n
    pack .ftop.flexmode.main.body.r2    -side top -anchor n
    pack .ftop.flexmode.main.body.r3    -side top -anchor n

    #define a frame for Remote Engage Switch
    #-------------------------------------------------------------------------
    frame .ftop.remoteengage
    frame .ftop.remoteengage.main -bd 1 -relief solid
    frame .ftop.remoteengage.main.title -bd 1 -relief solid -bg lightgray
    frame .ftop.remoteengage.main.body -bd 1 -relief solid
    
    label .ftop.remoteengage.main.title.text -text "Remote Engage Switch" \
      -font $medium_font -bg lightgray
    
    #define the radio button 
    #-------------------------------------------------------------------------
    radiobutton .ftop.remoteengage.main.body.enable \
      -text "Select to Enable Remote Engage Switch" -font $medium_font \
      -variable remoteStatus -value 0 -command "beepOnce; post $DISP_BTN6_SIG 6" 
      
    #pack the remote engage switch frame
    #-------------------------------------------------------------------------
    pack .ftop.remoteengage.main.body.enable -side top -anchor n -pady 10
    pack .ftop.remoteengage.main.title.text -side left -anchor nw
    pack .ftop.remoteengage.main.title -side top -anchor nw -fill both -expand yes
    pack .ftop.remoteengage.main.body -side bottom -anchor n -fill both -expand yes
    pack .ftop.remoteengage.main -side top -anchor n -fill both -expand yes -padx 5
    
    #define a general navigation frame
    #-------------------------------------------------------------------------
    frame .ftop.generalnav
    label .ftop.generalnav.divider -image imgDivider
    SnazzyButton::create .ftop.generalnav.cancel btnKhakiM4U btnKhakiM4D 0.5 \
            "beepOnce; post $DISP_BTN9_SIG 9" "Cancel"
    SnazzyButton::create .ftop.generalnav.accept btnGreenM4U btnGreenM4D 0.5 \
            "beepOnce; post $DISP_BTN2_SIG 2" "Accept"

    #pack the general navigation frame
    #-------------------------------------------------------------------------
    #pack .ftop.generalnav.divider -side top -anchor n
    pack .ftop.generalnav.accept -side right -anchor se -padx 2 -pady 5
    pack .ftop.generalnav.cancel -side left -anchor sw  -padx 2 -pady 5

    #pack the screen
    #-------------------------------------------------------------------------
    pack .ftop.user -side top  -fill x -expand yes
    pack .ftop.generalnav -side bottom -fill x -expand yes -anchor s
    pack .ftop -side top -fill x -fill y -expand yes


    #-------------------------------------------------------------------------
    # Standard entry and exit procedures (called by GuiMgr)
    #-------------------------------------------------------------------------
    # Action called by GuiMgr on entry to this screen
    proc actEntry { packProc__ } {
      eval $packProc__
	  global deflanguage
	  global userlevel
	  global flexmode
	  global remote
	  set deflanguage 4
	  set userlevel 1
	  set flexmode 3
	  set remote 1
      pack .ftop -fill both -expand yes
    }

    # Action called by GuiMgr on exit from this screen
    proc actExit {} {
        destroy .ftop
    }

    proc setDisplayLanguage { title langtitle languagePrompt \
				  leveltitle userLevelPrompt \
				  flexmodePrompt rtkonly 15sec 30sec 60sec \
				  always waasonly omnionly remoteText \
				  remoteTitleText \
			      canceltext accepttext } {
                              
	  .ftop.title.txt configure -text $title
	  .ftop.user.language.main.title.text configure -text $langtitle
	  .ftop.user.language.main.body.r1.prompt configure -text $languagePrompt
	  .ftop.user.level.main.title.text configure -text $leveltitle
	  .ftop.user.level.main.body.r1.prompt configure -text $userLevelPrompt
	  
	  if { $flexmodePrompt != "!" } {
		  .ftop.flexmode.main.title.text configure -text $flexmodePrompt
		  # Fill GPS Mode Text
	      .ftop.flexmode.main.body.r3.rtkonly.txt configure  -text $rtkonly
	      .ftop.flexmode.main.body.r3.15sec.txt configure    -text $15sec
	      .ftop.flexmode.main.body.r3.30sec.txt configure    -text $30sec
	      .ftop.flexmode.main.body.r3.60sec.txt configure    -text $60sec
	      .ftop.flexmode.main.body.r3.always.txt configure -text $always
	      .ftop.flexmode.main.body.r3.waasonly.txt configure -text $waasonly
	      .ftop.flexmode.main.body.r3.omnionly.txt configure -text $omnionly
	      pack .ftop.flexmode.main.title -side top -fill x -expand yes -anchor nw
	      pack .ftop.flexmode.main.body -side bottom -fill x -expand yes
	      pack .ftop.flexmode.main -side top -fill x -expand yes -padx 5
	      pack .ftop.flexmode -side top -pady 5
	  }
	  if { $remoteText != "!"} {
		  .ftop.remoteengage.main.title.text configure -text $remoteTitleText
		  .ftop.remoteengage.main.body.enable configure -text $remoteText 
		  pack .ftop.remoteengage -side top -fill x -expand yes
	  }
	  .ftop.generalnav.cancel configure -text $canceltext
	  .ftop.generalnav.accept configure -text $accepttext
    }

    proc actToggleAccuracyMode { btnText } {
    }
    
    proc setDefaultValues {lang user flexmode remote_} {
	  setDefaultLanguage $lang
	  setDefaultUser $user
	  setDefaultFlexmode $flexmode
	  setDefaultRemoteEngage $remote_
	  puts "setDefaultRemoteEngage: $remote_"
    }

    proc setDefaultLanguage { lang } {
	  global deflanguage
	  if {$lang == "0"} {
		  set deflanguage  0
		  enableLanguageListbox
	  }
	  if { $lang == "1"} {
		  set deflanguage  1
		  disableLanguageListbox
	  }
    }

    proc setDefaultUser { user } {
	  global userlevel
	  if {$user == "2"} {
		  set userlevel  2
		  disableLevelListbox
	  }
	  if {$user == "1"} {
		  set userlevel  1
		  enableLevelListbox
	  }
	  if {$user == "0" } {
		  set userlevel  0
		  enableLevelListbox
	  }
    }

    proc setDefaultFlexmode { flex } {
	  global flexmode
	  if {$flex == "0"} {
		  set flexmode  0
	  }
	  if {$flex == "1" } {
		  set flexmode  1
	  }
	  if {$flex == "2" } {
		  set flexmode  2
	  }
	  if {$flex == "3" } {
		  set flexmode  3
	  }
	  if {$flex == "4" } {
		  set flexmode  4
	  }
	  if {$flex == "5" } {
		  set flexmode  5
	  }
	  if {$flex == "6" } {
		  set flexmode  6
	  }
    }
    
    proc setDefaultRemoteEngage { engage__ } {
      global remote
      if {$engage__ == 0} {
        set remote 0
        .ftop.remoteengage.main.body.enable deselect
      }
      if {$engage__ == 1} {
        set remote 1
        .ftop.remoteengage.main.body.enable select
      }
    }
    
    proc getDefaultLanguage { } {
	  global deflanguageInd
	  return $deflanguageInd
    }

    proc getDefaultUserLevel { } {
	  global userlevelInd
	  return $userlevelInd
    }

    proc getDefaultFlexmode { } {
	  global flexmode
	  return $flexmode
    }
    
    proc getDefaultRemoteEngage { } {
	  global remote
	  return $remote
	  puts "Remote Engage Switch: $remote" 
    }

    proc actLanguageListBoxInsert { item } {
        .ftop.user.language.main.body.r2.lbox insert end $item
    }

    proc actLanguageListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.user.language.main.body.r2.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.user.language.main.body.r2.lbox selection set $index
        .ftop.user.language.main.body.r2.lbox see $index
    }

    proc actLanguageListboxGetCurindex {} {
      if { [.ftop.user.language.main.body.r2.lbox index end] != 0} {
          return [lindex [.ftop.user.language.main.body.r2.lbox curselection] 0]
      } else {
          return -1             ;# -1 tells the C side the listbox was empty
      }
    }

    proc actLevelListBoxInsert { item } {
        .ftop.user.level.main.body.r2.lbox insert end $item
    }

    proc actLevelListboxSelectItem { item__ } {
        # If list is not empty, try to select an item by name, if item not 
        # found select first item in list
        set items [.ftop.user.level.main.body.r2.lbox get 0 end]
        if { [llength $items] == 0 } {
            return
        }
        set index [lsearch -exact $items $item__]
        if {$index < 0} {
            set index 0
        }
        .ftop.user.level.main.body.r2.lbox selection set $index
        .ftop.user.level.main.body.r2.lbox see $index
    }

    proc actLevelListboxGetCurindex {} {
      if { [.ftop.user.level.main.body.r2.lbox index end] != 0} {
          return [lindex [.ftop.user.level.main.body.r2.lbox curselection] 0]
      } else {
          return -1             ;# -1 tells the C side the listbox was empty
      }
    }

    proc enableLanguageListbox { } {
	  global deflanguageInd
	  .ftop.user.language.main.body.r2.lbox configure -state "normal"
	  .ftop.user.language.main.body.r1.prompt deselect
	  set deflanguageInd 1 
    }

    proc disableLanguageListbox { } {
	  global deflanguageInd
	  .ftop.user.language.main.body.r2.lbox configure -state "disabled"
	  .ftop.user.language.main.body.r1.prompt select
	  set deflanguageInd 0 
    }

    proc enableLevelListbox { } {
	  global userlevelInd
	  .ftop.user.level.main.body.r2.lbox configure -state "normal"
	  .ftop.user.level.main.body.r1.prompt deselect
	  set userlevelInd  1
    }

    proc disableLevelListbox { } {
	  global userlevelInd
	  .ftop.user.level.main.body.r2.lbox configure -state "disabled"
	  .ftop.user.level.main.body.r1.prompt select
	  set userlevelInd  0
    }
    
    proc enableRemoteEngage { } {
	  global remote
	  .ftop.remoteengage.main.body.enable select
	  set remote 1
      puts "Enable Remote Engage: $remote" 
    }
    
    proc disableRemoteEngage { } {
	  global remote
	  .ftop.remoteengage.main.body.enable deselect
	  set remote 0
      puts "Enable Remote Engage: $remote" 
    }
}
    
