#!/bin/sh

###############################################################################
# Configuration options
###############################################################################

# Lower temperature limit in 'C
if [ -z $1 ]
then
    LOWER_LIMIT=-12
else
    LOWER_LIMIT=$1
fi

# Upper temperature limit in 'C
if [ -z $2 ]
then
    UPPER_LIMIT=60
else
    UPPER_LIMIT=$2
fi

# Hysteresis value
if [ -z $3 ]
then
    HYSTERESIS=5
else
    HYSTERESIS=$3
fi

# Interval for temperature checks in seconds.
if [ -z $4 ]
then
    CHECK_INTERVAL=5
else
    CHECK_INTERVAL=$4
fi

# This is to notify the vc app
NOTIFY_THRESHOLD=3

###############################################################################
# Implementation
###############################################################################

GREEN_LED=/dev/io11
RED_LED=/dev/io10

# Begin with status 0. If the temperature is OK the backlight will be turned
# on.  STATUS=0-> out of range, STATUS=1 -> temp is in range
STATUS=1
# 1 = no warning, 0 = warn
WARNING=1


###############################################################################
# Function for handling temperature out of range case
###############################################################################

handle_out_of_range()
{
    STATUS=0
    echo -e "\x1\c" > $GREEN_LED
    echo -e "\x1\c" > $RED_LED
    fbpwm -b 0
}

###############################################################################
# Function for handling temperature out of range case
##############################################################################

handle_back_in_range()
{
    STATUS=1
    echo -e "\x1\c" > $GREEN_LED
    echo -e "\x0\c" > $RED_LED
    fbpwm -b 1
}

###############################################################################
# Initialization
###############################################################################

# Make sure that the starting condition of the backlight matches our internal
# state
handle_back_in_range
# remove flag files
/bin/rm /tmp/lightOff.out
/bin/rm /tmp/warnUser.out

###############################################################################
# Polling loop
###############################################################################

while true; do

    # Read temperature using /proc interface

    TEMPERATURE=$( cat /proc/temperature | cut -d \' -f1 );

    #echo TEMPERATURE $TEMPERATURE
    # If the backlight is on then check limits

    if [ "$STATUS" -ne 0 ]
    then

        #echo "Backlight is on"

        UPPER_CHECK=`expr $TEMPERATURE \> $UPPER_LIMIT`
        LOWER_CHECK=`expr $TEMPERATURE \< $LOWER_LIMIT`

        if [ "$UPPER_CHECK" -ne 0 -o "$LOWER_CHECK" -ne 0 ]
        then
            #echo "Backlight is on, about to turn it off"
            handle_out_of_range
            touch /tmp/lightOff.out
        fi

    # backlight is off
    else

        #echo "Backlight is off"
        # Check if the temperature is within the limits

        UPPER_CHECK=`expr $TEMPERATURE \< $UPPER_LIMIT - $HYSTERESIS`
        LOWER_CHECK=`expr $TEMPERATURE \> $LOWER_LIMIT + $HYSTERESIS`

        if [ "$UPPER_CHECK" -ne 0 -a "$LOWER_CHECK" -ne 0 ]
        then
            #echo "Backlight is off, about to turn it on"
            handle_back_in_range
            /bin/rm /tmp/lightOff.out
        fi
    fi


    # Write out the current temperature if close to upper or lower limit
    # This is used by the vc app to notify user that the screen may
    # go dark

    # No warning in effect - check whether to raise warning
    if [ "$WARNING" -ne 0 ]
       then
       #echo "no warning in effect"
       UPPER_CHECK=`expr $TEMPERATURE \< $UPPER_LIMIT - $NOTIFY_THRESHOLD`
       LOWER_CHECK=`expr $TEMPERATURE \> $LOWER_LIMIT + $NOTIFY_THRESHOLD`

       if [ "$UPPER_CHECK" -ne 1 -o "$LOWER_CHECK" -ne 1 ]
       then
          WARNING=0
          #echo "no warning in effect, about to warn"
          touch /tmp/warnUser.out
       fi

    # Warning in effect - check whether to rescind warning
    else
       #echo "warning in effect"
       UPPER_CHECK=`expr $TEMPERATURE \>= $UPPER_LIMIT - $NOTIFY_THRESHOLD`
       LOWER_CHECK=`expr $TEMPERATURE \<= $LOWER_LIMIT + $NOTIFY_THRESHOLD`
       if [ "$UPPER_CHECK" -eq 0 -a "$LOWER_CHECK" -eq 0 ]
       then
          #echo "no warning in effect, about to rescind warning"
          WARNING=1
          /bin/rm /tmp/warnUser.out
       fi
    fi

    sleep $CHECK_INTERVAL

done
